import { Component } from 'react';
import FuseUtils from '@fuse/utils';
import { connect } from 'react-redux';
import AppContext from 'app/AppContext';
import { withRouter } from 'react-router-dom';
import { matchRoutes } from 'react-router-config';
import { hasAccessToPage } from 'app/utils/permissions';

class FuseAuthorization extends Component {
  constructor(props, context) {
    super(props);
    const { routes } = context;
    this.state = {
      accessGranted: true,
      routes,
    };
  }

  componentDidMount() {
    if (!this.state.accessGranted) {
      this.redirectRoute();
    }
  }

  shouldComponentUpdate(nextProps, nextState) {
    return nextState.accessGranted !== this.state.accessGranted;
  }

  componentDidUpdate() {
    if (!this.state.accessGranted) {
      this.redirectRoute();
    }
  }

  static getDerivedStateFromProps(props, state) {
    const { location, userRole, rolePath } = props;
    const { pathname } = location;

    const matched = matchRoutes(state.routes, pathname)[0];

    let accessGranted = matched
      ? FuseUtils.hasPermission(matched.route.auth, userRole)
      : true;

    if (accessGranted) {
      accessGranted = hasAccessToPage(rolePath, pathname);
    }

    return { accessGranted };
  }

  redirectRoute() {
    const { location, userRole, history, rolePath } = this.props;
    const { pathname, state } = location;

    let redirectUrl = state?.redirectUrl ? state.redirectUrl : '/';

    /*
        User is guest
        Redirect to Login Page
        */
    if (!userRole || userRole.length === 0) {
      history.push({
        pathname: '/login',
        state: { redirectUrl: pathname },
      });
    } else {
      /*
        User is member
        User must be on unAuthorized page or just logged in
        Redirect to dashboard or redirectUrl
        */

      if (
        (rolePath && !hasAccessToPage(rolePath, redirectUrl)) ||
        !hasAccessToPage(rolePath, pathname)
      ) {
        redirectUrl = '/pages/access-denied';
      }
      history.push({
        pathname: redirectUrl,
      });
    }
  }

  render() {
    // console.info('Fuse Authorization rendered', accessGranted);
    return this.state.accessGranted ? <>{this.props.children}</> : null;
  }
}

function mapStateToProps({ auth }) {
  return {
    userRole: auth.user.role,
    rolePath: auth.user.rolePath,
  };
}

FuseAuthorization.contextType = AppContext;

export default withRouter(connect(mapStateToProps)(FuseAuthorization));
