import rtl from 'jss-rtl';
import store from './store';
import { create } from 'jss';
import { Auth } from './auth';
import history from '@history';
import {
  jssPreset,
  StylesProvider,
  createGenerateClassName,
} from '@material-ui/core/styles';
import AppContext from './AppContext';
import MomentUtils from '@date-io/moment';
import jssExtend from 'jss-plugin-extend';
import FuseTheme from '@fuse/core/FuseTheme';
import FuseLayout from '@fuse/core/FuseLayout';
import routes from './fuse-configs/routesConfig';
import Provider from 'react-redux/es/components/Provider';
import { BrowserRouter as Router } from 'react-router-dom';
import FuseAuthorization from '@fuse/core/FuseAuthorization';
import { MuiPickersUtilsProvider } from '@material-ui/pickers';
import { QueryCache, ReactQueryCacheProvider } from 'react-query';

export const queryCache = new QueryCache({
  defaultConfig: {
    queries: {
      refetchOnWindowFocus: false,
    },
  },
});

const jss = create({
  ...jssPreset(),
  plugins: [...jssPreset().plugins, jssExtend(), rtl()],
  insertionPoint: document.getElementById('jss-insertion-point'),
});

const generateClassName = createGenerateClassName();

const App = () => {
  return (
    <AppContext.Provider
      value={{
        routes,
      }}
    >
      <StylesProvider jss={jss} generateClassName={generateClassName}>
        <ReactQueryCacheProvider queryCache={queryCache}>
          <Provider store={store}>
            <MuiPickersUtilsProvider utils={MomentUtils}>
              <Auth>
                <Router basename={process.env.REACT_APP_BASE_URL}>
                  <FuseAuthorization>
                    <FuseTheme>
                      <FuseLayout />
                    </FuseTheme>
                  </FuseAuthorization>
                </Router>
              </Auth>
            </MuiPickersUtilsProvider>
          </Provider>
        </ReactQueryCacheProvider>
      </StylesProvider>
    </AppContext.Provider>
  );
};

export default App;
