import PropTypes from 'prop-types';
import TableRow from '@material-ui/core/TableRow';
import TableHead from '@material-ui/core/TableHead';
import TableCell from '@material-ui/core/TableCell';
import TableSortLabel from '@material-ui/core/TableSortLabel';
 
const DataTableHead = ({
  sortBy,
  onSort,
  sortDir,
  columns,
  rowCount,
  numSelected,
  selectedRows,
  onSelectAllClick,
  isAllRowsSelected,
  isIndeterminateSelect,
  onToggleAllSelectedRow,
}) => {
  const renderHeader = (col) => {
    if (typeof col.header === 'function') {
      return col.header({
        col,
        selectedRows,
        isAllRowsSelected,
        isIndeterminateSelect,
        onToggleAllSelectedRow,
      });
    }

    return col.header;
  };

  return (
    <TableHead>
      <TableRow className="h-64 bg-white">
        {columns.map((col) => {
          const id =
            col.id ||
            (typeof col.accessor === 'string' ? col.accessor : undefined);

          return (
            <TableCell
              key={id}
              align={col.align}
              className="p-0 bg-white"
              sortDirection={sortBy === id ? sortDir : false}
              padding={col.disablePadding ? 'none' : 'default'}
            >
              {col.sortable ? (
                <TableSortLabel
                  direction={sortBy === id ? sortDir : 'asc'}
                  active={sortBy === id}
                  onClick={() => onSort(id)}
                >
                  {renderHeader(col)}
                </TableSortLabel>
              ) : (
                renderHeader(col)
              )}
            </TableCell>
          );
        })}
      </TableRow>
    </TableHead>
  );
};

DataTableHead.propTypes = {
  columns: PropTypes.array.isRequired,
};

export default DataTableHead;
