import PropTypes from 'prop-types';
import 'tinymce/tinymce';
import 'tinymce/icons/default';
import 'tinymce/themes/silver';
import 'tinymce/plugins/paste';
import 'tinymce/plugins/link';
import 'tinymce/plugins/directionality';
import 'tinymce/plugins/image';
import 'tinymce/plugins/table';
import 'tinymce/plugins/autoresize';
import 'tinymce/skins/ui/oxide/skin.min.css';
import 'tinymce/skins/ui/oxide/content.min.css';

import { Editor as TinyEditor } from '@tinymce/tinymce-react';

const Editor = ({ value = '', onChange, direction, className, ...props }) => {
  const handleEditorChange = (content, editor) => {
    onChange(content);
  };

  return (
    <div className={className}>
      <TinyEditor
        // initialValue={value}
        init={{
          skin: false,
          content_css: false,
          content_style: 'body {font-size: 14pt;}',
          height: 130,
          menubar: false,
          statusbar: false,
          plugins: [
            'directionality',
            'link image',
            'table paste',
            'autoresize',
          ],
          directionality: direction,
          branding: false,
          toolbar:
            'undo redo | bold italic backcolor | formatselect | fontsizeselect | \
             alignleft aligncenter alignright alignjustify | \
             bullist numlist outdent indent | removeformat | ltr rtl',
        }}
        value={value}
        onEditorChange={handleEditorChange}
        {...props}
      />
    </div>
  );
};

Editor.propTypes = {
  value: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  direction: PropTypes.string.isRequired,
  className: PropTypes.string.isRequired,
};

export default Editor;
