import React, { useEffect, useState } from "react";
import clsx from "clsx";
import PropTypes from "prop-types";
import { useForm } from "react-hook-form";
import Button from "@material-ui/core/Button";
import { makeStyles } from "@material-ui/core/styles";
import { red } from '@material-ui/core/colors';

import ToggleButton from "@material-ui/lab/ToggleButton";
import FilterListIcon from "@material-ui/icons/FilterList";
import Tooltip from "@material-ui/core/Tooltip";

const useStyles = makeStyles((theme) => ({
  root: {
    "& .MuiTextField-root": {
      margin: theme.spacing(1),
      width: "-moz-available",
    },
    items: {
      width: "-moz-available",

    }
  },
}));


const FilterBox = ({ filters, onChange, onClear, children }) => {
  const classes = useStyles();
  console.log({ filters });
  const { register, handleSubmit, errors, control, reset } = useForm({
    defaultValues: {
      name: filters?.name || "",
    },
  });

  const [showDetails, setShowDetails] = useState(true);

  const onSubmit = (data) => {
    onChange(data);
    console.log(data);
  };

  useEffect(() => {
    // const { name = "" } = filters;
    reset(filters);
    console.log("reset");
  }, [reset, filters]);

  const handleClearFilters = () => {
    onClear();
  };

  return (
 
      ( showDetails && (
      <form
        autoComplete="off"
        className="p-20 mb-4"
        onSubmit={handleSubmit(onSubmit)}
      >
        <div className={clsx("flex w-full  h-auto mt-16  flex-col md:flex-row", classes.root)}>
          <div className={clsx("flex justify-between  w-full border-l-0 md:border-l-1", classes.items)}>
            {React.Children.map(children, (child) => {
              return child.props.name
                ? React.createElement(child.type, {
                  ...{
                    ...child.props,
                    register,
                    control,
                    key: child.props.name,
                  },
                })
                : child;
            })}
          </div>

          <div className={clsx("flex flex-row justify-end md:flex-col md:flex-end min-w-128 border-t-1 md:border-t-0")}>
            <Button
              variant="contained"
              color="primary"
              size="small"
              className="m-8 "
              type="submit"
            >
              اعمال فیلتر
            </Button>

            <Button
              variant="contained"
              style={{ backgroundColor: '#e72324', color: '#FFFFFF' }}
              size="small"
              className="m-8"
              type="button"
              onClick={handleClearFilters}
            >
              ریست فیلتر
            </Button>
          
            <Tooltip title={showDetails ? "بستن فیلترها" : "نمایش فیلترها"}  >
              <ToggleButton
                value="showDetails"
                onClick={() => {
                  setShowDetails(!showDetails);
                }}
                className="border-none left-8 relative  mx-18  rounded-full fixed text-gray-500  "
                aria-label={showDetails ? "بستن فیلترها" : "نمایش فیلترها"}
              >
                <FilterListIcon />
              </ToggleButton>
            </Tooltip> 

          </div>


        </div>
      </form>))
 
  );
};

FilterBox.propTypes = {
  filters: PropTypes.object.isRequired,
  onChange: PropTypes.func.isRequired,
  onClear: PropTypes.func.isRequired,
};

export default FilterBox;
