import clsx from 'clsx';
import PropTypes from 'prop-types';
import Icon from '@material-ui/core/Icon';
import Button from '@material-ui/core/Button';
import { red } from '@material-ui/core/colors';
import Tooltip from '@material-ui/core/Tooltip';
import { makeStyles } from '@material-ui/core/styles';
import IconButton from '@material-ui/core/IconButton';

const useStyles = makeStyles((theme) => ({
  imageDelete: {
    position: 'absolute',
    bottom: 0,
    right: 0,
    color: red[400],
  },
  imageItem: {
    transitionProperty: 'box-shadow',
    transitionDuration: theme.transitions.duration.short,
    transitionTimingFunction: theme.transitions.easing.easeInOut,
  },
}));

const ImageBox = ({ t, name, imageSource, accept, onDelete, onChange }) => {
  const classes = useStyles();

  return (
    <div className="flex flex-col justify-center items-center px-16">
      {imageSource ? (
        <div
          className={clsx(
            classes.imageItem,
            'flex items-center justify-center relative w-128 h-128 rounded-8 overflow-hidden shadow-1 mb-16'
          )}
        >
          <Tooltip title={t('DELETE')}>
            <IconButton
              aria-label={t('DELETE')}
              onClick={(e) => onDelete()}
              className={classes.imageDelete}
            >
              <Icon>delete</Icon>
            </IconButton>
          </Tooltip>

          <img
            src={imageSource}
            className="max-w-none w-auto h-full"
            alt={t(name.toUpperCase())}
          />
        </div>
      ) : (
        <label
          htmlFor={`image-button-${name}`}
          className={clsx(
            classes.imageUpload,
            'flex items-center justify-center relative w-128 h-128 rounded-8 mb-16 overflow-hidden cursor-pointer shadow-1 hover:shadow-5'
          )}
        >
          <Icon fontSize="large" color="action">
            cloud_upload
          </Icon>
        </label>
      )}

      <label htmlFor={`image-button-${name}`}>
        <input
          type="file"
          accept={accept}
          className="hidden"
          onChange={onChange}
          id={`image-button-${name}`}
        />
        <Button component="span" className="whitespace-no-wrap normal-case">
          {t(`CHOOSE_${name.toUpperCase()}`)}
        </Button>
      </label>
    </div>
  );
};

ImageBox.propTypes = {
  accept: PropTypes.string,
  t: PropTypes.func.isRequired,
  imageSource: PropTypes.string,
  name: PropTypes.string.isRequired,
  onDelete: PropTypes.func.isRequired,
  onChange: PropTypes.func.isRequired,
};

export default ImageBox;
