import React, { useState } from "react";
import PropTypes from "prop-types";
import Input from "@material-ui/core/Input";
import Paper from "@material-ui/core/Paper";
import AppBar from "@material-ui/core/AppBar";
import { getMessageCount } from "app/utils/sms";
import { toPersianDigits } from "app/utils/string";
import Typography from "@material-ui/core/Typography";
import MessageTemplatesModal from "../MessageTemplatesModal";

const MessageBox = ({
  value,
  onChange,
  title = "متن ارسال",
  showTemplatesButton = true,
}) => {
  const [count, setCount] = useState({
    isPersian: true,
    length: 0,
    perMessage: 70,
    remaining: 70,
    messageCount: 1,
  });

  const handleChange = (event) => {
    const text = event.target.value;
    setCount(getMessageCount(text));
    onChange(text);
  };

  const handleSelectTemplate = (template) => {
    onChange(value + template?template:"");
  };

  return (
    <Paper className="w-full rounded-8 shadow-1 overflow-hidden">
      <div className="flex items-center justify-between px-16 h-52 border-b-1">

        <Typography  className="text-12 pl-8 pr-8 font-500 pt-48 bg-white text-grey-500 "> {title} </Typography>
        {showTemplatesButton && (
          <MessageTemplatesModal onSelect={handleSelectTemplate} />
        )}
      </div>

      <Input
        rows="6"
        multiline
        margin="none"
        value={value}
        disableUnderline
        onChange={handleChange}
        className="p-16 w-full"
        classes={{ root: "text-14" }}
        placeholder=" "
      />
      <AppBar
        className="card-footer flex flex-col sm:flex-row sm:justify-between border-t-1"
        position="static"
        color="White"
        elevation={0}
      >
        <div className="rounded-2 mb-8 md:mb-0 h-32 whitespace-no-wrap inline-flex items-center justify-center">
          <div className="px-12">
            <span className="text-12 font-400">متن پیام :</span>
            <span className="text-red-300 mr-4">
              {toPersianDigits(count.messageCount ? count.messageCount : 1)}{" "}
              صفحه‌ای
            </span>
          </div>
        </div>
        <div className="rounded-2 mb-8 md:mb-0 h-32 whitespace-no-wrap inline-flex items-center justify-center">
          <div className="px-12">
            <span className="text-red-300 ml-4">
              {toPersianDigits(count.remaining)}
            </span>
            <span className="text-12 font-400">کاراکتر باقیمانده</span>
          </div>
        </div>
        <div className="rounded-2 mb-8 md:mb-0 h-32 whitespace-no-wrap inline-flex items-center justify-center">
          <div className="px-12">
            <span className="text-12 font-400">نوع پیام :</span>
            <span className="text-red-300 mr-4">
              {count.isPersian ? "فارسی" : "انگلیسی"}
            </span>
          </div>
        </div>
      </AppBar>
    </Paper>
  );
};

MessageBox.propTypes = {
  title: PropTypes.string,
  value: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  showTemplatesButton: PropTypes.bool,
};

export default MessageBox;
