import clsx from 'clsx';
import PropTypes from 'prop-types';
import TableRow from '@material-ui/core/TableRow';
import { toPersianDigits } from 'app/utils/string';
import MaterialTable from '@material-ui/core/Table';
import TableBody from '@material-ui/core/TableBody';
import TableCell from '@material-ui/core/TableCell';
import TableHead from '@material-ui/core/TableHead';
import FuseScrollbars from '@fuse/core/FuseScrollbars';
import TableSortLabel from '@material-ui/core/TableSortLabel';
import TablePagination from '@material-ui/core/TablePagination';
import TablePaginationActions from 'app/components/TablePaginationActions';
import { makeStyles } from '@material-ui/core/styles';

const useStyles = makeStyles({
  '@global': {
    tr: {
      cursor: 'pointer',
    },
  },
});

const Table = ({ showFilters, tableInstance, count, filterBox, clicked }) => {
  const {
    page,
    gotoPage,
    prepareRow,
    setPageSize,
    headerGroups,
    getTableProps,
    state: { pageIndex, pageSize },
  } = tableInstance;
  const handleChangePage = (event, newPage) => {
    gotoPage(newPage);
  };

  const handleChangeRowsPerPage = (event) => {
    setPageSize(Number(event.target.value));
  };
  useStyles();
  return (
    <div className="w-full flex flex-col">
      <FuseScrollbars className="flex-grow overflow-x-auto">
        {showFilters && filterBox ? filterBox : null}

        <MaterialTable {...getTableProps()} stickyHeader>
          <TableHead>
            {headerGroups.map((headerGroup) => (
              <TableRow {...headerGroup.getHeaderGroupProps()}>
                {headerGroup.headers.map((column) => (
                  <TableCell
                    className="whitespace-no-wrap p-12"
                    {...(!column.sortable
                      ? column.getHeaderProps()
                      : column.getHeaderProps(column.getSortByToggleProps()))}
                  >
                    {column.render('Header')}
                    {column.sortable ? (
                      <TableSortLabel
                        active={column.isSorted}
                        // react-table has a unsorted state which is not treated here
                        direction={column.isSortedDesc ? 'desc' : 'asc'}
                      />
                    ) : null}
                  </TableCell>
                ))}
              </TableRow>
            ))}
          </TableHead>
          <TableBody>
            {page.map((row, i) => {
              prepareRow(row);
              return (
                <TableRow
                  onClick={()=>clicked(row)}
                  {...row.getRowProps()}
                  // onClick={(ev) => onRowClick(ev, row)}
                  className="truncate"
                >
                  {row.cells.map((cell) => {
                    return (
                      <TableCell
                        {...cell.getCellProps()}
                        className={clsx('p-12', cell.column.className)}
                      >
                        {cell.render('Cell')}
                      </TableCell>
                    );
                  })}
                </TableRow>
              );
            })}
          </TableBody>
        </MaterialTable>
      </FuseScrollbars>
      {count && (
        <TablePagination
          component="div"
          classes={{
            root: 'flex-shrink-0 border-0',
            spacer: 'w-0 max-w-0',
          }}
          rowsPerPageOptions={[
            5,
            10,
            25,
            // { label: "All", value: pagination.total },
          ]}
          colSpan={5}
          count={count}
          rowsPerPage={pageSize}
          page={pageIndex}
          SelectProps={{
            inputProps: { 'aria-label': 'rows per page' },
            native: false,
          }}
          onChangePage={handleChangePage}
          onChangeRowsPerPage={handleChangeRowsPerPage}
          ActionsComponent={TablePaginationActions}
          labelDisplayedRows={({ from, to, count }) => {
            return `${toPersianDigits(from)} - ${toPersianDigits(
              to
            )} از ${toPersianDigits(count)}`;
          }}
          labelRowsPerPage="تعداد سطرهای هر صفحه"
        />
      )}
    </div>
  );
};

Table.propTypes = {
  filterBox: PropTypes.node,
  count: PropTypes.number,
  showFilters: PropTypes.bool.isRequired,
  tableInstance: PropTypes.object.isRequired,
};

export default Table;
