import { useTranslation } from 'react-i18next';
import { toLocaleDigits } from 'app/utils/string';
import Pagination from '@material-ui/core/TablePagination';
import TablePaginationActions from '../TablePaginationActions';

const defaultRowsPerPageOptions = [1, 5, 10, 25];

const defaultClasses = { root: 'flex-shrink-0 border-0' };

const TablePagination = ({ rowsPerPageOptions, classes, ...props }) => {
  const { t, i18n } = useTranslation('app');

  const currentLang = i18n.language;

  const getRowsPerPageOptions = (options) => {
    const perPageOptions = options ? options : defaultRowsPerPageOptions;

    return perPageOptions.map((option) => {
      return {
        label: toLocaleDigits(
          option?.label ? option.label : option,
          currentLang
        ),
        value: option?.value ? option.value : option,
      };
    });
  };

  return (
    <Pagination
      component="div"
      classes={{ ...defaultClasses, ...classes }}
      rowsPerPageOptions={getRowsPerPageOptions(rowsPerPageOptions)}
      colSpan={5}
      SelectProps={{
        native: true,
        inputProps: { 'aria-label': t('ROWS_PER_PAGE') },
      }}
      ActionsComponent={TablePaginationActions}
      labelDisplayedRows={({ from, to, count }) => {
        return `${toLocaleDigits(from, currentLang)} - ${toLocaleDigits(
          to,
          currentLang
        )} ${t('ROWS_PER_PAGE_OF')} ${toLocaleDigits(count, currentLang)}`;
      }}
      labelRowsPerPage={t('ROWS_PER_PAGE')}
      {...props}
    />
  );
};

TablePagination.propTypes = {};

export default TablePagination;
