import { memo } from 'react';
import clsx from 'clsx';
import { useDispatch, useSelector } from 'react-redux';
import AppBar from '@material-ui/core/AppBar';
import Hidden from '@material-ui/core/Hidden';
import FuseSearch from '@fuse/core/FuseSearch';
import Toolbar from '@material-ui/core/Toolbar';
import FuseShortcuts from '@fuse/core/FuseShortcuts';
import { selectToolbarTheme } from 'app/store/fuse/settingsSlice';
import UserMenu from 'app/fuse-layouts/shared-components/UserMenu';
import { makeStyles, ThemeProvider } from '@material-ui/core/styles';
import FullScreenToggle from '../../shared-components/FullScreenToggle';
import LanguageSwitcher from '../../shared-components/LanguageSwitcher';
import NavbarMobileToggleButton from 'app/fuse-layouts/shared-components/NavbarMobileToggleButton';
import ChatPanelToggleButton from 'app/fuse-layouts/shared-components/chatPanel/ChatPanelToggleButton';
import QuickPanelToggleButton from 'app/fuse-layouts/shared-components/quickPanel/QuickPanelToggleButton';
import Button from '@material-ui/core/Button';
//------------------maddahi add 


const useStyles = makeStyles((theme) => ({
  root: {
    backgroundColor:'rgba(255, 255, 255, 0)',
  },
  loginstyle: {
    '& > *': {
      margin: theme.spacing(1),
    },
  },
}));

function ToolbarLayout1(props) {
  const config = useSelector(({ fuse }) => fuse.settings.current.layout.config);
  const toolbarTheme = useSelector(selectToolbarTheme);

  const classes = useStyles(props);

  const dispatch = useDispatch();
  const user = useSelector(({ auth }) => auth.user);

  return (
    <ThemeProvider theme={toolbarTheme}>
      <AppBar
        id="fuse-toolbar"
        className={clsx(classes.root, 'flex absolute z-10')}
        // color="default"
        // style={{ backgroundColor: toolbarTheme.palette.background.paper }}
        elevation={1}
      >
        <Toolbar className="p-0 min-h-48 md:min-h-64">
          {config.navbar.display && config.navbar.position === 'right' && (
            <Hidden lgUp>
              <NavbarMobileToggleButton className="w-80 h-40 p-0 mx-0 sm:mx-8" />
            </Hidden>
          )}



          <div className={classes.loginstyle, "flex flex-1 justify-center "}>

            {!user.role || user.role.length === 0 ? (
              <>
                {/* <Button color="action" className="mr-4 sm:mr-8  md:mr-32" // startIcon={<Icon></Icon>}
                >
                  تعرفه پنل
                </Button>
                <Button  color="primary" className="mr-4 sm:mr-8  md:mr-32" >
                  تعرفه شارژ پیامک
                </Button>
                <Button   color="primary" className="mr-4 sm:mr-8  md:mr-32" >
                  تعرفه خطوط پیامک
                </Button>
                <Button color="primary" className="mr-4 sm:mr-8  md:mr-32" >
                  نمایندگی
                </Button>
                <Button color="primary" className="mr-4 sm:mr-8  md:mr-32" >
                  تماس با ما
                </Button> */}
              </>
            ) : (<>   </>)}
          </div>

          <div className="flex items-center px-16">
            <LanguageSwitcher />
            <FullScreenToggle />
            <FuseSearch />
            <Hidden lgUp>     <ChatPanelToggleButton />            </Hidden>
            <QuickPanelToggleButton />
            <UserMenu />
          </div>

          {config.navbar.display && config.navbar.position === 'left' && (
            <Hidden lgUp>
              <NavbarMobileToggleButton />
            </Hidden>
          )}
        </Toolbar>
      </AppBar>
    </ThemeProvider>
  );
}

export default memo(ToolbarLayout1);
