import { useState } from 'react';
import { queryCache } from 'app/App';
import Button from '@material-ui/core/Button';
import Popover from '@material-ui/core/Popover';
import MenuItem from '@material-ui/core/MenuItem';
import { changeLanguage } from 'app/store/i18nSlice';
import Typography from '@material-ui/core/Typography';
import { useSelector, useDispatch } from 'react-redux';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';
import { updateUserLanguage } from 'app/auth/store/userSlice';

const languages = [
  {
    id: 'fa',
    title: 'Persian',
    flag: 'ir',
  },
  {
    id: 'en',
    title: 'English',
    flag: 'us',
  },
  
  {
    id: 'ar',
    title: 'Arabic',
    flag: 'sa',
  },
  {
    id: 'ru',
    title: 'Russian',
    flag: 'ru',
  },
];

function LanguageSwitcher(props) {
  const dispatch = useDispatch();

  const currentLanguageId = useSelector(({ i18n }) => i18n.language);

  const currentLanguage = languages.find((lng) => lng.id === currentLanguageId);

  const [menu, setMenu] = useState(null);

  const langMenuClick = (event) => {
    setMenu(event.currentTarget);
  };

  const langMenuClose = () => {
    setMenu(null);
  };

  function handleLanguageChange(lng) {
    dispatch(changeLanguage(lng.id));
    langMenuClose();
    queryCache.clear();
    dispatch(updateUserLanguage(lng.id));
  }

  return (
    <>
      <Button className="h-40 w-64" onClick={langMenuClick}>
        <img
          className="mx-4 min-w-20"
          alt={currentLanguage.title}
          src={`${process.env.PUBLIC_URL}/assets/images/flags/${currentLanguage.flag}.png`}
        />

        <Typography className="mx-4 font-bold" color="textSecondary">
          {currentLanguage.id}
        </Typography>
      </Button>

      <Popover
        anchorEl={menu}
        open={Boolean(menu)}
        onClose={langMenuClose}
        classes={{ paper: 'py-8' }}
        anchorOrigin={{ vertical: 'bottom', horizontal: 'center' }}
        transformOrigin={{ vertical: 'top', horizontal: 'center' }}
      >
        {languages.map((lng) => (
          <MenuItem key={lng.id} onClick={() => handleLanguageChange(lng)}>
            <ListItemIcon className="min-w-40">
              <img
                alt={lng.title}
                className="min-w-20"
                src={`${process.env.PUBLIC_URL}/assets/images/flags/${lng.flag}.png`}
              />
            </ListItemIcon>
            <ListItemText primary={lng.title} />
          </MenuItem>
        ))}
      </Popover>
    </>
  );
}

export default LanguageSwitcher;
