import react, { useEffect, useState } from 'react';
import * as yup from "yup";

import Button from "@material-ui/core/Button";
import FuseAnimate from '@fuse/core/FuseAnimate';
import FuseAnimateGroup from '@fuse/core/FuseAnimateGroup';
import Card from '@material-ui/core/Card';
import CardContent from '@material-ui/core/CardContent';

import { makeStyles, withStyles } from '@material-ui/core/styles';
import Typography from '@material-ui/core/Typography';
import clsx from 'clsx';
import Spinner from 'app/components/Spinner';
import usePackageView from '../../hooks/usePackageView';
import InputAdornment from '@material-ui/core/InputAdornment';

import { DateTimePicker } from "@material-ui/pickers";
import FormControl from "@material-ui/core/FormControl";
import TextField from "@material-ui/core/TextField";
import { useForm, Controller } from "react-hook-form";
import FuseChipSelect from "@fuse/core/FuseChipSelect";
import { yupResolver } from "@hookform/resolvers/yup";

const groupsData = [
	"حقیقی", "حقوقی",
].map((item) => ({
	value: item,
	label: item,
}));
const validationSchema = yup.object().shape({
	// groups: yup.string().required(),
});
const ValidationTextField = withStyles({
	root: {
		'& input:valid + fieldset': {
			// borderColor: 'green',
			borderWidth: 1,
		},
		'& input:invalid + fieldset': {
			borderColor: 'red',
			borderWidth: 2,
		},
		'& input:valid:focus + fieldset': {
			borderLeftWidth: 6,
			padding: '4px !important', // override inline-style
		},
	},
})(TextField);
const useStyles = makeStyles((theme) => ({
	root: {
		width: '100%',
		'& > * + *': {
			marginTop: theme.spacing(2),
		},
	}, header: {
		height: 600,
		background: `linear-gradient(to left, ${theme.palette.primary.dark} 0%, ${theme.palette.primary.main} 100%)`,
		color: theme.palette.primary.contrastText
	},
	badge: {
		backgroundColor: theme.palette.error.main,
		color: theme.palette.getContrastText(theme.palette.error.main)
	},
	price: {
		backgroundColor: theme.palette.primary[600],
		color: theme.palette.getContrastText(theme.palette.primary[600])
	}
}));


const CompleteProfile = () => {

	const { register, handleSubmit, control, errors } = useForm({
		defaultValues: {
			text: "",
			groups: [],
			contacts: "",
			sendNumber: "",
			sendDate: null,
			removeDuplicates: false,
			doNotSendToSpecialList: false,
		},
		resolver: yupResolver(validationSchema),
	});

	const handleSendMessage = (data) => console.log({ data });


	const classes = useStyles();
	const { data, isLoading } = usePackageView();

	const formatter = new Intl.NumberFormat('fa-IR', {
		style: 'currency',
		currency: 'IRR',
		minimumFractionDigits: 0
	});


	if (isLoading) {
		return <Spinner />;
	}
	return (
		<div className="flex flex-wrap w-full ">
			<form onSubmit={handleSubmit(handleSendMessage)} className="flex flex-wrap w-full pt-56">

				<div className="flex w-full  mb-16">
					<Controller

						isMulti
						name="groups"
						control={control}
						className="mx-8 ml-16  pl-16 w-1/2"
						as={FuseChipSelect}
						options={groupsData}
						placeholder="شخصیت  "
						textFieldProps={{
							label: "  شخصیت",
							InputLabelProps: {
								shrink: true,
							},
							variant: "outlined",
						}}
					/>
				</div>
				<div className="flex   w-full">
					<ValidationTextField
						autoFocus
						fullWidth
						type="text"
						name="title"
						label="  نام "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 w-1/2"
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/>
					<ValidationTextField

						fullWidth
						type="text"
						name="title"
						label="  نام خانوداگی "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 w-1/2"
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/>
				</div>
				<div className="flex   w-full">
					<ValidationTextField

						fullWidth
						type="text"
						name="title"
						label="  نام پدر "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 w-1/2"
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/>
					<ValidationTextField

						fullWidth
						type="text"
						name="title"
						label="  کد ملی   "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 w-1/2"
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/>
				</div>
				<div className="flex   w-full">
					<ValidationTextField

						fullWidth
						type="text"
						name="title"
						label="  شماره شناسنامه "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 w-1/2"
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/>
					<FormControl
						className="mx-8 mb-20 w-1/2"
						variant="outlined"
						style={{ direction: "rtl" }}
					>
						<Controller
							name="sendDate"
							control={control}
							as={DateTimePicker}
							autoOk
							clearable
							disablePast
							showTodayButton
							okLabel="تأیید"
							cancelLabel="لغو"
							label="  تاریخ تولد"
							margin="dense"
							todayLabel="امروز"
							clearLabel="پاک کردن"
							inputVariant="outlined"							
							labelFunc={(date) =>
								date ? date.format("jYYYY/jMM/jDD HH:mm") : ""
							}
						/>
					</FormControl>
				</div>
				<div className="flex   w-full">
					<ValidationTextField

						fullWidth
						type="text"
						name="title"
						label="  موبایل   "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 w-1/2"
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/>
					<ValidationTextField

						fullWidth
						type="text"
						name="title"
						label="  تلفن     "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 w-1/2"
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/>
				</div>
				<div className="flex   w-full">
					<ValidationTextField

						fullWidth
						type="text"
						name="title"
						label="  ایمیل   "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 w-1/2"
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/>
					<Controller 
						isMulti
						name="groups"
						control={control}
						className="mx-8 mb-20 w-1/2 mt-8"
						as={FuseChipSelect}
						options={groupsData}
						placeholder="استان  "
						textFieldProps={{
							label: "  استان",
							InputLabelProps: {
								shrink: true,
							},
							variant: "outlined",
						}}
					/>
				</div>
				<div className="flex   w-full">
					<Controller
						isMulti
						name="groups"
						control={control}
						className="mx-8 mb-20 w-1/2  mt-8"
						as={FuseChipSelect}
						options={groupsData}
						placeholder="شهر  "
						textFieldProps={{
							label: "  شهر",
							InputLabelProps: {
								shrink: true,
							},
							variant: "outlined",
						}}
					/>
					<ValidationTextField

						fullWidth
						type="text"
						name="title"
						label="  کد پستی   "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 w-1/2"
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/>

				</div>
				<div className="flex   w-full">
					<ValidationTextField

						fullWidth
						type="text"
						name="title"
						label="  آدرس کامل   "
						margin="dense"
						variant="outlined"
						inputRef={register}
						className="mx-8 mb-20 "
						InputProps={{
							startAdornment: <InputAdornment position="start"> </InputAdornment>,
						}}
					/></div>
				<div className="flex w-full mt-32 mb-8 justify-center ">
					<Button
						type="button"
						className="mx-8"
						color="secondary"
						variant="contained"
					>
						ثبت و ادامه
					</Button>

				</div>
			</form>


		</div>
	);
};


export default CompleteProfile;
