import React from "react";
import * as yup from "yup";
import { useParams } from 'react-router';
import ContactBox from "../ContactBox";
import Spinner from 'app/components/Spinner';
import Select from "@material-ui/core/Select";
import Switch from "@material-ui/core/Switch";
import MessageInvoice from "../MessageInvoice";
import MenuItem from "@material-ui/core/MenuItem";
import { yupResolver } from "@hookform/resolvers/yup";
import MessageBox from "app/components/MessageBox";
import TextField from "@material-ui/core/TextField";
import InputLabel from "@material-ui/core/InputLabel";
import { DateTimePicker } from "@material-ui/pickers";
import { useForm, Controller } from "react-hook-form";
import FormControl from "@material-ui/core/FormControl";
import OutlinedInput from "@material-ui/core/OutlinedInput";
import FormHelperText from "@material-ui/core/FormHelperText";
import FormControlLabel from "@material-ui/core/FormControlLabel";
import { withStyles, } from '@material-ui/core/styles';
import InputAdornment from '@material-ui/core/InputAdornment';
import LoadingButton from 'app/components/LoadingButton';
import { useTranslation } from 'react-i18next';
import useSaveNormalMsg from '../../hooks/useSaveNormalMsg';
import useNormalMsg from '../../hooks/useNormalMsg';
import { showMessage } from 'app/store/fuse/messageSlice';
import { useDispatch } from 'react-redux';
import { useHistory } from 'react-router-dom';

const ValidationTextField = withStyles({
  root: {
    '& input:valid + fieldset': {
      // borderColor: 'green',
      borderWidth: 1,
    },
    '& input:invalid + fieldset': {
      borderColor: 'red',
      borderWidth: 2,
    },
    '& input:valid:focus + fieldset': {
      borderLeftWidth: 6,
      padding: '4px !important', // override inline-style
    },
  },
})(TextField);

const validationSchema = yup.object().shape({
  sendNumber: yup.string().required(),
});

const NewMessage = (props) => {

  const dispatch = useDispatch();
  const history = useHistory();

  const { register, handleSubmit, control, errors, formState: { isSubmitting } } = useForm({
    defaultValues: {
      text: "",
      contacts: "",
      sendNumber: "",
      sendDate: null,
      doNotSendToSpecialList: false,
    },
    resolver: yupResolver(validationSchema),
  });
  let { MsgId } = useParams();
  const isEdit = MsgId === 'new';
  const { data, isLoading, remove } = useNormalMsg({
    MsgId,
    enabled: isEdit,
  });
  const [saveNormalMsg] = useSaveNormalMsg();

  const handleEdit = (data) => {
    const {     ...restOfData } = data;
  
    return saveNormalMsg({ data: restOfData, isEdit }).then(() => {
      dispatch(showMessage({ message: 'Message send' }));
      if (!isEdit) {
        history.push('/apps/e-sms/sendmsg/post');
      }
    });
  };


  const { t } = useTranslation('message');
  const handleSendMessage = (data) => console.log({ data });

  if (isLoading) {
    return <Spinner />;
  }
  return (
    
      <div className="flex flex-wrap">
        <div className="w-full md:w-3/6 p-12 mt-0">
          {/* <form onSubmit={handleSubmit(handleSendMessage)}> */}
          <form className="h-full" onSubmit={handleSubmit(handleEdit)} noValidate>
            <ValidationTextField
              autoFocus
              fullWidth
              type="text"
              name="title"
              label="عنوان ارسال"
              margin="dense"
              variant="outlined"
              inputRef={register}
              className="mt-0 mb-20"
              InputProps={{
                startAdornment: <InputAdornment position="start"> </InputAdornment>,
              }}
            />

            <div>
              <Controller name="textmsg" control={control} as={MessageBox} />

            </div>

            <div>
              <FormControl
                className="flex w-full mt-16 mb-16"
                variant="outlined"
                margin="dense"
                error={!!errors?.sendNumber}
              >
                <InputLabel htmlFor="send-number-label-placeholder">
                  از شماره
                </InputLabel>
                <Select
                  error={!!errors?.sendNumber}
                  input={
                    <Controller
                      name="sendNumber"
                      control={control}
                      as={OutlinedInput}
                      id="send-number-label-placeholder"
                      labelWidth={"ارسال از شماره".length * 6}
                    />
                  }
                >
                  <MenuItem value="123456">
                    <em>123456</em>
                  </MenuItem>
                  <MenuItem value="1587878">
                    <em>1587878</em>
                  </MenuItem>
                  <MenuItem value="9898565">
                    <em>9898565</em>
                  </MenuItem>
                  <MenuItem value="787878">
                    <em>787878</em>
                  </MenuItem>
                </Select>
                {errors?.sendNumber && (
                  <FormHelperText>{errors?.sendNumber?.message}</FormHelperText>
                )}
              </FormControl>

            </div>

            <div>
              <Controller name="contacts" control={control} as={ContactBox} />

            </div>

            <div>
              <FormControl
                className="flex w-full mt-8 mb-16"
                variant="outlined"
                style={{ direction: "rtl" }}
              >
                <Controller
                  name="sendDate"
                  control={control}
                  as={DateTimePicker}
                  autoOk
                  clearable
                  disablePast
                  showTodayButton
                  okLabel="تأیید"
                  cancelLabel="لغو"
                  label="زمان ارسال"
                  margin="dense"
                  todayLabel="امروز"
                  clearLabel="پاک کردن"
                  inputVariant="outlined"
                  labelFunc={(date) =>
                    date ? date.format("jYYYY/jMM/jDD HH:mm") : ""
                  }
                />
              </FormControl>

            </div>

            <div>
              <div className="mt-8 mb-16">
                <FormControlLabel
                  control={
                    <Switch name="doNotSendToSpecialList" inputRef={register} />
                  }
                  label="عدم ارسال به لیست ویژه"
                />
                <FormHelperText id="my-helper-text">
                  این گزینه بدین معنی است که پیامک به شماره های موجود در لیست ویژه
                  ارسال نمی شود
                </FormHelperText>
              </div>
            </div>

            <div className="my-32 flex">
              <LoadingButton
                type="button"
                className="mx-8"
                color="secondary"
                variant="contained"
              >
                {t('BILL_Calc')}
              </LoadingButton>

              <LoadingButton
                type="submit"
                color="secondary"
                variant="contained"
                isLoading={isSubmitting}
                className="whitespace-no-wrap normal-case"
                disabled={isSubmitting}
              >
                {t('SEND_Msg')}
              </LoadingButton>

            </div>
          </form>
        </div>
        <div className="w-full md:w-3/6 p-12">
          <MessageInvoice />
        </div>
      </div>
    // </form>
  );
};

NewMessage.propTypes = {};

export default NewMessage;
