import react, { useEffect, useState } from 'react';
import Button from "@material-ui/core/Button";
import FuseAnimate from '@fuse/core/FuseAnimate';
import FuseAnimateGroup from '@fuse/core/FuseAnimateGroup';
import Card from '@material-ui/core/Card';
import CardContent from '@material-ui/core/CardContent';
import { makeStyles } from '@material-ui/core/styles';
import Typography from '@material-ui/core/Typography';
import clsx from 'clsx';
import Spinner from 'app/components/Spinner';
import usePackageView from '../../hooks/usePackageView';

import { useForm, Controller } from "react-hook-form";
import FuseChipSelect from "@fuse/core/FuseChipSelect";
import { Link } from 'react-router-dom';

const bakgateway = [
	"  آنلاین  ",
].map((item) => ({
	value: item,
	label: item,
}));
const payType = [
	"    زرین پال", "      ملی", '    ملت',
].map((item) => ({
	value: item,
	label: item,
}));
const useStyles = makeStyles((theme) => ({
	root: {

		width: '100%',
		'& > * + *': {
			marginTop: theme.spacing(2),
		},
	}, header: {
		height: 600,
		background: `linear-gradient(to left, ${theme.palette.primary.dark} 0%, ${theme.palette.primary.main} 100%)`,
		color: theme.palette.primary.contrastText
	},
	badge: {
		backgroundColor: theme.palette.error.main,
		color: theme.palette.getContrastText(theme.palette.error.main)
	},
	price: {
		backgroundColor: theme.palette.primary[600],
		color: theme.palette.getContrastText(theme.palette.primary[600])
	}
}));


const SelectPackage = () => {
	const classes = useStyles();
	const { data, isLoading } = usePackageView();

	const formatter = new Intl.NumberFormat('fa-IR', {
		style: 'currency',
		currency: 'IRR',
		minimumFractionDigits: 0
	});
	const { control } = useForm({});

	if (isLoading) {
		return <Spinner />;
	}
	return (
		<div className="flex flex-wrap pt-56">
			<form className="flex flex-wrap justify-between w-full">
				{data.length > 0 &&
					data.map((row) => (
						<div className="w-full max-w-320 sm:w-1/2 md:w-1/4 lg:w-1/4 p-12">
							<Card className="relative rounded-8" raised>
								<div className="p-24 text-center">
									<Typography className="text-28">{row.title}</Typography>
									<Typography color="textSecondary" className="text-16 font-bold">
										{row.subTitle}
									</Typography>
									<Typography color="grey" className="text-12 font-light">
										{row.type}
									</Typography>
								</div>

								<CardContent className="text-center p-0">
									<div className={clsx(classes.price, 'flex flex-col justify-center py-16 px-32')}>
										<div className="flex justify-center">
											<Typography
												color="inherit"
												className="text-24 mx-4 font-light leading-none"
											>
												{formatter.format(row.price ? row.price : 0)}
											</Typography>	<Typography color="inherit" className="font-medium">

											</Typography>
										</div>
										<Typography color="inherit" className="mx-4">
											{row.duration ? row.duration : ''}
										</Typography>
									</div>

									<div className="flex flex-col p-32">
										{row.description.map((des) => (
											<Typography color="textSecondary" className="mb-4">
												{des.title ? des.title : ''}
											</Typography>
										))}
									</div>
								</CardContent>

								<div className="flex flex-col items-center justify-center pb-32 px-32">
									<Button variant="contained" color="secondary" className="w-full">
										انتخاب
									</Button>
									<Typography color="textSecondary" className="mt-16">
										{row.subscribe ? row.subscribe : ''}
									</Typography>
								</div>
							</Card>
						</div>
					))}

				<div className="flex w-full mt-32 mb-8 justify-center ">
					<Button
						type="button"
						className="mx-8"
						color="secondary"
						variant="contained"
					>
						ثبت و ادامه
					</Button>

				</div>
			</form>


			<form className="flex flex-wrap justify-between w-full"  >
				<div className={classes.root}>
					<div className=" border border-opacity-5 p-8 rounded  justify-center   flex-row text-center">
						<Typography color="green" variant="h6" gutterBottom className="text-grey-900">
							پرداخت صورتحساب
						</Typography>
						<Typography color="green" variant="p" className="text-black">
							پنل  کاربری - شرکتی
							<br />

							<br /> قابل پرداخت : 1.333.000 ریال
						</Typography>
						<div className="flex flex-row w-full mt-16 mb-8 justify-between ">
							<Controller
								name="groups"
								size="small"
								control={control}
								className="  mr-24  ml-24 min-w-120 sm:w-1/2 md:w-full"
								as={FuseChipSelect}
								options={bakgateway}
								placeholder="آنلاین"
								textFieldProps={{
									label: "  نوع پرداخت   ",
									InputLabelProps: {
										shrink: true,
									},
									variant: "outlined",
								}}
							/>

							<Controller
								name="groups"
								size="small"
								control={control}
								className="  ml-16  pl-16 min-w-120 sm:w-1/2 md:w-full"
								as={FuseChipSelect}
								options={bakgateway}
								placeholder="  ملت    "
								textFieldProps={{
									label: "  انتخاب درگاه     ",
									InputLabelProps: {
										shrink: true,
									},
									variant: "outlined",
								}}
							/>
						</div>
					</div>
				</div>

				<div className="flex w-full mt-32 mb-8 justify-center ">
					<Button
						type="submit"
						className="mx-8"
						color="secondary"
						variant="contained"
						component={Link} to="/apps/Authentication/SelectPackage"
					>
						پرداخت صورتحساب
					</Button>
				</div>
			</form>


		</div>
	);
};


export default SelectPackage;
