import react, { useEffect, useState } from 'react';
import * as yup from "yup";

import Button from "@material-ui/core/Button";
import FuseAnimate from '@fuse/core/FuseAnimate';
import FuseAnimateGroup from '@fuse/core/FuseAnimateGroup';
import Card from '@material-ui/core/Card';
import CardContent from '@material-ui/core/CardContent';

import { makeStyles, withStyles } from '@material-ui/core/styles';
import clsx from 'clsx';
import Spinner from 'app/components/Spinner';
import usePackageView from '../../hooks/usePackageView';
import InputAdornment from '@material-ui/core/InputAdornment';

import { DateTimePicker } from "@material-ui/pickers";
import FormControl from "@material-ui/core/FormControl";
import TextField from "@material-ui/core/TextField";
import { useForm, Controller } from "react-hook-form";
import FuseChipSelect from "@fuse/core/FuseChipSelect";
import { yupResolver } from "@hookform/resolvers/yup";
import Accordion from '@material-ui/core/Accordion';
import AccordionDetails from '@material-ui/core/AccordionDetails';
import AccordionSummary from '@material-ui/core/AccordionSummary';
import Typography from '@material-ui/core/Typography';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import { Link } from 'react-router-dom';
import Icon from '@material-ui/core/Icon';
 
import Table from '@material-ui/core/Table';
import TableBody from '@material-ui/core/TableBody';
import TableCell from '@material-ui/core/TableCell';
import TableContainer from '@material-ui/core/TableContainer';
import TableHead from '@material-ui/core/TableHead';
import TableRow from '@material-ui/core/TableRow';
import Paper from '@material-ui/core/Paper';


const groupsData = [
	"پشت کارت ملی", "تصویر رنگی کارت ملی", 'صفحه اول شناسنامه',
].map((item) => ({
	value: item,
	label: item,
}));
const validationSchema = yup.object().shape({
	// groups: yup.string().required(),
});
const ValidationTextField = withStyles({
	root: {
		'& input:valid + fieldset': {
			// borderColor: 'green',
			borderWidth: 1,
		},
		'& input:invalid + fieldset': {
			borderColor: 'red',
			borderWidth: 2,
		},
		'& input:valid:focus + fieldset': {
			borderLeftWidth: 6,
			padding: '4px !important', // override inline-style
		},
	},
})(TextField);
const useStyles = makeStyles((theme) => ({
	root: {
		width: '100%',
		'& > * + *': {
			marginTop: theme.spacing(2),
		},
	}, header: {
		height: 600,
		background: `linear-gradient(to left, ${theme.palette.primary.dark} 0%, ${theme.palette.primary.main} 100%)`,
		color: theme.palette.primary.contrastText
	},
	badge: {
		backgroundColor: theme.palette.error.main,
		color: theme.palette.getContrastText(theme.palette.error.main)
	},
	price: {
		backgroundColor: theme.palette.primary[600],
		color: theme.palette.getContrastText(theme.palette.primary[600])
	},
	heading: {
		fontSize: theme.typography.pxToRem(15),
		flexBasis: '33.33%',
		flexShrink: 0,
	},
	secondaryHeading: {
		fontSize: theme.typography.pxToRem(15),
		color: theme.palette.text.secondary,
	},
	imgtop: { marginTop: "-90px !important" } ,
	table: {
		minWidth: 650,
	  },
}));

const rows = [];


const UploadDoc = () => {

	const { register, handleSubmit, control, errors } = useForm({
		defaultValues: {
			text: "",
			groups: [],
			contacts: "",
			sendNumber: "",
			sendDate: null,
			removeDuplicates: false,
			doNotSendToSpecialList: false,
		},
		resolver: yupResolver(validationSchema),
	});

	const handleSendMessage = (data) => console.log({ data });
	const preventDefault = (event) => event.preventDefault();


	const classes = useStyles();
	const { data, isLoading } = usePackageView();

	const formatter = new Intl.NumberFormat('fa-IR', {
		style: 'currency',
		currency: 'IRR',
		minimumFractionDigits: 0
	});

	const [expanded, setExpanded] = react.useState(false);

	const handleChange = (panel) => (event, isExpanded) => {
		setExpanded(isExpanded ? panel : false);
	};

	if (isLoading) {
		return <Spinner />;
	}
	return (
		<div className="flex flex-wrap w-full ">
			<form onSubmit={handleSubmit(handleSendMessage)} className="flex flex-wrap w-full pt-56">


				<Accordion expanded={true} onChange={handleChange('panel1')} className={clsx(classes.root, "rounded")}>
					<AccordionSummary
						expandIcon={<ExpandMoreIcon />}
						aria-controls="panel1bh-content"
						id="panel1bh-header"
					>
						<Icon color="action" className=" text-16 pt-3">  help_outline   </Icon>
						<Typography className={classes.heading}>
						
							آپلود مدارک شناسایی و فعال سازی پنل
							</Typography>
						<Typography className={classes.secondaryHeading}> </Typography>
					</AccordionSummary>
					<AccordionDetails className="flex flex-row ">
						<div className="flex flex-col justify-start w-3/5 ">
							<Typography >
								جهت فعالسازی پنل پیامک ابتدا می بایست مدارک شناسایی خواسته شده در زیر را اپلود کنید
							</Typography>
							<Typography className="mt-16" >
								دقت فرمایید که عکس سلفی می بایست مطابق تصویر نمونه و به همراه کارت ملی و متن زیر باشد
							</Typography>
						 
							<Link href="#" onClick={preventDefault} variant="body2">
								"جهت ثبت نام در سامانه پیامک + تاریخ و امضا"
							</Link>
							<Typography className="mt-16" >
								متن فوق باید با خوردکار نوسته شده باشد . بدیهی است در صورت عدم رعایت موارد خواسته شده مدرک شناسایی تایید نحواد شد و امکان ارسال پیامک نخواهید داشت.
							</Typography>
						</div>
						<div className={clsx("flex justify-end  w-2/5", classes.imgtop)}    >
							<img
								alt={"y"}
								className={clsx("min-w-20 w-full ")}
								src="/assets/images/sbsms/auth/uploadimg.png"
							/>
						</div>
					</AccordionDetails>
				</Accordion>
				<Accordion expanded={expanded === 'panel2'} onChange={handleChange('panel2')} className={clsx(classes.root, "rounded-t")}>
					<AccordionSummary
						expandIcon={<ExpandMoreIcon />}
						aria-controls="panel2bh-content"
						id="panel2bh-header"
					>
						<Typography className={classes.heading}>کیفیت تصویر مدارک</Typography>
						<Typography className={classes.secondaryHeading}>

						</Typography>
					</AccordionSummary>
					<AccordionDetails>
						<Typography>
							Donec placerat, lectus sed mattis semper, neque lectus feugiat lectus, varius pulvinar
							diam eros in elit. Pellentesque convallis laoreet laoreet.
						</Typography>
					</AccordionDetails>
				</Accordion>
				<Accordion expanded={expanded === 'panel3'} onChange={handleChange('panel3')} className={classes.root}>
					<AccordionSummary
						expandIcon={<ExpandMoreIcon />}
						aria-controls="panel3bh-content"
						id="panel3bh-header"
					>
						<Typography className={classes.heading}>  پسوند های قابل قبول</Typography>
						<Typography className={classes.secondaryHeading}>

						</Typography>
					</AccordionSummary>
					<AccordionDetails>
						<Typography>
							Nunc vitae orci ultricies, auctor nunc in, volutpat nisl. Integer sit amet egestas eros,
							vitae egestas augue. Duis vel est augue.
						</Typography>
					</AccordionDetails>
				</Accordion>
				<Accordion expanded={expanded === 'panel4'} onChange={handleChange('panel4')} className={clsx(classes.root, "rounded-b")}>
					<AccordionSummary
						expandIcon={<ExpandMoreIcon />}
						aria-controls="panel4bh-content"
						id="panel4bh-header"
					>
						<Typography className={classes.heading}>  احراز هویت</Typography>
					</AccordionSummary>
					<AccordionDetails>
						<Typography>
							Nunc vitae orci ultricies, auctor nunc in, volutpat nisl. Integer sit amet egestas eros,
							vitae egestas augue. Duis vel est augue.
						</Typography>
					</AccordionDetails>
				</Accordion>

				<div className="flex flex-row justify-start w-full pt-16 mb-16">
					<Controller
						name="groups"
						size="small" 
						control={control}
						className="  ml-16  pl-16 w-1/2"
						as={FuseChipSelect}
						options={groupsData}
						placeholder="نوع مدرک   "
						textFieldProps={{
							label: "  نوع مدرک",
							InputLabelProps: {
								shrink: true,
							},
							variant: "outlined",
						}}
					/>
					<Button
						type="button"
						size="small" 
						className="mx-8"
						color="primary"
						variant="contained"
					>
						انتخاب فایل
					</Button>
					<Button
						type="button"
						size="small" 
						className="mx-8"
						color="secondary"
						variant="contained"
					>
						ارسال فایل
					</Button>
				</div>



				<TableContainer component={Paper}>
      <Table className={classes.table} aria-label="simple table">
        <TableHead>
          <TableRow>
            <TableCell>نوع مدرک</TableCell>
            <TableCell align="center">تاریخ ارسال</TableCell>
            <TableCell align="center">کد پیگیری</TableCell>
            <TableCell align="center">فایل مدرک</TableCell>
            <TableCell align="center">وضعیت </TableCell>
			<TableCell align="center">توضیحات </TableCell>
			<TableCell align="center">ابزار </TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {rows.map((row) => (
            <TableRow key={row.name}>
              <TableCell component="th" scope="row">
                {row.name}
              </TableCell>
              <TableCell align="center">{row.calories}</TableCell>
              <TableCell align="center">{row.fat}</TableCell>
              <TableCell align="center">{row.carbs}</TableCell>
              <TableCell align="right">{row.protein}</TableCell>
              <TableCell align="center">{row.protein}</TableCell>
              <TableCell align="center">{row.protein}</TableCell>
            </TableRow>
          ))}
        </TableBody>
      </Table>
    </TableContainer>


				<div className="flex w-full mt-32 mb-8 justify-start ">
					<Button
						type="button"
						className="mx-8"
						color="secondary"
						variant="contained"
					>
						مرحله قبل
					</Button>
					<Button
						type="button"
						className="mx-8"
						color="primary"
						variant="contained"
					>
						ثبت و ادامه
					</Button>
				</div>
			</form>


		</div>
	);
};


export default UploadDoc;
