import axios from 'axios';
import { useQuery } from 'react-query';

export default function useOrderView({ postId, enabled = true }) {
  return useQuery(
    ['orders', postId],
    (_, postId) =>  
      axios
        .get(`/api/order-app/order?`, { params: { postId } })
        .then((res) => {
          const data = res.data;
          const {
            master,
            cluster,
            tags = [],
            courselevel = null,
            properties = [],
          } = data;

          const { ClusterId } = cluster || {};
          const { masterId } = master || {};

          data.cluster = ClusterId ? { ...cluster, id: ClusterId } : null;

          if (!masterId) {
            data.master = null;
          }

          data.courselevel = courselevel
            ? { id: courselevel, name: courselevel }
            : null;

          data.tags = tags.map((tag) => ({ value: tag, label: tag }));

          data.properties = properties.map(
            ({
              PropertyId,
              PropertyName,
              PropertyLabelId,
              PropertyLabelName,
              ...propertyObject
            }) => {
              const propertyLabel = {
                id: PropertyLabelId,
                title: PropertyLabelName,
              };

              const property = {
                id: PropertyId,
                title: PropertyName,
              };
              return { ...propertyObject, property, propertyLabel };
            }
          );

          return data;
        }),
    {
      enabled,
      refetchOnWindowFocus: false,
      refetchOnReconnect: false,
    }
  );
}
