import { useEffect, useMemo, useState } from 'react';
import qs from 'qs';
import Fab from '@material-ui/core/Fab';
import Icon from '@material-ui/core/Icon';
import Spinner from 'app/components/Spinner';
import ContactsHeader from './AllContactsHeader';
import useContacts from '../../hooks/useContacts';
import useDeleteContacts from '../../hooks/useDeleteContacts';

import { useTranslation } from 'react-i18next';
import DataTable from 'app/components/DataTable';
import { makeStyles } from '@material-ui/core/styles';
import IconButton from '@material-ui/core/IconButton';
import FusePageCarded from '@fuse/core/FusePageCarded';
import UploadIcon from '@material-ui/icons/CloudUpload';
import { useLocation, useHistory } from 'react-router-dom';
import useDataTable from 'app/components/DataTable/useDataTable';
import DataTableCheckbox from 'app/components/DataTable/DataTableCheckbox';
import FuseAnimate from '@fuse/core/FuseAnimate';
import Typography from '@material-ui/core/Typography';
import { Link } from 'react-router-dom';
import moment from 'moment';
import { ListAlt, GetApp, Cached, DoneAll } from "@material-ui/icons";

import { CircularProgressbar, buildStyles } from 'react-circular-progressbar';
import "react-circular-progressbar/dist/styles.css";
import ChangingProgressProvider from "./ChangingProgressProvider";

export const dateFormat = 'YYYY-MM-DD';

const useStyles = makeStyles((theme) => ({
  fab: {
    position: 'absolute',
    Bottom: 0,
    left: theme.spacing(1),

  },


}));

function AllContacts(postId, showDetails) {
  const classes = useStyles();
  const { t } = useTranslation('contacts');

  const history = useHistory();
  const { search: locationSearch } = useLocation();

  const urlParams = qs.parse(locationSearch, {
    ignoreQueryPrefix: true,
  });

  const [queryPerPage, setQueryPerPage] = useState(
    parseInt(urlParams.perPage) || 10
  );
  const [queryPage, setQueryPage] = useState(parseInt(urlParams.page) || 1);
  const [querySortBy, setQuerySortBy] = useState(urlParams.sortBy);
  const [querySortDir, setQuerySortDir] = useState(urlParams.sortDir);
  const [querySearch, setQuerySearch] = useState(urlParams.search);

  const {
    isLoading,
    isFetching,
    resolvedData = { count: 0, products: [], pageCount: 0 },
  } = useContacts({
    postId: postId.postId,
    page: queryPage,
    search: querySearch,
    sortBy: querySortBy,
    perPage: queryPerPage,
    sortDir: querySortDir,
  });

  const [deleteContacts] = useDeleteContacts();

  const columns = useMemo(
    () => [
      {
        id: 'selection',
        header: ({
          selectedRows,
          isAllRowsSelected,
          isIndeterminateSelect,
          onToggleAllSelectedRow,
        }) => {
          const selectedRowIds = Object.keys(selectedRows);

          return (
            <div className="flex  ">
              <DataTableCheckbox
                className="mx-10"
                checked={isAllRowsSelected}
                indeterminate={isIndeterminateSelect}
                onChange={(e) => onToggleAllSelectedRow(e.target.checked)}
              />

              {selectedRowIds.length > 0 && (
                <div className="flex items-center justify-center h-54 mx-10">
                  <IconButton
                    onClick={(e) => {
                      e.stopPropagation();
                      deleteContacts(selectedRowIds).then(() => {
                        onToggleAllSelectedRow(false);
                      });
                    }}
                  >
                    <Icon color="error">delete</Icon>
                  </IconButton>
                </div>
              )}
            </div>
          );
        },
        accessor: ({ row, isSelected, handleToggleSelectedRow }) => (
          <div>
            <DataTableCheckbox
              className="mx-10"
              checked={isSelected}
              onChange={(e) =>
                handleToggleSelectedRow(row.id, e.target.checked)
              }
            />
          </div>
        ),
        headerClassName: 'w-48',
        disablePadding: true,
      },
      {
        header: t('TITLE'), accessor: 'title', sortable: true
      },
      { header: t('SENDERNAME'), accessor: 'sendNumber', sortable: true },
      {
        header: t('QUANTITY'), accessor: ({ row }) =>
          <Typography className="text-12 text-blue-500 ">
            {row.contacts.length}
          </Typography>, sortable: true
      },
      { header: t('SENDERNUMBER'), accessor: 'sendNumber', sortable: true },
      { header: t('DATETIME'), accessor: 'sendDate', sortable: true },
      {
        id: 'status',
        header: t('STATUS'),
        sortable: true,
        accessor: ({ row }) =>
          row.publish ? (
            <Typography className="text-12 sm:text-12 truncate">
              ارسال شده
            </Typography>
          ) : (
            <div style={{ width: 40, height: 40 }}>
              <ChangingProgressProvider values={[0, 5, 10, 12, 20, 30, 35, 40, 60, 70, 80]}>
                {percentage => (
                  <CircularProgressbar
                    strokeWidth={12}
                    value={percentage} text={`${percentage}%`}
                    styles={buildStyles({
                      pathTransitionDuration: 0.15,
                      rotation: 1,
                      textColor: "grey",
                      pathColor: "turquoise",
                      textSize: '32px',
                    })}
                  />
                )}
              </ChangingProgressProvider>
            </div>
          ),
      },
      {
        header: t('PRICE'), accessor: ({ row }) =>
          <Typography className="text-12 text-red-500 ">
            {row.price ? row.price : 0} ریال
          </Typography>, sortable: true
      },
      { header: t('PRICERETURN'), accessor: 'price_return', sortable: true },
      { header: t('TEXT'), accessor: ({ row }) => row.textmsg.substr(1, 8), headerClassName: 'w-48', sortable: true },
      {
        id: 'tools',
        header: t('TOOLS'),
        sortable: true,
        accessor: ({ row }) =>
          row.publish ? (
            <Icon className="text-green text-18">check_circle</Icon>
          ) : (<>
            <IconButton className="p-0" onClick={() => window.print()}>  <ListAlt />    </IconButton>
            <IconButton className="p-0" onClick={() => window.print()}>  <Cached />     </IconButton>
            <IconButton className="p-0" onClick={() => window.print()}>  <GetApp />     </IconButton>
            <IconButton className="p-0" onClick={() => window.print()}>  <DoneAll />    </IconButton>
          </>
          ),
      },
    ],
    [t, deleteContacts]
  );

  const {
    page,
    sortBy,
    search,
    perPage,
    sortDir,
    handleSearch,
    appliedFilters,
    ...tableInstance
  } = useDataTable({
    columns,
    initialPage: queryPage,
    initialSortBy: querySortBy,
    initialSearch: querySearch,
    data: resolvedData?.products,
    initialPerPage: queryPerPage,
    initialSortDir: querySortDir,
  });

  useEffect(() => {
    setQueryPage(page);
  }, [page]);

  useEffect(() => {
    setQueryPerPage(perPage);
  }, [perPage]);

  useEffect(() => {
    setQuerySearch(search);
  }, [search]);

  useEffect(() => {
    if (sortBy !== querySortBy) {
      setQuerySortBy(sortBy);
    }

    if (sortDir !== querySortDir) {
      setQuerySortDir(sortDir);
    }
  }, [sortBy, sortDir, querySortBy, querySortDir]);

  const handleNavigateToOrder = (row) => {
    history.push(`/apps/e-services/ordersview/${row.id}`);
  };

  return (
    <FusePageCarded

      classes={{
        content: 'flex   ',
        contentWrapper: 'p-0 m-0 br-0',
        contentCard: 'overflow-hidden rounded-none ',
        header: (showDetails ? 'min-h-0 max-h-136  h-auto bg-white' : "invisible min-h-0 h-0 sm:h-0 sm:min-h-0 bg-white"),
      }}
      header={<ContactsHeader onSearch={handleSearch} />}
      content={

        <>
          {isLoading && <Spinner />}
          <DataTable

            hover
            page={page}
            stickyHeader
            sortBy={sortBy}
            sortDir={sortDir}
            perPage={perPage}
            isLoading={isFetching}
            count={resolvedData?.count}
            onRowClick={handleNavigateToOrder}
            paginationClasses={{ toolbar: 'ltr:pr-52 rtl:pl-52' }}
            {...tableInstance}
          />
          {console.log(resolvedData)}
          <Fab
            color="primary"
            className={classes.fab}
            aria-label="upload excel file"
          >
            <UploadIcon />
          </Fab>
        </>
      }
      innerScroll
    />
  );
}

export default AllContacts;
