import { useState } from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import Icon from '@material-ui/core/Icon';
import { useSelector } from 'react-redux';
import Input from '@material-ui/core/Input';
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import { useTranslation } from 'react-i18next';
import FuseAnimate from '@fuse/core/FuseAnimate';
import Typography from '@material-ui/core/Typography';
import { ThemeProvider } from '@material-ui/core/styles';
import { selectMainTheme } from 'app/store/fuse/settingsSlice';

import DateTimePickerFilter from "app/components/FilterBox/DateTimePickerFilter";
import FilterBox from "app/components/FilterBox";
import InputLabel from "@material-ui/core/InputLabel";
import Select from "@material-ui/core/Select";
import TextField from '@material-ui/core/TextField';
import MenuItem from "@material-ui/core/MenuItem";
import { useForm, Controller } from 'react-hook-form';
import FormControl from "@material-ui/core/FormControl";
import OutlinedInput from "@material-ui/core/OutlinedInput";


function AllNormalMsgReportHeader({ onSearch, initialSearchValue }) {
  const { t } = useTranslation('reports');
  const [keyword, setKeyword] = useState(initialSearchValue || '');
  const mainTheme = useSelector(selectMainTheme);

  const {
    control,
  } = useForm({
  });

  const handleSearch = (e) => {
    e.preventDefault();
    onSearch(keyword);
  };

  return (
    <div className="flex flex-1 w-full items-center justify-between">   
      <div className="flex  flex-1 items-center justify-center justify-between ">
        <ThemeProvider theme={mainTheme}>
          <FuseAnimate animation="transition.slideDownIn" delay={300}>
            <Paper
              className="w-full    py-4 rounded-8"
              elevation={1}
            >
            {/* //  <form onSubmit={handleSearch} className="flex items-center"> */}
              <FilterBox   >
                    <FormControl
                      className="p-0 mt-8 m-0 w-1/4 "
                      variant="outlined"
                      margin="dense"
                    // error={!!errors?.sendNumber}
                    >
                      <InputLabel htmlFor="send-number-label-placeholder">
                        انتخاب فیلتر
                      </InputLabel>
                      <Select
                        // error={!!errors?.sendNumber}
                        input={
                          <Controller
                            name="sendNumber"
                            control={control}
                            as={OutlinedInput}
                            id="send-number-label-placeholder"
                            labelWidth={" انتخاب فیلتر".length * 6}
                          />
                        }
                      >
                        <MenuItem value="123456">
                          <em>فرستنده</em>
                        </MenuItem>
                        <MenuItem value="1587878">
                          <em>شماره ارسال</em>
                        </MenuItem>
                        <MenuItem value="9898565">
                          <em>متن پیام</em>
                        </MenuItem>
                        <MenuItem value="787878">
                          <em>عنوان</em>
                        </MenuItem>
                      </Select>
                      {/* {errors?.sendNumber && (
                    <FormHelperText>{errors?.sendNumber?.message}</FormHelperText>
                  )} */}
                    </FormControl>


                    <TextField label="جستجو" name="id" size="small"
                      defaultValue=" "
                     // onChange={(e) => setKeyword(e.target.value)}
                      className="px-4 mt-8 m-0  w-1/4 "
                      variant="outlined"
                    />
                    <DateTimePickerFilter name="fromDate" label="-انتخاب تاریخ-" className="px-4 mt-8 m-0  w-1/4 " />
                    <DateTimePickerFilter name="toDate" label="-انتخاب تاریخ-" className="px-4 mt-8 m-0  w-1/4 " />
                  </FilterBox>
              {/* </form> */}
            </Paper>
          </FuseAnimate>
        </ThemeProvider>
      </div> 
    </div>
  );
}

AllNormalMsgReportHeader.propTypes = {
  onSearch: PropTypes.func.isRequired,
  initialSearchValue: PropTypes.string,
};

export default AllNormalMsgReportHeader;
