import Icon from '@material-ui/core/Icon';
import Table from '@material-ui/core/Table';
import AppBar from '@material-ui/core/AppBar';
import Button from '@material-ui/core/Button';
import Dialog from '@material-ui/core/Dialog';
import { useTranslation } from 'react-i18next';
import Toolbar from '@material-ui/core/Toolbar';
import TableRow from '@material-ui/core/TableRow';
import Checkbox from '@material-ui/core/Checkbox';
import TextField from '@material-ui/core/TextField';
import FuseChipSelect from '@fuse/core/FuseChipSelect';
import { useForm, Controller } from 'react-hook-form';
import IconButton from '@material-ui/core/IconButton';
import Typography from '@material-ui/core/Typography';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogCloseButton from 'app/components/DialogCloseButton';

import useCreateContact from '../hooks/useCreateContact';
import useSaveContact from '../hooks/useSaveContact';
import useContactGroupList from '../hooks/useContactsGroupList';

function ContactFormDialog({
  isOpen,
  routes,
  onClose,
  onDelete,
  edit = false,
  selectedContact,
}) {
  const { register, handleSubmit, control } = useForm();
  const { t } = useTranslation('contacts');

  const { data: contactgrouplist = [] } = useContactGroupList();
 

  const [createContact] = useCreateContact();
  const [saveContact] = useSaveContact();

  const handleSubmitForm = ({ name, ...data }) => {
    if (edit) {       
      saveContact(selectedContact.id);
    } else {
      createContact().then(() => onClose());
    }
  };

  return (
    <Dialog
      fullWidth
      maxWidth="sm"
      minHeight="sm"
      open={isOpen}
      disableBackdropClick
      onClose={onClose}
      classes={{
        paper: 'm-24 rounded-8',
      }}
    >
      <AppBar position="static" elevation={1}>
        <Toolbar className="flex w-full">
          <Typography variant="subtitle1" color="inherit">
            {edit ? t('EDIT_CONTACTS') : t('ADD_CONTACTS')}
          </Typography>
        </Toolbar>
        <DialogCloseButton onClick={onClose} />
      </AppBar>
      <form
        noValidate
        onSubmit={handleSubmit(handleSubmitForm)}
        className="flex flex-col md:overflow-hidden"
      >
        <DialogContent classes={{ root: 'p-24' }}>
        <Controller
          isClearable
          name="title"
          control={control}
          as={FuseChipSelect}
          isSearchable={true}
          options={contactgrouplist}
          placeholder="Contacts Group"
          className="md:w-1/2 px-3 mt-8"
          getOptionValue={(option) => option.id}
          getOptionLabel={(option) => option.title}
          textFieldProps={{
            variant: 'outlined',
            label: t('CONTACTSGROUP'),
            InputLabelProps: { shrink: true },
          }}
        />

          <div className="flex flex-col">
            <TextField
              required
              autoFocus
              name="name"
              size="small"
              label={t('CONTACTS')}
              variant="outlined"
              inputRef={register}
              className="mt-8 mb-16 mx-4"
              defaultValue={edit ? selectedContact.role : ''}
            />

            
          </div>
        </DialogContent>

        {!edit ? (
          <DialogActions className="justify-between p-8">
            <div className="px-16">
              <Button
                variant="contained"
                color="primary"
                type="submit"
                // disabled={!canBeSubmitted()}
              >
                {t('ADD')}
              </Button>
            </div>
          </DialogActions>
        ) : (
          <DialogActions className="justify-between p-8">
            <div className="px-16">
              <Button
                variant="contained"
                color="primary"
                type="submit"
                // disabled={!canBeSubmitted()}
              >
                {t('EDIT')}
              </Button>
            </div>
            <IconButton
              onClick={() => {
                onDelete(selectedContact?.id);
                onClose();
              }}
            >
              <Icon color="error">delete</Icon>
            </IconButton>
          </DialogActions>
        )}
      </form>
    </Dialog>
  );
}

export default ContactFormDialog;
