import { useEffect, useMemo, useState } from 'react';
import qs from 'qs';
import Fab from '@material-ui/core/Fab';
import Icon from '@material-ui/core/Icon';
import Spinner from 'app/components/Spinner';
import ContactsGroupHeader from './AllContactsGroupHeader';
import { useTranslation } from 'react-i18next';
import DataTable from 'app/components/DataTable';

import useContactsGroup from '../../hooks/useContactsGroup';
import useDeleteContactsGroup from '../../hooks/useDeleteContactsGroup';


import { makeStyles } from '@material-ui/core/styles';
import IconButton from '@material-ui/core/IconButton';
import FusePageCarded from '@fuse/core/FusePageCarded';
import UploadIcon from '@material-ui/icons/CloudUpload';
import { useLocation, useHistory } from 'react-router-dom';
import useDataTable from 'app/components/DataTable/useDataTable';
import DataTableCheckbox from 'app/components/DataTable/DataTableCheckbox'; 
import { ListAlt, GetApp, Cached, DoneAll } from "@material-ui/icons";
import { CircularProgressbar, buildStyles } from 'react-circular-progressbar';
import "react-circular-progressbar/dist/styles.css";
import ChangingProgressProvider from "./ChangingProgressProvider";
import ContactFormDialog from '../ContactFormDialog'; 
export const dateFormat = 'YYYY-MM-DD';


const useStyles = makeStyles((theme) => ({
  fab: {
    position: 'absolute',
    Bottom: 0,
    left: theme.spacing(1),
  },
}));

function AllContactsGroup(postId, showDetails) {
  const classes = useStyles();
  const { t } = useTranslation('contacts');
  const history = useHistory();
  const { search: locationSearch } = useLocation();

  const [isDialogOpen, setIsDialogOpen] = useState(false);
  const [isEditDialog, setIsEditDialog] = useState(false);
  const [selectedRole, setSelectedRole] = useState(null);

  const urlParams = qs.parse(locationSearch, {
    ignoreQueryPrefix: true,
  });

  const [queryPerPage, setQueryPerPage] = useState(
    parseInt(urlParams.perPage) || 10
  );
  const [queryPage, setQueryPage] = useState(parseInt(urlParams.page) || 1);
  const [querySortBy, setQuerySortBy] = useState(urlParams.sortBy);
  const [querySortDir, setQuerySortDir] = useState(urlParams.sortDir);
  const [querySearch, setQuerySearch] = useState(urlParams.search);

   
  const {
    isLoading,
    isFetching,
    resolvedData = { count: 0, contactgroup: [], pageCount: 0 },
  } = useContactsGroup({
    postId: postId.postId,
    page: queryPage,
    search: querySearch,
    sortBy: querySortBy,
    perPage: queryPerPage,
    sortDir: querySortDir,
  });

  const [deleteContactsGroup] = useDeleteContactsGroup();

  const columns = useMemo(
    () => [
      {
        id: 'selection',
        header: ({
          selectedRows,
          isAllRowsSelected,
          isIndeterminateSelect,
          onToggleAllSelectedRow, 
        }) => {
          const selectedRowIds = Object.keys(selectedRows);

          return (
            <div className="flex  ">
              <DataTableCheckbox
                className="mx-10"
                checked={isAllRowsSelected}
                indeterminate={isIndeterminateSelect}
                onChange={(e) => onToggleAllSelectedRow(e.target.checked)}
              />

              {selectedRowIds.length > 0 && (
                <div className="flex items-center justify-center h-54 mx-10">
                  <IconButton
                    onClick={(e) => {
                      e.stopPropagation();
                      deleteContactsGroup(selectedRowIds).then(() => {
                        onToggleAllSelectedRow(false);
                      });
                    }}
                  >
                    <Icon color="error">delete</Icon>
                  </IconButton>
                </div>
              )}
            </div>
          );
        },
        accessor: ({ row, isSelected, handleToggleSelectedRow }) => (
          <div>
            <DataTableCheckbox
              className="mx-10"
              checked={isSelected}
              onChange={(e) =>
                handleToggleSelectedRow(row.id, e.target.checked)
              }
            />
          </div>
        ),
        headerClassName: 'w-48',
        disablePadding: true,
      },
      {
        header: t('TITLE'), accessor: 'title', sortable: true
      },
      { header: t('DESCRIPTION'), accessor: 'description', sortable: true },
      {
        id: 'status',
        header: t('STATUS'),
        sortable: true,
        accessor: ({ row }) =>
          row.publish ? (
            <Icon className="text-green text-18">check_circle</Icon>
          ) : (
            <Icon className="text-red text-18">unpublished</Icon>
          ),
      },
      { header: t('COUNT'), accessor: 'memberCount', sortable: true },
      {
        id: 'tools',
        header: t('TOOLS'),
        sortable: true,
        accessor: ({ row }) =>
          row.publish ? (
            <Icon className="text-green text-18">check_circle</Icon>
          ) : (<>
            <IconButton className="p-0" onClick={() => window.print()}>  <ListAlt />    </IconButton>
            <IconButton className="p-0" onClick={() => window.print()}>  <Cached />     </IconButton>
            <IconButton className="p-0" onClick={() => window.print()}>  <GetApp />     </IconButton>
            <IconButton className="p-0" onClick={() => window.print()}>  <DoneAll />    </IconButton>
          </>
          ),
      },
    ],
    [t, deleteContactsGroup]
  );

  const {
    page,
    sortBy,
    search,
    perPage,
    sortDir,
    handleSearch,
    appliedFilters,
    ...tableInstance
  } = useDataTable({
    columns,
    initialPage: queryPage,
    initialSortBy: querySortBy,
    initialSearch: querySearch,
    data: resolvedData?.contactgroup,
    initialPerPage: queryPerPage,
    initialSortDir: querySortDir,
  });

  useEffect(() => {
    setQueryPage(page);
  }, [page]);

  useEffect(() => {
    setQueryPerPage(perPage);
  }, [perPage]);

  useEffect(() => {
    setQuerySearch(search);
  }, [search]);

  useEffect(() => {
    if (sortBy !== querySortBy) {
      setQuerySortBy(sortBy);
    }

    if (sortDir !== querySortDir) {
      setQuerySortDir(sortDir);
    }
  }, [sortBy, sortDir, querySortBy, querySortDir]);

  const handleOpenAddDialog = () => {
    setIsDialogOpen(true);
    setIsEditDialog(false);
  };

  const handleOpenEditDialog = (role) => {
    setIsDialogOpen(true);
    setIsEditDialog(true);
    setSelectedRole(role);
  };

  const handleCloseDialog = () => {
    setIsDialogOpen(false);
    setIsEditDialog(false);
    setSelectedRole(null);
  };

  return (
    <FusePageCarded

      classes={{
        content: 'flex   ',
        contentWrapper: 'p-0 m-0 br-0',
        contentCard: 'overflow-hidden rounded-none ',
        header: (showDetails ? 'min-h-0 max-h-136  h-auto bg-white' : "invisible min-h-0 h-0 sm:h-0 sm:min-h-0 bg-white"),
      }}
      header={<ContactsGroupHeader 
        onSearch={handleSearch}  
        onOpenAddDialog={handleOpenAddDialog} />}
      content={

        <>
          {isLoading && <Spinner />}
          <DataTable

            hover
            page={page}
            stickyHeader
            sortBy={sortBy}
            sortDir={sortDir}
            perPage={perPage}
            isLoading={isFetching}
            count={resolvedData?.count}
            
            paginationClasses={{ toolbar: 'ltr:pr-52 rtl:pl-52' }}
            {...tableInstance}
          />
          {console.log(resolvedData)}
          <Fab
            color="primary"
            className={classes.fab}
            aria-label="upload excel file"
          >
            <UploadIcon />
          </Fab>
          {isDialogOpen  && (
            <ContactFormDialog
              // routes={routes}
              edit={isEditDialog}
              isOpen={isDialogOpen}
             // onDelete={deleteRole}
              onClose={handleCloseDialog}
             /// selectedRole={selectedRole}
            />
          )}

        </>
      }
      innerScroll
    />
  );
}

export default AllContactsGroup;
