import { useState } from 'react';
// import PropTypes from "prop-types";
import { Line } from 'react-chartjs-2';
import Card from '@material-ui/core/Card';
import Button from '@material-ui/core/Button';
import Typography from '@material-ui/core/Typography';
import CardContent from '@material-ui/core/CardContent';

const AllMessagesChart = (props) => {
  const [datasetType, setDatasetType] = useState('monthly');

  const data = {
    yearly: [
      {
        label: 'home service',
        data: [190, 300, 340, 220, 2900, 390, 250, 3800],
        fill: 'start',
      },
      {
        label: 'food ',
        data: [2200, 2900, 3900, 2500, 3800, 3200, 2900, 1900],
        fill: 'start',
      },
      {
        label: 'car wash',
        data: [2300, 2950, 4900, 2100, 3970, 3400, 2200, 2900],
        fill: 'start',
      },
    ],
    monthly: [
      {
         label: 'home service',
        data: [4100, 380, 800, 290, 190, 3900, 250, 380],
        fill: 'start',
      },
      {
       label: 'food ',
        data: [3000, 3400, 4100, 3800, 2200, 3200, 2900, 1900],
        fill: 'start',
      },
      {
         label: 'car wash',
        data: [2200, 4900, 3900, 2500, 3800, 5200, 2900, 1900],
        fill: 'start',
      },
    ],
  };

  const palette = [
    { backgroundColor: '#4F4789' },
    { backgroundColor: '#F97068' },
    { backgroundColor: '#D1D646' },
  ];

  const dataWithColors = data[datasetType].map((item, index) => {
    return { ...item, ...palette[index] };
  });

  return (
    <Card className="w-full rounded-4 shadow-1">
      <div className="relative p-24 flex flex-row items-center justify-between">
        <div className="flex flex-col">
          <Typography className="h3 sm:h2">
       order and service  chart 
          </Typography>
        </div>

        <div className="flex flex-row items-center">
          <Button
            size="small"
            className="py-0 px-12"
            disabled={datasetType === 'monthly'}
            onClick={() => setDatasetType('monthly')}
          >
          monthly
          </Button>
          <Button
            size="small"
            className="py-0 px-12"
            disabled={datasetType === 'yearly'}
            onClick={() => setDatasetType('yearly')}
          >
         yearly
          </Button>
        </div>
      </div>
      <CardContent>
        <Line
          data={{
            labels: [
              '2019-02',
              '2019-04',
              '2019-06',
              '2019-08',
              '2019-10',
              '2019-12',
              '2020-02',
              '2020-03',
            ],
            datasets: dataWithColors,
          }}
          options={{
            cutoutPercentage: 66,
            spanGaps: false,
            legend: {
              display: true,
              position: 'bottom',
              rtl: true,
              labels: {
                padding: 20,
                fontFamily:
                  'IRANSans, Roboto, Helvetica Neue, Arial, sans-serif',
              },
            },
            scales: {
              xAxes: [
                {
                  barPercentage: 0.4,
                },
              ],
              yAxes: [
                {
                  ticks: {
                    suggestedMin: 0,
                    suggestedMax: 100,
                  },
                },
              ],
            },
            tooltips: {
              titleFontFamily:
                'IRANSans, Roboto, Helvetica Neue, Arial, sans-serif',
              bodyFontFamily:
                'IRANSans, Roboto, Helvetica Neue, Arial, sans-serif',
            },
            maintainAspectRatio: false,
          }}
          height={300}
        />
      </CardContent>
    </Card>
  );
};

AllMessagesChart.propTypes = {};

export default AllMessagesChart;
