import { useState } from 'react';
import PropTypes from 'prop-types';
import Editor from 'app/components/Editor';
import { Controller } from 'react-hook-form';
import Switch from '@material-ui/core/Switch';
import CategoryDialog from './CategoryDialog';
import TextField from '@material-ui/core/TextField';
 import FuseChipSelect from '@fuse/core/FuseChipSelect';
 
import FormControlLabel from '@material-ui/core/FormControlLabel';

const display_type = [
  { id: '1',  name: 'SliderMain' },
  { id: '2',  name: 'CategorySlider' },
  { id: '3',  name: 'ProductCollection' }, 
  { id: '4',  name: 'ProductCollectionByCategory' },   
  { id: '5',  name: 'Daily' },      
  { id: '6',  name: 'WowCollection' },     
  { id: '7',  name: 'DiccountTimerCollection' },   
  { id: '8',  name: 'Category2item' },     
  { id: '9',  name: 'Category3item' },     
  { id: '10', name: 'Category1item' },     
  { id: '11', name: 'Category4item' },     
  { id: '12', name: 'CategoryTableView' },     
  { id: '13', name: 'CollectionSlider' },     
  { id: '14', name: 'Baner' },   
  { id: '15', name: 'Brands' },   
];
const display_page = [
  { id: '1',  name: 'AllPages' },
  { id: '2',  name: 'MainPage' }, 
  { id: '3',  name: 'Product' }, 
  { id: '4',  name: 'Products' }, 
  { id: '5',  name: 'CustomPagesApi' }, 
];
const PostBasicInfo = ({
  t,
  theme,
  errors,
  control,
  register,
  setValue,
  getValues,
}) => {
  const [isCategoryDialogOpen, setIsCategoryDialogOpen] = useState(false);
  
  const appName = 'nandwsouk';
  const setNameValue = () => {
    let {
      name = 0,  title = 0,
    } = getValues(['title_name' , 'title' ]);
     name=title.split(' ').join('_') ; 
    return name;
  };
 

  return (
    <div>
      <div className="-mx-3 flex flex-wrap  ">
        <Controller
          control={control}   
            name="title_name"       
          render={({ onChange, onBlur, value }) => (
            <TextField
              fullWidth
              type="text"
              value={value}
              onBlur={onBlur}
              variant="outlined"
              inputRef={register}
              error={!!errors?.title}
              helperText={errors?.title?.message}
              onChange={(e) => {
                onChange(e);
                setValue('name', setNameValue(), {
                  shouldDirty: true,
                });
              }}
              name="title"
              label={t('TITLE')}
              className="md:w-1/3 px-3 mt-8 mb-24 md:mb-0"
                       
            />
          )}
        />
     
        <TextField
          fullWidth
          type="text"
          name="name"
          label={t('NAME')}
          variant="outlined"
          inputRef={register}
          className="md:w-1/3 px-3 mt-8"
        />
           <FormControlLabel
        label={t('PUBLISH')}
        className="mt-8 mb-24"
        control={
          <Controller
            name="publish"
            control={control}
            render={(props) => (
              <Switch
                checked={props.value}
                onChange={(e) => props.onChange(e.target.checked)}
              />
            )}
          />
        }
      />
      </div>

    <div className="-mx-3 flex flex-wrap  ">
      <Controller
          isClearable
          control={control}
          name="display_type"
          as={FuseChipSelect}
          placeholder="Level"
          isSearchable={false}
          options={display_type}
          className="w-1/2 mt-8   mr-8 mb-8"
          getOptionValue={(option) => option.id}
          getOptionLabel={(option) => option.name}
          textFieldProps={{
            variant: 'outlined',
            label: t('DISPLY_TYPE'),
            InputLabelProps: { shrink: true },
          }}
        />
        <Controller
          isClearable
          control={control}
          name="display_page"
          as={FuseChipSelect}
          placeholder="Level"
          isSearchable={false}
          options={display_page}
          className="w-1/3 mt-8   mr-8   mb-8"
          getOptionValue={(option) => option.id}
          getOptionLabel={(option) => option.name}
          textFieldProps={{
            variant: 'outlined',
            label: t('DISPLAY_PAGE'),
            InputLabelProps: { shrink: true },
          }}
        />
  </div>

      <TextField
        rows="2"
        multiline
        fullWidth
        name="info"
        label={t('INFO')}
        variant="outlined"
        inputRef={register}
        className="mt-8 mb-24"
      />

     
       <TextField
          fullWidth
          type="text"
          name="link"
          label={t('LINK')}
          variant="outlined"
          inputRef={register}
          className="  px-3 mt-8"
        />

 
   

      <CategoryDialog
        t={t}
        isOpen={isCategoryDialogOpen}
       
      />
    </div>
  );
};

PostBasicInfo.propTypes = {
  t: PropTypes.func.isRequired,
  theme: PropTypes.object.isRequired,
  register: PropTypes.func.isRequired,
  errors: PropTypes.object.isRequired,
  setValue: PropTypes.func.isRequired,
  control: PropTypes.object.isRequired,
  getValues: PropTypes.func.isRequired,
};

export default PostBasicInfo;
