import { useState } from 'react';
import PropTypes from 'prop-types'; 
import { Controller } from 'react-hook-form';
import Switch from '@material-ui/core/Switch';
import CategoryDialog from './CategoryDialog';
import TextField from '@material-ui/core/TextField'; 
import FuseChipSelect from '@fuse/core/FuseChipSelect'; 
import FormControlLabel from '@material-ui/core/FormControlLabel';

const display_type = [
  { id: '1',  name: 'SquareBox' },
  { id: '2',  name: 'RectangleBox' },  
];

const PostBasicInfo = ({
  t,
  theme,
  errors,
  control,
  register,
  setValue,
  getValues,
}) => {
  const [isCategoryDialogOpen, setIsCategoryDialogOpen] = useState(false);

 
  const appName = 'nandwsouk';

  const handleOpenCategoryDialog = () => {
    setIsCategoryDialogOpen(true);
  };

  const handleCloseCategoryDialog = () => {
    setIsCategoryDialogOpen(false);
  };

  const handleSelectCategory = (selectedCategory) => {
    const categories = getValues('categoriesObject');

    const idName = selectedCategory.id ? 'id' : 'categoryLabelId';

    const isAlreadySelected = categories.find(
      (category) => category[idName] === selectedCategory[idName]
    );
    if (!isAlreadySelected) {
      setValue('categoriesObject', [...categories, selectedCategory], {
        shouldDirty: true,
      });
    }
  };

  return (
    <div>
      <div className="-mx-3 flex flex-wrap mb-8">
        <TextField
          required
          autoFocus 
          name="name"
          label={t('NAME')}
          variant="outlined"
          inputRef={register}
          error={!!errors?.name}
          helperText={errors?.name?.message}
          className="w-4/5  px-3 mt-8 mb-8 md:mb-0"
        />
     <FormControlLabel
        label={t('PUBLISH')}
        className=" mt-8 mb-8"
        control={
          <Controller
            name="publish"
            control={control}
            render={(props) => (
              <Switch
                checked={props.value}
                onChange={(e) => props.onChange(e.target.checked)}
              />
            )}
          />
        }
      />
      </div>

      <div className="-mx-3 flex flex-wrap mb-8">
      <Controller
          isClearable
          control={control}
          name="display_type"
          as={FuseChipSelect}
          placeholder="Level"
          isSearchable={false}
          options={display_type}
          className="w-1/4 mt-8   mr-8 mb-8"
          getOptionValue={(option) => option.id}
          getOptionLabel={(option) => option.name}
          textFieldProps={{
            variant: 'outlined',
            label: t('DISPLY_TYPE'),
            InputLabelProps: { shrink: true },
          }}
        />

      
 </div>
 <Controller
        isMulti
        options={[]}
        control={control}
        className="  mb-8"
        as={FuseChipSelect}
        isSearchable={false}
        name="categoriesObject"
        openMenuOnClick={false}
        onClick={handleOpenCategoryDialog}
        getOptionLabel={(option) => option.value}
        placeholder={t('SELECT_MULTIPLE_CATEGORIES')}
        getOptionValue={(option) =>
          option.id ? option.id : option.categoryLabelId
        }
        textFieldProps={{
          variant: 'outlined',
          label: t('CATEGORIES'),
          InputLabelProps: { shrink: true },
          onClick: handleOpenCategoryDialog,
        }}
      />

      <TextField
        rows="2"
        multiline
        fullWidth
        name="info"
        label={t('INFO')}
        variant="outlined"
        inputRef={register}
        className="mt-8 mb-24"
      />

<Controller
        isMulti
        isClearable
        name="tags"
        control={control}
        placeholder={t('SELECT_MULTIPLE_TAGS')}
        as={FuseChipSelect}
        className="mt-8 mb-24"
        textFieldProps={{
          label: t('TAGS'),
          variant: 'outlined',
          InputLabelProps: { shrink: true },
        }}
      />


      

      <CategoryDialog
        t={t}
        isOpen={isCategoryDialogOpen}
        onClose={handleCloseCategoryDialog}
        onSelectCategory={handleSelectCategory}
      />
    </div>
  );
};

PostBasicInfo.propTypes = {
  t: PropTypes.func.isRequired,
  theme: PropTypes.object.isRequired,
  register: PropTypes.func.isRequired,
  errors: PropTypes.object.isRequired,
  setValue: PropTypes.func.isRequired,
  control: PropTypes.object.isRequired,
  getValues: PropTypes.func.isRequired,
};

export default PostBasicInfo;
