import { useState } from 'react';
import PropTypes from 'prop-types';
import { Link } from 'react-router-dom';
import Icon from '@material-ui/core/Icon';
import { useSelector } from 'react-redux';
import Input from '@material-ui/core/Input';
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import { useTranslation } from 'react-i18next';
import FuseAnimate from '@fuse/core/FuseAnimate';
import Typography from '@material-ui/core/Typography';
import { ThemeProvider } from '@material-ui/core/styles';
import { selectMainTheme } from 'app/store/fuse/settingsSlice';

function PostListHeader({ onSearch, initialSearchValue }) {
  const { t } = useTranslation('cms_translate');
  const [keyword, setKeyword] = useState(initialSearchValue || '');
  const mainTheme = useSelector(selectMainTheme);

  const handleSearch = (e) => {
    e.preventDefault();
    onSearch(keyword);
  };

  return (
    <div className="flex p-16  w-full items-center justify-between">
      <div className="flex items-center">
        <FuseAnimate animation="transition.expandIn" delay={300}>
          <Icon className="text-32">shopping_basket</Icon>
        </FuseAnimate>
        <FuseAnimate animation="transition.slideLeftIn" delay={300}>
          <Typography className="hidden sm:flex mx-0 sm:mx-12" variant="h6">
            {t('BLOG_LIST')}
          </Typography>
        </FuseAnimate>
      </div>

      <div className="flex flex-1 items-center justify-center px-12">
        <ThemeProvider theme={mainTheme}>
          <FuseAnimate animation="transition.slideDownIn" delay={300}>
            <Paper
              className="w-full max-w-512 px-8 py-4 rounded-8"
              elevation={1}
            >
              <form onSubmit={handleSearch} className="flex items-center">
                <Icon color="action">search</Icon>
                <Input
                  fullWidth
                  value={keyword}
                  disableUnderline
                  className="flex flex-1 mx-8"
                  inputProps={{ 'aria-label': 'Search' }}
                  onChange={(e) => setKeyword(e.target.value)}
                  placeholder="Search" //TODO: Use general translation file for general words like search
                />
              </form>
            </Paper>
          </FuseAnimate>
        </ThemeProvider>
      </div>
      <FuseAnimate animation="transition.slideRightIn" delay={300}>
        <Button
          component={Link}
          color="secondary"
          variant="contained"
          to="/apps/e-cms/postlist/new"
          className="whitespace-no-wrap normal-case"
        >
          <span className="hidden sm:flex">{t('ADD_NEW_PRODUCT')}</span>
          {/* TODO: add 'new' to general transition file */}
          <span className="flex sm:hidden">New</span>
        </Button>
      </FuseAnimate>
    </div>
  );
}

PostListHeader.propTypes = {
  onSearch: PropTypes.func.isRequired,
  initialSearchValue: PropTypes.string,
};

export default PostListHeader;
