import PropTypes from 'prop-types';
import Icon from '@material-ui/core/Icon';
import List from '@material-ui/core/List';
import Button from '@material-ui/core/Button';
import FuseAnimate from '@fuse/core/FuseAnimate';
import ListItem from '@material-ui/core/ListItem';
import { makeStyles } from '@material-ui/core/styles';
import NavLinkAdapter from '@fuse/core/NavLinkAdapter';
import ListItemText from '@material-ui/core/ListItemText';
import ListSubheader from '@material-ui/core/ListSubheader';

const useStyles = makeStyles((theme) => ({
  listItem: {
    color: 'inherit!important',
    textDecoration: 'none!important',
    height: 40,
    width: 'calc(100% - 16px)',
    borderRadius: '0 20px 20px 0',
    paddingLeft: 24,
    paddingRight: 12,
    '&.active': {
      backgroundColor: theme.palette.secondary.main,
      color: `${theme.palette.secondary.contrastText}!important`,
      pointerEvents: 'none',
      '& .list-item-icon': {
        color: 'inherit',
      },
    },
    '& .list-item-icon': {
      fontSize: 16,
      width: 16,
      height: 16,
      marginRight: 16,
    },
  },
  listSubheader: {
    paddingLeft: 24,
  },
}));

function CategoryLabelsSidebarContent({ t, onOpenAddDialog }) {
  const folders = [
    {
      id: 0,
      handle: 'all',
      title: t('ALL'),
      icon: 'view_headline',
    },
  ];

  const filters = [
    {
      id: 0,
      handle: 'starred',
      title: t('STARRED'),
      icon: 'star',
    },
    {
      id: 1,
      handle: 'important',
      title: t('PRIORITY'),
      icon: 'error',
    },
    {
      id: 3,
      handle: 'disable',
      title: t('DISABLED'),
      icon: 'sync_disabled',
    },
  ];

  const classes = useStyles();

  return (
    <FuseAnimate animation="transition.slideUpIn" delay={400}>
      <div className="flex-auto border-l-1 border-solid">
        <div className="p-24">
          <Button
            color="primary"
            className="w-full"
            variant="contained"
            onClick={onOpenAddDialog}
          >
            {t('ADD_LABEL')}
          </Button>
        </div>

        <div className={classes.listWrapper}>
          <List>
            {folders.length > 0 &&
              folders.map((folder) => (
                <ListItem
                  button
                  key={folder.id}
                  activeClassName="active"
                  component={NavLinkAdapter}
                  className={classes.listItem}
                  to={`/apps/e-cms/category/labels/${folder.handle}`}
                >
                  <Icon className="list-item-icon" color="action">
                    {folder.icon}
                  </Icon>
                  <ListItemText primary={folder.title} disableTypography />
                </ListItem>
              ))}
          </List>

          <List>
            <ListSubheader className={classes.listSubheader} disableSticky>
              {t('FILTERS')}
            </ListSubheader>

            {filters.length > 0 &&
              filters.map((filter) => (
                <ListItem
                  button
                  key={filter.id}
                  activeClassName="active"
                  component={NavLinkAdapter}
                  className={classes.listItem}
                  to={`/apps/e-cms/category/labels/${filter.handle}`}
                >
                  <Icon className="list-item-icon" color="action">
                    {filter.icon}
                  </Icon>
                  <ListItemText primary={filter.title} disableTypography />
                </ListItem>
              ))}
          </List>
        </div>
      </div>
    </FuseAnimate>
  );
}

CategoryLabelsSidebarContent.propTypes = {
  t: PropTypes.func.isRequired,
  onOpenAddDialog: PropTypes.func.isRequired,
};

export default CategoryLabelsSidebarContent;
