import axios from 'axios';
import FuseUtils from '@fuse/utils';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { getCategoriesKey } from './useCategories';

const uploadImage = (filename = '', file, isEdit) => {
  var formData = new FormData();
  formData.append(filename, file);

  if (isEdit) {
    return axios
      .put('/api/cmsCategory-app/upload', formData)
      .then((res) => res.data);
  }

  return axios
    .post('/api/cmsCategory-app/upload', formData)
    .then((res) => res.data);
};

const saveCategory = ({ category, isEdit }) => {
  const { imageFile, iconFile, ...data } = category;

  const imagesToUpload = [];

  if (imageFile) {
    imagesToUpload.push({
      file: imageFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_background_',
    });
  }

  if (iconFile) {
    imagesToUpload.push({
      file: iconFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_icon_',
    });
  }

  if (!isEdit && !data.id) {
    data.id = FuseUtils.generateGUID();
  }

  return Promise.all(
    imagesToUpload.map((image) =>
      uploadImage(image.filename, image.file, isEdit)
    )
  ).then((uploadedImages) => {
    uploadedImages.forEach((uploadedImage) => {
      const fieldName = uploadedImage.id === 'icon' ? 'iconSrc' : 'imageSrc';
      data[fieldName] = uploadedImage.url;
    });

    if (isEdit) {
      return axios
        .put('/api/cmsCategory-app/update-category', data)
        .then(() => data);
    }

    return axios.post('/api/cmsCategory-app/new-category', data).then(() => data);
  });
};

export default function useSaveCategory() {
  return useMutation(saveCategory, {
    onMutate: ({
      isEdit,
      category,
      labelHandle,
      filterHandle,
      folderHandle,
    }) => {
      const categoriesKey = getCategoriesKey({
        labelHandle,
        filterHandle,
        folderHandle,
      });

      queryCache.cancelQueries('categories');
      const previousCategories = queryCache.getQueryData(categoriesKey);
      let newCategories;

      if (isEdit) {
        newCategories = previousCategories.map((item) =>
          item.id === category.id ? category : item
        );
      } else {
        newCategories = [category, ...previousCategories];
      }

      queryCache.setQueryData(categoriesKey, newCategories);

      return () => queryCache.setQueryData(categoriesKey, previousCategories);
    },
    onError: (err, variables, rollback) => rollback(),
    onSuccess: () => {
      queryCache.invalidateQueries('categories', { refetchInactive: true });
    },
  });
}
