import axios from 'axios';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { removeNodeAtPath } from 'react-sortable-tree';

export default function useDeleteTreeCategory() {
  return useMutation(
    (path) => {
      return axios.delete('/api/cmsTreeCategory-app/remove-category', {
        data: { path },
      });
    },
    {
      onMutate: (path) => {
        queryCache.cancelQueries('e-cms-app-treeCategories');

        const previousTreeData = queryCache.getQueryData(
          'e-cms-app-treeCategories'
        );

        queryCache.setQueryData(
          'e-cms-app-treeCategories',
          removeNodeAtPath({
            treeData: previousTreeData,
            path,
            getNodeKey: ({ treeIndex }) => treeIndex,
          })
        );

        return () =>
          queryCache.setQueryData('e-cms-app-treeCategories', previousTreeData);
      },
      onError: (err, variables, rollback) => rollback(),
      onSuccess: () => {
        queryCache.invalidateQueries('e-cms-app-treeCategories');
      },
    }
  );
}
