import axios from 'axios';
import FuseUtils from '@fuse/utils';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';

const uploadImage = (postId = '', image) => {
  var formData = new FormData();
  const fileName = 'p_' + postId + '_' + image.id + '_';
  formData.append(fileName, image.file);

  if (postId) {
    return axios.put('/api/e-cms-app/upload', formData).then((res) => res.data);
  }

  return axios.post('/api/e-cms-app/upload', formData).then((res) => res.data);
};

const savePost = ({ data, isEdit = false }) => {
  const { images,  properties, ...formData } = data;

  const oldImages = [];
  const imagesToUpload = images.filter((image) => {
    if (image.__isChanged__) {
      return true;
    }

    oldImages.push(image);

    return false;
  });

  return Promise.all(
    imagesToUpload.map((image) => uploadImage(formData.id, image))
  ).then((uploadedImages) => {
    formData.images = [...oldImages, ...uploadedImages];


   

    formData.categories = formData.categoriesObject.map(
      (category) => category.value
    );

    //Add extra fields
    formData.handle = '';

    if (!isEdit && !formData.id) {
      formData.id = FuseUtils.generateGUID();
    }

    if (isEdit) {
      return axios.put('/api/e-cms-app/post/save', formData);
    }

    return axios.post('/api/e-cms-app/post/create', formData);
  });
};

export default function useSavePost() {
  return useMutation(savePost, {
    onSuccess: (data, variables) => {
      console.log('onSuccess', data, variables);
      queryCache.invalidateQueries('e-cms-app-postlist');
    },
  });
}
