import axios from 'axios';
import FuseUtils from '@fuse/utils';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { changeNodeAtPath, addNodeUnderParent } from 'react-sortable-tree';

const uploadImage = (filename = '', file, isEdit) => {
  var formData = new FormData();
  formData.append(filename, file);

  if (isEdit) {
    return axios
      .put('/api/cmsTreeCategory-app/upload', formData)
      .then((res) => res.data);
  }

  return axios
    .post('/api/cmsTreeCategory-app/upload', formData)
    .then((res) => res.data);
};

const updateTreeCategory = ({ data, path, treeIndex, isEdit }) => {
  const { imageFile, iconFile, ...formData } = data;

  const imagesToUpload = [];

  if (imageFile) {
    imagesToUpload.push({
      file: imageFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_background_',
    });
  }

  if (iconFile) {
    imagesToUpload.push({
      file: iconFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_icon_',
    });
  }

  if (!isEdit && !formData.id) {
    formData.id = FuseUtils.generateGUID();
  }

  return Promise.all(
    imagesToUpload.map((image) =>
      uploadImage(image.filename, image.file, isEdit)
    )
  ).then((uploadedImages) => {
    uploadedImages.forEach((uploadedImage) => {
      const imageFieldName =
        uploadedImage.id === 'icon' ? 'iconSrc' : 'imageSrc';
      formData[imageFieldName] = uploadedImage.url;
    });

    if (isEdit) {
      return axios
        .put('/api/cmsTreeCategory-app/update-category', {
          category: formData,
          path,
        })
        .then(() => formData);
    }

    return axios
      .post('/api/cmsTreeCategory-app/new-category', {
        category: formData,
        treeIndex,
      })
      .then(() => formData);
  });
};

export default function useUpdateTreeCategory() {
  return useMutation(updateTreeCategory, {
    onMutate: ({ data, path, treeIndex, isEdit }) => {
      queryCache.cancelQueries('e-cms-app-treeCategories');

      const previousTreeData = queryCache.getQueryData(
        'e-cms-app-treeCategories'
      );

      let newTreeData = null;

      const getNodeKey = ({ treeIndex }) => treeIndex;
      if (isEdit) {
        newTreeData = changeNodeAtPath({
          treeData: previousTreeData,
          path,
          getNodeKey,
          newNode: data,
        });
      } else {
        newTreeData = addNodeUnderParent({
          treeData: previousTreeData,
          parentKey: path ? path[path.length - 1] : null,
          expandParent: true,
          getNodeKey,
          newNode: data,
        }).treeData;
      }

      queryCache.setQueryData('e-cms-app-treeCategories', newTreeData);

      return () =>
        queryCache.setQueryData('e-cms-app-treeCategories', previousTreeData);
    },
    onError: (err, newData, rollback) => rollback(),
    onSuccess: (data, variables) => {
      queryCache.invalidateQueries('e-cms-app-treeCategories');
    },
  });
}
