import PropTypes from 'prop-types';
import Icon from '@material-ui/core/Icon';
import List from '@material-ui/core/List';
import AddLabelMenu from './AddLabelMenu';
import FuseAnimate from '@fuse/core/FuseAnimate';
import ListItem from '@material-ui/core/ListItem';
import { makeStyles } from '@material-ui/core/styles';
import NavLinkAdapter from '@fuse/core/NavLinkAdapter';
import ListItemText from '@material-ui/core/ListItemText';
import ListSubheader from '@material-ui/core/ListSubheader';
import usePropertyFilters from '../hooks/usePropertyFilters';
import CircularProgress from '@material-ui/core/CircularProgress';

const useStyles = makeStyles((theme) => ({
  listItem: {
    color: 'inherit!important',
    textDecoration: 'none!important',
    height: 40,
    width: 'calc(100% - 16px)',
    borderRadius: '0 20px 20px 0',
    paddingLeft: 24,
    paddingRight: 12,
    '&.active': {
      backgroundColor: theme.palette.secondary.main,
      color: `${theme.palette.secondary.contrastText}!important`,
      pointerEvents: 'none',
      '& .list-item-icon': {
        color: 'inherit',
      },
    },
    '& .list-item-icon': {
      fontSize: 16,
      width: 16,
      height: 16,
      marginRight: 16,
    },
  },
  listSubheader: {
    paddingLeft: 24,
  },
}));

function PropertiesSidebarContent({ t, labels, isLabelsLoading }) {
  const folders = [
    {
      id: 0,
      handle: 'all',
      title: t('ALL'),
      icon: 'view_headline',
    },
  ];

  const {
    data: filters = [],
    isLoading: isFiltersLoading,
  } = usePropertyFilters();

  const classes = useStyles();

  return (
    <FuseAnimate animation="transition.slideUpIn" delay={400}>
      <div className="flex-auto border-l-1 border-solid">
        <div className="p-24">
          <AddLabelMenu t={t} />
        </div>

        <div className={classes.listWrapper}>
          <List>
            {folders.length > 0 &&
              folders.map((folder) => (
                <ListItem
                  button
                  key={folder.id}
                  activeClassName="active"
                  component={NavLinkAdapter}
                  className={classes.listItem}
                  to={`/apps/e-cms/properties/${folder.handle}`}
                >
                  <Icon className="list-item-icon" color="action">
                    {folder.icon}
                  </Icon>
                  <ListItemText primary={folder.title} disableTypography />
                </ListItem>
              ))}
          </List>

          <List>
            <ListSubheader className={classes.listSubheader} disableSticky>
              {t('FILTERS')}
            </ListSubheader>

            {isFiltersLoading && (
              <ListItem>
                <CircularProgress disableShrink size={20} color="secondary" />
              </ListItem>
            )}
            {filters.length > 0 &&
              filters.map((filter) => (
                <ListItem
                  button
                  key={filter.id}
                  activeClassName="active"
                  component={NavLinkAdapter}
                  className={classes.listItem}
                  to={`/apps/e-cms/properties/filter/${filter.handle}`}
                >
                  <Icon className="list-item-icon" color="action">
                    {filter.icon}
                  </Icon>
                  <ListItemText primary={filter.title} disableTypography />
                </ListItem>
              ))}
          </List>

          <List>
            <ListSubheader className={classes.listSubheader} disableSticky>
              {t('LABELS')}
            </ListSubheader>

            {isLabelsLoading && (
              <ListItem>
                <CircularProgress disableShrink size={20} color="secondary" />
              </ListItem>
            )}
            {labels.length > 0 &&
              labels.map((label) => (
                <ListItem
                  button
                  key={label.id}
                  component={NavLinkAdapter}
                  className={classes.listItem}
                  to={`/apps/e-cms/properties/label/${label.handle}`}
                >
                  <Icon
                    color="action"
                    className="list-item-icon"
                    style={{ color: label.color }}
                  >
                    label
                  </Icon>
                  <ListItemText primary={label.title} disableTypography />
                </ListItem>
              ))}
          </List>
        </div>
      </div>
    </FuseAnimate>
  );
}

PropertiesSidebarContent.propTypes = {
  t: PropTypes.func.isRequired,
  labels: PropTypes.array.isRequired,
  isLabelsLoading: PropTypes.bool.isRequired,
};

export default PropertiesSidebarContent;
