import PropTypes from 'prop-types';
import Icon from '@material-ui/core/Icon';
import { useSelector } from 'react-redux';
import Input from '@material-ui/core/Input';
import Paper from '@material-ui/core/Paper';
import Hidden from '@material-ui/core/Hidden';
import IconButton from '@material-ui/core/IconButton';
import { ThemeProvider } from '@material-ui/core/styles';
import { selectMainTheme } from 'app/store/fuse/settingsSlice';

function PropertyLabelsHeader({
  t,
  pageLayout,
  searchText,
  onSearchTextChange,
}) {
  const mainTheme = useSelector(selectMainTheme);

  return (
    <ThemeProvider theme={mainTheme}>
      <div className="flex flex-1 items-center">
        <Paper
          className="flex items-center w-full h-48 sm:h-56 p-16 ltr:pl-4 lg:ltr:pl-16 rtl:pr-4 lg:rtl:pr-16 rounded-8"
          elevation={1}
        >
          <Hidden lgUp>
            <IconButton
              onClick={(ev) => pageLayout.current.toggleLeftSidebar()}
              aria-label="open left sidebar"
            >
              <Icon>menu</Icon>
            </IconButton>
          </Hidden>

          <Icon color="action">search</Icon>

          <Input
            fullWidth
            disableUnderline
            className="px-16"
            value={searchText}
            placeholder={t('SEARCH')}
            inputProps={{ 'aria-label': t('SEARCH') }}
            onChange={(e) => onSearchTextChange(e.target.value)}
          />
        </Paper>
      </div>
    </ThemeProvider>
  );
}

PropertyLabelsHeader.propTypes = {
  t: PropTypes.func.isRequired,
  searchText: PropTypes.string.isRequired,
  pageLayout: PropTypes.object.isRequired,
  onSearchTextChange: PropTypes.func.isRequired,
};

export default PropertyLabelsHeader;
