import axios from 'axios';
import FuseUtils from '@fuse/utils';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';

const getLabelObject = (data) => ({
  id: '',
  color: '',
  handle: '',
  enable: false,
  starred: false,
  description: '',
  important: false,
  ...data,
});

const addLabel = (title) => {
  return axios.post('/api/cmsProperty-app/new-label', getLabelObject({ title }));
};

export default function useAddPropertyLabel() {
  return useMutation(addLabel, {
    onMutate: (title) => {
      queryCache.cancelQueries('propertyLabels');

      const previousLabels = queryCache.getQueryData('propertyLabels');

      queryCache.setQueryData('propertyLabels', [
        getLabelObject({ id: FuseUtils.generateGUID(), title }),
        ...previousLabels,
      ]);

      return () => queryCache.setQueryData('propertyLabels', previousLabels);
    },
    onError: (err, variables, rollback) => rollback(),
    onSuccess: () => {
      queryCache.invalidateQueries('propertyLabels');
    },
  });
}
