import axios from 'axios';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { getPropertiesKey } from './useProperties';

export default function useDeleteProperty() {
  return useMutation(
    ({ id }) => {
      return axios.delete('/api/cmsProperty-app/remove-property', {
        data: { propertyId: id },
      });
    },
    {
      onMutate: ({ id, labelHandle, filterHandle, folderHandle }) => {
        const propertiesKey = getPropertiesKey({
          labelHandle,
          filterHandle,
          folderHandle,
        });

        queryCache.cancelQueries('properties');

        const previousProperties = queryCache.getQueryData(propertiesKey);

        queryCache.setQueryData(
          propertiesKey,
          previousProperties.filter((property) => property.id !== id)
        );

        return () => queryCache.setQueryData(propertiesKey, previousProperties);
      },
      onError: (err, variables, rollback) => rollback(),
      onSuccess: () => {
        queryCache.invalidateQueries('properties');
      },
    }
  );
}
