import axios from 'axios';
import FuseUtils from '@fuse/utils';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';

const uploadImage = (filename = '', file, isEdit) => {
  var formData = new FormData();
  formData.append(filename, file);

  if (isEdit) {
    return axios
      .put('/api/cmsProperty-app/upload', formData)
      .then((res) => res.data);
  }

  return axios
    .post('/api/cmsProperty-app/upload', formData)
    .then((res) => res.data);
};

const savePropertyLabel = ({ propertyLabel, isEdit }) => {
  const { imageFile, iconFile, ...data } = propertyLabel;

  const imagesToUpload = [];

  if (imageFile) {
    imagesToUpload.push({
      file: imageFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_background_',
    });
  }

  if (iconFile) {
    imagesToUpload.push({
      file: iconFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_icon_',
    });
  }

  return Promise.all(
    imagesToUpload.map((image) =>
      uploadImage(image.filename, image.file, isEdit)
    )
  ).then((uploadedImages) => {
    uploadedImages.forEach((uploadedImage) => {
      const fieldName = uploadedImage.id === 'icon' ? 'iconSrc' : 'imageSrc';
      data[fieldName] = uploadedImage.url;
    });

    if (isEdit) {
      return axios
        .put('/api/cmsProperty-app/update-property-label', data)
        .then(() => data);
    }

    return axios.post('/api/cmsProperty-app/new-label', data).then(() => data);
  });
};

export default function useSavePropertyLabel() {
  return useMutation(savePropertyLabel, {
    onMutate: ({ isEdit, propertyLabel }) => {
      queryCache.cancelQueries('propertyLabels');

      const previousPropertyLabels = queryCache.getQueryData('propertyLabels');
      let newPropertyLabels;

      if (isEdit) {
        newPropertyLabels = previousPropertyLabels.map((item) =>
          item.id === propertyLabel.id ? propertyLabel : item
        );
      } else {
        newPropertyLabels = [propertyLabel, ...previousPropertyLabels];
      }

      queryCache.setQueryData('propertyLabels', newPropertyLabels);

      return () =>
        queryCache.setQueryData('propertyLabels', previousPropertyLabels);
    },
    onError: (err, variables, rollback) => rollback(),
    onSuccess: () => {
      queryCache.invalidateQueries('propertyLabels', { refetchInactive: true });
    },
  });
}
