import PropTypes from 'prop-types';
import Icon from '@material-ui/core/Icon';
import { useSelector } from 'react-redux';
import Input from '@material-ui/core/Input';
import Paper from '@material-ui/core/Paper';
import Hidden from '@material-ui/core/Hidden';
import Button from '@material-ui/core/Button';
import IconButton from '@material-ui/core/IconButton';
import { ThemeProvider } from '@material-ui/core/styles';
import { selectMainTheme } from 'app/store/fuse/settingsSlice';

function StatusHeader({
  t,
  pageLayout,
  searchText,
  onOpenAddDialog,
  onSearchTextChange,
}) {
  const mainTheme = useSelector(selectMainTheme);

  return (
    <ThemeProvider theme={mainTheme}>
      <div className="flex flex-1 w-full items-center justify-between">
        <div className="flex flex-1 items-center rtl:pl-12 ltr:pr-12">
          <Paper
            className="flex items-center w-full h-48 sm:h-56 p-16 ltr:pl-4 lg:ltr:pl-16 rtl:pr-4 lg:rtl:pr-16 rounded-8"
            elevation={1}
          >
            <Hidden lgUp>
              <IconButton
                onClick={(ev) => pageLayout.current.toggleLeftSidebar()}
                aria-label="open left sidebar"
              >
                <Icon>menu</Icon>
              </IconButton>
            </Hidden>

            <Icon color="action">search</Icon>

            <Input
              fullWidth
              disableUnderline
              className="px-16"
              value={searchText}
              placeholder={t('SEARCH')}
              inputProps={{ 'aria-label': t('SEARCH') }}
              onChange={(e) => onSearchTextChange(e.target.value)}
            />
          </Paper>
        </div>

        <Button
          color="secondary"
          variant="contained"
          onClick={onOpenAddDialog}
          className="whitespace-no-wrap normal-case"
        >
          <span className="hidden sm:flex">{t('ADD_NEW_CATEGORY')}</span>
          <span className="flex sm:hidden">{t('NEW')}</span>
        </Button>
      </div>
    </ThemeProvider>
  );
}

StatusHeader.propTypes = {
  t: PropTypes.func.isRequired,
  searchText: PropTypes.string.isRequired,
  pageLayout: PropTypes.object.isRequired,
  onOpenAddDialog: PropTypes.func.isRequired,
  onSearchTextChange: PropTypes.func.isRequired,
};

export default StatusHeader;
