import axios from 'axios';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { getStatusKey } from './useStatus';

export default function useDeleteCategory() {
  return useMutation(
    ({ id }) => {
      return axios.delete('/api/cmsStatus-app/remove-category', {
        data: { categoryId: id },
      });
    },
    {
      onMutate: ({ id, labelHandle, filterHandle, folderHandle }) => {
        const statusKey = getStatusKey({
          labelHandle,
          filterHandle,
          folderHandle,
        });

        queryCache.cancelQueries('status');

        const previousStatus = queryCache.getQueryData(statusKey);

        queryCache.setQueryData(
          statusKey,
          previousStatus.filter((category) => category.id !== id)
        );

        return () => queryCache.setQueryData(statusKey, previousStatus);
      },
      onError: (err, variables, rollback) => rollback(),
      onSuccess: () => {
        queryCache.invalidateQueries('status');
      },
    }
  );
}
