import { useState } from 'react';
import Icon from '@material-ui/core/Icon';
import Spinner from 'app/components/Spinner';
import Button from '@material-ui/core/Button';
import { useTranslation } from 'react-i18next';
import SortableTree from 'react-sortable-tree';
import { useTheme } from '@material-ui/core/styles';
import Typography from '@material-ui/core/Typography';
import IconButton from '@material-ui/core/IconButton';
import FusePageSimple from '@fuse/core/FusePageSimple';
import useTreeCategories from '../hooks/useTreeCategories';
import TreeCategoryFormDialog from './TreeCategoryFormDialog';
import useUpdateTreeCategory from '../hooks/useUpdateTreeCategory';
import useUpdateTreeCategories from '../hooks/useUpdateTreeCategories';
import 'react-sortable-tree/style.css';

const TreeCategory = () => {
  const [isDialogOpen, setIsDialogOpen] = useState(false);
  const [isEditDialog, setIsEditDialog] = useState(false);
  const [selectedCategory, setSelectedCategory] = useState(null);

  const { data: treeCategories = [], isLoading } = useTreeCategories();
  const [updateTreeCategories] = useUpdateTreeCategories();
  const [updateTreeCategory] = useUpdateTreeCategory();

  const { t } = useTranslation('products');

  const theme = useTheme();

  const handleChangeTree = (treeData) => {
    updateTreeCategories(treeData);
  };

  const handleOpenAddDialog = (selectedCategory) => {
    setSelectedCategory(selectedCategory);
    setIsDialogOpen(true);
    setIsEditDialog(false);
  };

  const handleOpenEditDialog = (selectedCategory) => {
    setSelectedCategory(selectedCategory);
    setIsEditDialog(true);
    setIsDialogOpen(true);
  };

  const handleCloseDialog = () => {
    setSelectedCategory(null);
    setIsDialogOpen(false);
    setIsEditDialog(false);
  };

  const handleSubmit = (data, path, treeIndex) => {
    return updateTreeCategory({ data, path, treeIndex, isEdit: isEditDialog });
  };

  return (
    <FusePageSimple
      classes={{
        contentWrapper: 'h-full',
        header: 'min-h-72 h-72 sm:h-136 sm:min-h-136',
        content: 'p-16 sm:p-24',
      }}
      header={
        <div className="flex flex-1 items-center justify-between p-4 sm:p-24">
          <Typography variant="h6" className="mx-12 hidden sm:flex">
            {t('TREE_CATEGORY')}
          </Typography>

          <Button
            color="secondary"
            variant="contained"
            className="whitespace-no-wrap normal-case"
            onClick={() => handleOpenAddDialog(null)}
          >
            <span className="hidden sm:flex">{t('ADD_NEW_CATEGORY')}</span>
            <span className="flex sm:hidden">{t('ADD')}</span>
          </Button>
        </div>
      }
      content={
        <div className="w-full h-full">
          {isLoading && <Spinner />}
          <SortableTree
            treeData={treeCategories}
            onChange={handleChangeTree}
            rowDirection={theme.direction}
            generateNodeProps={(treeInfo) => ({
              buttons: [
                <IconButton
                  size="small"
                  onClick={() => handleOpenAddDialog(treeInfo)}
                >
                  <Icon>add</Icon>
                </IconButton>,
                <IconButton
                  size="small"
                  onClick={() => handleOpenEditDialog(treeInfo)}
                >
                  <Icon>edit</Icon>
                </IconButton>,
              ],
            })}
          />

          {isDialogOpen && (
            <TreeCategoryFormDialog
              edit={isEditDialog}
              onSubmit={handleSubmit}
              onClose={handleCloseDialog}
              selectedCategory={selectedCategory}
            />
          )}
        </div>
      }
    />
  );
};

export default TreeCategory;
