import axios from 'axios';
import FuseUtils from '@fuse/utils';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';

const uploadImage = (productId = '', image) => {
  var formData = new FormData();
  const fileName = 'p_' + productId + '_' + image.id + '_';
  formData.append(fileName, image.file);

  if (productId) {
    return axios
      .put('/api/e-commerce-app/upload', formData)
      .then((res) => res.data);
  }

  return axios
    .post('/api/e-commerce-app/upload', formData)
    .then((res) => res.data);
};

const saveProduct = ({ data, isEdit = false }) => {
  const { images, master, cluster, properties, ...formData } = data;

  const oldImages = [];
  const imagesToUpload = images.filter((image) => {
    if (image.__isChanged__) {
      return true;
    }

    oldImages.push(image);

    return false;
  });

  return Promise.all(
    imagesToUpload.map((image) => uploadImage(formData.id, image))
  ).then((uploadedImages) => {
    formData.images = [...oldImages, ...uploadedImages];

    formData.masterId = master ? master.id : null;
    formData.clusterId = cluster ? cluster.id : null;

    formData.properties = properties.map(
      ({ property, propertyLabel, ...item }) => {
        return {
          ...item,
          PropertyId: property.id,
          PropertyName: property.title,
          PropertyLabelId: propertyLabel.id,
          PropertyLabelName: propertyLabel.title,
        };
      }
    );

    formData.categories = formData.categoriesObject.map(
      (category) => category.value
    );

    //Add extra fields
    formData.handle = '';

    if (!isEdit && !formData.id) {
      formData.id = FuseUtils.generateGUID();
    }

    if (isEdit) {
      return axios.put('/api/e-commerce-app/product/save', formData);
    }

    return axios.post('/api/e-commerce-app/product/create', formData);
  });
};

export default function useSaveProduct() {
  return useMutation(saveProduct, {
    onSuccess: (data, variables) => {
      console.log('onSuccess', data, variables);
      queryCache.invalidateQueries('products');
    },
  });
}
