import FuseAnimate from '@fuse/core/FuseAnimate';
import FusePageCarded from '@fuse/core/FusePageCarded';
import CancelIcon from '@material-ui/icons/Cancel';
import CheckCircleIcon from '@material-ui/icons/CheckCircle';
import Button from '@material-ui/core/Button';
import Icon from '@material-ui/core/Icon';
import { useTheme } from '@material-ui/core/styles';
import Tab from '@material-ui/core/Tab';
import Tabs from '@material-ui/core/Tabs';
import Tooltip from '@material-ui/core/Tooltip';
import Typography from '@material-ui/core/Typography';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import withReducer from 'app/store/withReducer';
import MapIcon from '@material-ui/icons/Map';
import RoomIcon from '@material-ui/icons/Room';
import React, { useEffect, useMemo, useState } from 'react';
import Googlemaps from '../Googlemap';
import { useDispatch, useSelector } from 'react-redux';
import { Link, useParams } from 'react-router-dom';
import { useDeepCompareEffect } from '@fuse/hooks';
import reducer from '../store';
import { resetOrder, getOrder } from '../store/orderSlice';
import OrderInvoice from './OrderInvoice';
import OrdersStatus from './OrdersStatus';
import DataTableCheckbox from 'app/components/DataTable/DataTableCheckbox';
import { useTranslation } from 'react-i18next';
import useDeleteOrderList from 'app/pages/e-laundry/Orders/hooks/useDeleteOrderList';
import {
  Accordion,
  AccordionDetails,
  AccordionSummary,
  Box,
  IconButton,
} from '@material-ui/core';
import useOrderView from 'app/pages/e-laundry/Orders/hooks/useOrderView';

function Marker(props) {
  return (
    <Tooltip title={props.text} placement="top">
      <Icon className="text-red">place</Icon>
    </Tooltip>
  );
}

function Order(props) {
  const dispatch = useDispatch();
  let { postId } = useParams();
  const isEdit = postId !== 'new';
  const { data, isLoading, remove } = useOrderView({
    postId,
    enabled: isEdit,
  });
  const order = useSelector(({ eCommerceApp }) => eCommerceApp.order);
  const theme = useTheme();

  const routeParams = useParams();
  const [tabValue, setTabValue] = useState(0);
  const [noOrder, setNoOrder] = useState(false);
  const [map, setMap] = useState('shipping');

  useDeepCompareEffect(() => {
    dispatch(getOrder(routeParams)).then((action) => {
      if (!action.payload) {
        setNoOrder(true);
      }
    });
  }, [dispatch, routeParams]);
  useEffect(() => {
    return () => {
      dispatch(resetOrder());
      setNoOrder(false);
    };
  }, [dispatch]);

  function handleChangeTab(event, value) {
    setTabValue(value);
  }
  const { t } = useTranslation('orders');
  const [deleteOrderList] = useDeleteOrderList();
  const columns = useMemo(
    () => [
      {
        id: 'selection',
        header: ({
          selectedRows,
          isAllRowsSelected,
          isIndeterminateSelect,
          onToggleAllSelectedRow,
        }) => {
          const selectedRowIds = Object.keys(selectedRows);

          return (
            <div className="flex">
              <DataTableCheckbox
                className="mx-10"
                checked={isAllRowsSelected}
                indeterminate={isIndeterminateSelect}
                onChange={(e) => onToggleAllSelectedRow(e.target.checked)}
              />

              {selectedRowIds.length > 0 && (
                <div className="flex items-center justify-center h-64 mx-10">
                  <IconButton
                    onClick={(e) => {
                      e.stopPropagation();
                      deleteOrderList(selectedRowIds).then(() => {
                        onToggleAllSelectedRow(false);
                      });
                    }}
                  >
                    <Icon color="error">delete</Icon>
                  </IconButton>
                </div>
              )}
            </div>
          );
        },
        accessor: ({ row, isSelected, handleToggleSelectedRow }) => (
          <div>
            <DataTableCheckbox
              className="mx-10"
              checked={isSelected}
              onChange={(e) =>
                handleToggleSelectedRow(row.id, e.target.checked)
              }
            />
          </div>
        ),
        headerClassName: 'w-136',
        disablePadding: true,
      },
      {
        header: t('CUSTOMER_NAME'),
        sortable: true,
        accessor: ({ row }) =>
          row.customer.firstName + ' ' + row.customer.lastName,
      },
      {
        header: t('payment_method'),
        accessor: ({ row }) => row.gateway.title,
        sortable: true,
      },
      { header: t('PRICE'), accessor: 'total', sortable: true },
      {
        header: t('STATUS'),
        sortable: true,
        accessor: ({ row }) =>
          row.status.length ? row.status[row.status.length - 1].name : '',
        id: 'status',
      },
      { header: t('DATE'), accessor: 'fdate', sortable: true },
      { header: t('DESCRIPTION'), accessor: 'description', sortable: true },
      {
        id: 'active',
        header: t('ACTIVE'),
        sortable: true,
        accessor: ({ row }) =>
          row.active ? (
            <Icon className="text-green text-20">check_circle</Icon>
          ) : (
            <Icon className="text-red text-20">remove_circle</Icon>
          ),
      },
    ],
    [t, deleteOrderList]
  );

  if (noOrder) {
    return (
      <FuseAnimate delay={100}>
        <div className="flex flex-col flex-1 items-center justify-center h-full">
          <Typography color="textSecondary" variant="h5">
            There is no such order!
          </Typography>
          <Button
            className="normal-case mt-24"
            component={Link}
            variant="outlined"
            to="/apps/e-commerce/orders"
            color="inherit"
          >
            Go to Orders Page
          </Button>
        </div>
      </FuseAnimate>
    );
  }

  return (
    <FusePageCarded
      classes={{
        content: 'flex',
        header: 'min-h-72 h-72 sm:h-136 sm:min-h-136',
      }}
      header={
        order && (
          <div className="flex flex-1 w-full items-center justify-between">
            <div className="flex flex-1 flex-col items-center sm:items-start">
              <FuseAnimate animation="transition.slideRightIn" delay={300}>
                <Typography
                  className="normal-case flex items-center sm:mb-12"
                  component={Link}
                  role="button"
                  to="/apps/e-commerce/orders"
                  color="inherit"
                >
                  <Icon className="text-20">
                    {theme.direction === 'ltr' ? 'arrow_back' : 'arrow_forward'}
                  </Icon>
                  <span className="mx-4">Orders</span>
                </Typography>
              </FuseAnimate>

              <div className="flex flex-col min-w-0 items-center sm:items-start">
                <FuseAnimate animation="transition.slideLeftIn" delay={300}>
                  <Typography className="text-16 sm:text-20 truncate">
                    {`Order ${order.reference}`}
                  </Typography>
                </FuseAnimate>

                <FuseAnimate animation="transition.slideLeftIn" delay={300}>
                  <Typography variant="caption">
                    {`From ${order?.customer?.firstName} ${order?.customer?.lastName}`}
                  </Typography>
                </FuseAnimate>
              </div>
            </div>
          </div>
        )
      }
      contentToolbar={
        <Tabs
          value={tabValue}
          onChange={handleChangeTab}
          indicatorColor="primary"
          textColor="primary"
          variant="scrollable"
          scrollButtons="auto"
          classes={{ root: 'w-full h-64' }}
        >
          <Tab className="h-64 normal-case" label="Order Details" />
          <Tab className="h-64 normal-case" label="Products" />
          <Tab className="h-64 normal-case" label="Invoice" />
          <Tab className="h-64 normal-case" label="Status" />
        </Tabs>
      }
      content={
        order && (
          <div className="p-16 sm:p-24  w-full">
            {/* Order Details */}
            {tabValue === 0 && (
              <div>
                {data === undefined ? (
                  'some thing went wrong '
                ) : (
                  <div className="pb-48">
                    <div className="pb-16 flex items-center">
                      <Icon color="action">account_circle</Icon>
                      <Typography className="h2 mx-16" color="textSecondary">
                        {data?.user.data?.displayName}
                      </Typography>
                    </div>

                    <div className="mb-24">
                      <div className="table-responsive mb-48">
                        <table className="simple">
                          <thead>
                            <tr>
                              <th>{t('NAME')}</th>
                              <th>{t('EMAIL')}</th>
                              <th>{t('PHONE')}</th>
                              <th>{t('ROLE')}</th>
                            </tr>
                          </thead>
                          <tbody>
                            <tr>
                              <td>
                                <Typography className="truncate mx-8">
                                  {data?.user.data?.displayName}
                                </Typography>
                              </td>
                              <td>
                                <Typography className="truncate">
                                  {data?.user.data?.email}
                                </Typography>
                              </td>
                              <td>
                                <Typography className="truncate">
                                  {data?.user.mobile}
                                </Typography>
                              </td>
                              <td>
                                <span className="truncate">
                                  {data?.user.role}
                                </span>
                              </td>
                            </tr>
                          </tbody>
                        </table>
                      </div>
                    </div>
                  </div>
                )}
                {console.log(data)}
                <div className="pb-16 flex items-center">
                  <MapIcon color="action" />
                  <Typography className="h2 mx-16" color="textSecondary">
                    From Address
                  </Typography>
                </div>
                <div className="mb-48">
                  <Box className="shadow p-8">
                    <Box className="flex flex-col md:flex-row">
                      <div className="w-full h-320">
                        <Googlemaps
                          place={{
                            lat: data?.fromAddress[0]?.lat,
                            lng: data?.fromAddress[0]?.long,
                          }}
                        />
                      </div>
                    </Box>
                    <Typography className="w-full m-16 ">
                      {data?.fromAddress[0]?.address}
                    </Typography>
                  </Box>
                  <div className="pb-16 mt-48 flex items-center">
                    <RoomIcon color="action" />
                    <Typography className="h2 mx-16" color="textSecondary">
                      to Address
                    </Typography>
                  </div>
                  <Box className="shadow  p-8">
                    <Box className="flex flex-col md:flex-row">
                      <div className="w-full h-320">
                        <Googlemaps
                          place={{
                            lat: data?.toAddress[0]?.lat,
                            lng: data?.toAddress[0]?.long,
                          }}
                        />
                      </div>
                    </Box>
                    <Typography className="w-full  m-16">
                      {data?.toAddress[0]?.address}
                    </Typography>
                  </Box>
                </div>
                <div className="pb-48">
                  <div className="pb-16 flex items-center">
                    <Icon color="action">access_time</Icon>
                    <Typography className="h2 mx-16" color="textSecondary">
                      Master List
                    </Typography>
                  </div>
                  <div className="table-responsive">
                    <table className="simple">
                      <thead>
                        <tr>
                          <th>Master Name</th>
                          <th>Master Code</th>
                          <th>Master Address</th>
                          <th>Master Mobile</th>
                        </tr>
                      </thead>
                      <tbody>
                        <tr>
                          <td>{data?.masterList[0].masterName}</td>
                          <td>{data?.masterList[0].masterCode}</td>
                          <td>{data?.masterList[0].masterAddress}</td>
                          <td>{data?.masterList[0].masterMobile}</td>
                        </tr>
                      </tbody>
                    </table>
                  </div>
                </div>
              </div>
            )}

            {/* Products */}
            {tabValue === 1 && (
              <div className="table-responsive">
                <table className="simple">
                  <thead>
                    <tr>
                      <th>ID</th>
                      <th>Image</th>
                      <th>Name</th>
                      <th>Price</th>
                      <th>Quantity</th>
                    </tr>
                  </thead>
                  <tbody>
                    {data?.products?.map((product) => (
                      <tr key={product.id}>
                        <td>{product.id}</td>
                        <td>
                          <img
                            className="product-image"
                            src={product.images[0].url}
                            alt="product"
                          />
                        </td>
                        <td>
                          <Typography
                            component={Link}
                            to={`/apps/e-commerce/products/${product.id}`}
                            className="truncate"
                            style={{
                              color: 'inherit',
                              textDecoration: 'underline',
                            }}
                          >
                            {product.name}
                          </Typography>
                        </td>
                        <td>
                          <span className="truncate">
                            ${product.priceTaxExcl}
                          </span>
                        </td>
                        <td>
                          <span className="truncate">{product.discount}</span>
                        </td>
                      </tr>
                    ))}
                  </tbody>
                </table>
              </div>
            )}
            {/* Invoice */}
            {tabValue === 2 && <OrderInvoice order={order} />}
            {tabValue === 3 && (
              <div className="pb-48">
                <div className="pb-16 flex items-center">
                  <Icon color="action">access_time</Icon>
                  <Typography className="h2 mx-16" color="textSecondary">
                    Status
                  </Typography>
                </div>
                <div className="table-responsive">
                  <table className="simple">
                    <thead>
                      <tr>
                        <th>ردیف</th>
                        <th>وضعیت سفارش</th>
                        <th>تغییر وضعیت در تاریخ</th>
                        <th>وضعیت</th>
                      </tr>
                    </thead>
                    <tbody>
                      {console.log(data)}
                      {data?.status.map((item, i) => (
                        <tr>
                          <td>{item.stcode}</td>
                          <td>{item.name}</td>
                          <td>{item.date}</td>
                          <td>
                            {item.active !== true ||
                            item.active === undefined ? (
                              <CancelIcon style={{ color: 'red' }} />
                            ) : (
                              <CheckCircleIcon style={{ color: 'green' }} />
                            )}
                          </td>
                        </tr>
                      ))}
                    </tbody>
                  </table>
                </div>
              </div>
            )}
          </div>
        )
      }
      innerScroll
    />
  );
}

export default withReducer('eCommerceApp', reducer)(Order);
