import PropTypes from 'prop-types';
import Icon from '@material-ui/core/Icon';
import Select from '@material-ui/core/Select';
import MenuItem from '@material-ui/core/MenuItem';
import IconButton from '@material-ui/core/IconButton';
import FormControl from '@material-ui/core/FormControl';

function PropertiesToolbar({
  t,
  orderBy,
  onOrderByChange,
  orderDescending,
  onToggleOrderDescending,
}) {
  const handleOrderChange = (ev) => {
    onOrderByChange(ev.target.value);
  };

  return (
    <div className="flex justify-between w-full">
      <div className="flex" />
      <div className="flex items-center">
        <FormControl className="">
          <Select
            displayEmpty
            name="filter"
            value={orderBy}
            onChange={handleOrderChange}
          >
            <MenuItem value="">
              <em>{t('ORDER_BY')}</em>
            </MenuItem>
            <MenuItem value="title">{t('TITLE')}</MenuItem>
          </Select>
        </FormControl>
        <IconButton onClick={onToggleOrderDescending}>
          <Icon
            style={{ transform: orderDescending ? 'scaleY(-1)' : 'scaleY(1)' }}
          >
            sort
          </Icon>
        </IconButton>
      </div>
    </div>
  );
}

PropertiesToolbar.propTypes = {
  t: PropTypes.func.isRequired,
  orderBy: PropTypes.string.isRequired,
  orderDescending: PropTypes.bool.isRequired,
  onOrderByChange: PropTypes.func.isRequired,
  onToggleOrderDescending: PropTypes.func.isRequired,
};

export default PropertiesToolbar;
