import axios from 'axios';
import FuseUtils from '@fuse/utils';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { getPropertiesKey } from './useProperties';

const uploadImage = (filename = '', file, isEdit) => {
  var formData = new FormData();
  formData.append(filename, file);

  if (isEdit) {
    return axios
      .put('/api/property-app/upload', formData)
      .then((res) => res.data);
  }

  return axios
    .post('/api/property-app/upload', formData)
    .then((res) => res.data);
};

const saveProperty = ({ property, isEdit }) => {
  const { imageFile, iconFile, ...data } = property;

  const imagesToUpload = [];

  if (imageFile) {
    imagesToUpload.push({
      file: imageFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_background_',
    });
  }

  if (iconFile) {
    imagesToUpload.push({
      file: iconFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_icon_',
    });
  }

  if (data.showType) {
    data.showType = data.showType?.id;
  }

  if (!isEdit && !data.id) {
    data.id = FuseUtils.generateGUID();
  }

  return Promise.all(
    imagesToUpload.map((image) =>
      uploadImage(image.filename, image.file, isEdit)
    )
  ).then((uploadedImages) => {
    uploadedImages.forEach((uploadedImage) => {
      const fieldName = uploadedImage.id === 'icon' ? 'iconSrc' : 'imageSrc';
      data[fieldName] = uploadedImage.url;
    });

    if (isEdit) {
      return axios
        .put('/api/property-app/update-property', data)
        .then(() => data);
    }

    return axios.post('/api/property-app/new-property', data).then(() => data);
  });
};

export default function useSaveProperty() {
  return useMutation(saveProperty, {
    onMutate: ({
      isEdit,
      property,
      labelHandle,
      filterHandle,
      folderHandle,
    }) => {
      const propertiesKey = getPropertiesKey({
        labelHandle,
        filterHandle,
        folderHandle,
      });

      queryCache.cancelQueries('properties');
      const previousProperties = queryCache.getQueryData(propertiesKey);
      let newProperties;

      if (isEdit) {
        newProperties = previousProperties.map((item) =>
          item.id === property.id ? property : item
        );
      } else {
        newProperties = [property, ...previousProperties];
      }

      queryCache.setQueryData(propertiesKey, newProperties);

      return () => queryCache.setQueryData(propertiesKey, previousProperties);
    },
    onError: (err, variables, rollback) => rollback(),
    onSuccess: () => {
      queryCache.invalidateQueries('properties', { refetchInactive: true });
    },
  });
}
