import { useState } from 'react';
import PropTypes from 'prop-types';
import Editor from 'app/components/Editor';
import { Controller } from 'react-hook-form';
import Switch from '@material-ui/core/Switch';
import CategoryDialog from './CategoryDialog';
import TextField from '@material-ui/core/TextField';

import AddCircleIcon from '@material-ui/icons/AddCircle';
import PlaceIcon from '@material-ui/icons/Place';
import {
  Button,
  FormControl,
  Icon,
  IconButton,
  InputLabel,
  makeStyles,
  MenuItem,
  Select,
  Typography,
} from '@material-ui/core';
import Mymodal from '../../Mymodal/Mymodal';
import { Autocomplete } from '@material-ui/lab';
import useOrderList from '../../hooks/useOrderList';
import { useHistory, useLocation } from 'react-router';
import qs from 'qs';

const courseLevels = [
  { id: 'ابتدایی', name: 'ابتدایی' },
  { id: 'متوسط', name: 'متوسط' },
  { id: 'پیشرفته', name: 'پیشرفته' },
];
const useStyles = makeStyles((theme) => ({
  modalroot: {
    backgroundColor: 'white',
    borderRadius: 8,
    width: 600,
    overflow: 'hidden',
  },
  modalwrapper: {
    width: '100%',
    minHeight: 200,
  },
  modalhead: {
    backgroundColor: '#3c4252',
    width: '100%',
    height: 50,
    padding: 20,
    textAlign: 'right',
    display: 'flex',
    alignItems: 'center',
    color: 'white',
  },
  body: {
    padding: 20,
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: 'center',
  },
  addbtn: {
    padding: '5px 20px',
    color: 'white',
    backgroundColor: 'gray',
    width: '100%',
    '&:hover': {
      backgroundColor: 'gray',
    },
  },
}));

const OrderBasicInfo = ({
  t,
  theme,
  errors,
  control,
  register,
  setValue,
  getValues,
}) => {
  const [state, setState] = useState({
    company: '',
    status: '',
    pay: '',
    user: '',
    address: '',
    description: '',
  });

  const handleChange = (event) => {
    const name = event.target.name;
    setState({
      ...state,
      [name]: event.target.value,
    });
  };
  const [open, setOpen] = useState(false);
  const handleOpen = () => {
    setOpen(true);
  };

  const handleClose = () => {
    setOpen(false);
  };
  const classes = useStyles();
  const { search: locationSearch } = useLocation();

  const urlParams = qs.parse(locationSearch, {
    ignoreQueryPrefix: true,
  });

  const [queryPage, setQueryPage] = useState(parseInt(urlParams.page) || 1);
  const {
    isLoading,
    isFetching,
    resolvedData = { count: 0, orders: [], pageCount: 0 },
  } = useOrderList({
    page: queryPage,
  });
  return (
    <div className="max-w-2xl">
      <div className="pb-48 flex items-center">
        <Icon color="action">account_circle</Icon>
        <Typography className="h2 mx-16" color="textSecondary">
          مشخصات مشتری
        </Typography>
        <IconButton onClick={handleOpen}>
          <AddCircleIcon color="action" />
        </IconButton>
      </div>
      <div className="pb-16 flex items-center">
        <PlaceIcon color="action" />
        <Typography className="h2 mx-16" color="textSecondary">
          آدرس تحویل
        </Typography>
      </div>
      <div className="flex justify-around">
        <FormControl style={{ width: '100%', margin: 20 }} variant="outlined">
          <InputLabel>شرکت</InputLabel>
          <Select
            native
            value={state.company}
            onChange={handleChange}
            label="شرکت"
            inputRef={register}
            name="company"
            inputProps={{
              name: 'company',
            }}
          >
            <option aria-label="None" value="" />
            <option value="ngh.ir">ngh.ir</option>
          </Select>
        </FormControl>
        <FormControl style={{ width: '100%', margin: 20 }} variant="outlined">
          <InputLabel>وضعیت</InputLabel>
          <Select
            native
            value={state.status}
            onChange={handleChange}
            label="وضعیت"
            inputRef={register}
            name="status"
            inputProps={{
              name: 'status',
            }}
          >
            <option aria-label="None" value="" />
            <option value={'cancel'}>لغو سفر</option>
            <option value={'end'}>اتمام سفر</option>
            <option value={'start'}>سوار شدن مسافر</option>
            <option value={'end2'}>رسیدن مسافر به مقصد</option>
          </Select>
        </FormControl>
        <FormControl style={{ width: '100%', margin: 20 }} variant="outlined">
          <InputLabel>نوع پرداخت</InputLabel>
          <Select
            native
            value={state.pay}
            onChange={handleChange}
            label="نوع پرداخت"
            inputRef={register}
            name="pay"
            inputProps={{
              name: 'pay',
            }}
          >
            <option aria-label="None" value="" />
            <option value={'naghdi'}>نقدی</option>
            <option value={'online'}>غیر نقدی</option>
          </Select>
        </FormControl>
      </div>
      <TextField
        multiline
        rows={4}
        style={{ width: '100%', margin: 20 }}
        label="توضیحات"
        inputRef={register}
        onChange={handleChange}
        name="description"
        value={state.description}
        variant="outlined"
        inputProps={{
          name: 'description',
        }}
      />
      <Mymodal
        open={open}
        close={handleClose}
        modal={
          <>
            <div className={classes.modalroot}>
              <div className={classes.modalwrapper}>
                <div className={classes.modalhead}>انتخاب نماینده</div>
                <div className={classes.body}>
                  <FormControl variant="outlined" className="w-full my-16">
                    <InputLabel id="demo-simple-select-outlined-label">
                      User
                    </InputLabel>
                    <Select
                      inputRef={register}
                      name="user"
                      labelId="demo-simple-select-outlined-label"
                      id="demo-simple-select-outlined"
                      value={state.user}
                      onChange={handleChange}
                      label="User"
                      inputProps={{
                        name: 'user',
                      }}
                    >
                      <MenuItem value="">
                        <em>None</em>
                      </MenuItem>
                      {resolvedData.orders.map((item, i) => (
                        <MenuItem value={item.user.data.displayName}>
                          {item.user.data.displayName}
                        </MenuItem>
                      ))}
                    </Select>
                  </FormControl>
                  <FormControl variant="outlined" className="w-full my-16">
                    <InputLabel id="demo-simple-select-outlined-label">
                      Address
                    </InputLabel>
                    <Select
                      labelId="demo-simple-select-outlined-label"
                      id="demo-simple-select-outlined"
                      value={state.address}
                      onChange={handleChange}
                      inputRef={register}
                      name="address"
                      label="Address"
                      inputProps={{
                        name: 'address',
                      }}
                    >
                      <MenuItem value="">
                        <em>None</em>
                      </MenuItem>
                      {resolvedData.orders.map((item, i) => (
                        <MenuItem value={item.fromAddress[0].address}>
                          {item.fromAddress[0].address}
                        </MenuItem>
                      ))}
                    </Select>
                  </FormControl>
                  <Button
                    disabled={
                      state.address === '' || state.user === '' ? true : false
                    }
                    className={classes.addbtn}
                    onClick={handleClose}
                  >
                    Add
                  </Button>
                </div>
              </div>
            </div>
          </>
        }
      />
    </div>
  );
};

OrderBasicInfo.propTypes = {
  t: PropTypes.func.isRequired,
  theme: PropTypes.object.isRequired,
  register: PropTypes.func.isRequired,
  errors: PropTypes.object.isRequired,
  setValue: PropTypes.func.isRequired,
  control: PropTypes.object.isRequired,
  getValues: PropTypes.func.isRequired,
};
export default OrderBasicInfo;
