import axios from 'axios';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { removeNodeAtPath } from 'react-sortable-tree';

export default function useDeleteTreeCategory() {
  return useMutation(
    (path) => {
      return axios.delete('/api/tree-category-app/remove-category', {
        data: { path },
      });
    },
    {
      onMutate: (path) => {
        queryCache.cancelQueries('treeCategories');

        const previousTreeData = queryCache.getQueryData('treeCategories');

        queryCache.setQueryData(
          'treeCategories',
          removeNodeAtPath({
            treeData: previousTreeData,
            path,
            getNodeKey: ({ treeIndex }) => treeIndex,
          })
        );

        return () =>
          queryCache.setQueryData('treeCategories', previousTreeData);
      },
      onError: (err, variables, rollback) => rollback(),
      onSuccess: () => {
        queryCache.invalidateQueries('treeCategories');
      },
    }
  );
}
