import { useState } from 'react';
import PropTypes from 'prop-types';
import Editor from 'app/components/Editor';
import { Controller } from 'react-hook-form';
import Switch from '@material-ui/core/Switch';
import CategoryDialog from './CategoryDialog';
import TextField from '@material-ui/core/TextField';
import useMasterList from '../../hooks/useMasterList';
import FuseChipSelect from '@fuse/core/FuseChipSelect';
import useClusterList from '../../hooks/useClusterList';
import FormControlLabel from '@material-ui/core/FormControlLabel';

const courseLevels = [
  { id: 'ابتدایی', name: 'ابتدایی' },
  { id: 'متوسط', name: 'متوسط' },
  { id: 'پیشرفته', name: 'پیشرفته' },
];

const PostBasicInfo = ({
  t,
  theme,
  errors,
  control,
  register,
  setValue,
  getValues,
}) => {
  const [isCategoryDialogOpen, setIsCategoryDialogOpen] = useState(false);

  const { data: clusterList = [] } = useClusterList();
  const { data: masterList = [] } = useMasterList();

  const appName = 'immerse';

  const handleOpenCategoryDialog = () => {
    setIsCategoryDialogOpen(true);
  };

  const handleCloseCategoryDialog = () => {
    setIsCategoryDialogOpen(false);
  };

  const handleSelectCategory = (selectedCategory) => {
    const categories = getValues('categoriesObject');

    const idName = selectedCategory.id ? 'id' : 'categoryLabelId';

    const isAlreadySelected = categories.find(
      (category) => category[idName] === selectedCategory[idName]
    );
    if (!isAlreadySelected) {
      setValue('categoriesObject', [...categories, selectedCategory], {
        shouldDirty: true,
      });
    }
  };

  return (
    <div>
      <div className="-mx-3 flex flex-wrap mb-24">
        <TextField
          required
          autoFocus
          fullWidth
          name="name"
          label={t('NAME')}
          variant="outlined"
          inputRef={register}
          error={!!errors?.name}
          helperText={errors?.name?.message}
          className="md:w-1/2 px-3 mt-8 mb-24 md:mb-0"
        />
        <TextField
          fullWidth
          type="text"
          name="Code"
          label={t('CODE')}
          variant="outlined"
          inputRef={register}
          className="md:w-1/2 px-3 mt-8"
        />
      </div>

      <div className="-mx-3 flex flex-wrap mb-24">
        <Controller
          isClearable
          name="cluster"
          control={control}
          as={FuseChipSelect}
          isSearchable={false}
          options={clusterList}
          placeholder="clusterList"
          getOptionValue={(option) => option.id}
          getOptionLabel={(option) => option.name}
          className="md:w-1/2 px-3 mt-8 mb-24 md:mb-0"
          textFieldProps={{
            variant: 'outlined',
            label: t('CLUSTER_LIST'),
            InputLabelProps: { shrink: true },
          }}
        />
        <Controller
          isClearable
          name="master"
          control={control}
          as={FuseChipSelect}
          isSearchable={false}
          options={masterList}
          placeholder="masterList"
          className="md:w-1/2 px-3 mt-8"
          getOptionValue={(option) => option.masterId}
          getOptionLabel={(option) => option.masterName}
          textFieldProps={{
            variant: 'outlined',
            label: t('MASTER_LIST'),
            InputLabelProps: { shrink: true },
          }}
        />
      </div>

      {appName === 'immerse' && (
        <Controller
          isClearable
          control={control}
          name="courselevel"
          as={FuseChipSelect}
          placeholder="Level"
          isSearchable={false}
          options={courseLevels}
          className="mt-8 mb-24"
          getOptionValue={(option) => option.id}
          getOptionLabel={(option) => option.name}
          textFieldProps={{
            variant: 'outlined',
            label: t('COURSE_LEVEL'),
            InputLabelProps: { shrink: true },
          }}
        />
      )}

      {/* <div className={classes.formGroup}>
            <Typography
              className={classes.formGroupTitle}
              color="textSecondary"
            >
              سطح
            </Typography>

            <FormControl>
              <Controller
                render={(props) => (
                  <RadioGroup
                    row
                    aria-label="append type"
                    {...props}
                    name="appendType"
                  >
                    <FormControlLabel
                      value="beginning"
                      control={<Radio />}
                      label="ابتدایی"
                    />
                    <FormControlLabel
                      value="end"
                      control={<Radio />}
                      label="متوسط"
                    />
                    <FormControlLabel
                      value="end"
                      control={<Radio />}
                      label="پیشرفته"
                    />
                  </RadioGroup>
                )}
                name="appendType"
                control={control}
              />
            </FormControl>
          </div> */}

      <Controller
        isMulti
        options={[]}
        control={control}
        className="mb-24"
        as={FuseChipSelect}
        isSearchable={false}
        name="categoriesObject"
        openMenuOnClick={false}
        onClick={handleOpenCategoryDialog}
        getOptionLabel={(option) => option.value}
        placeholder={t('SELECT_MULTIPLE_CATEGORIES')}
        getOptionValue={(option) =>
          option.id ? option.id : option.categoryLabelId
        }
        textFieldProps={{
          variant: 'outlined',
          label: t('CATEGORIES'),
          InputLabelProps: { shrink: true },
          onClick: handleOpenCategoryDialog,
        }}
      />

      <TextField
        rows="2"
        multiline
        fullWidth
        name="info"
        label={t('INFO')}
        variant="outlined"
        inputRef={register}
        className="mt-8 mb-24"
      />

      <Controller
        as={Editor}
        control={control}
        name="description"
        className="mt-8 mb-24"
        direction={theme.direction}
      />
      {/* 
      <Controller
        name="description"
        control={control}
        modules={{
          toolbar: [
            [{ header: [1, 2, 3, 4, 5, 6, true] }],
            ['bold', 'italic', 'underline', 'strike', 'blockquote'],
            [
              { list: 'ordered' },
              { list: 'bullet' },
              { indent: '-1' },
              { indent: '+1' },
            ],
            ['link', 'image', 'code-block'],
            [{ direction: theme.direction }], // text direction
            [{ size: ['small', false, 'large', 'huge'] }], // custom dropdown
            [{ color: [] }, { background: [] }], // dropdown with defaults from theme
            [{ font: [] }],
            [{ align: [] }],
            ['clean'],
          ],
        }}
        render={({ onChange, value }) => (
          <ReactQuill
            theme="snow"
            value={value || ''}
            className="mt-8 mb-24"
            onChange={(description) => onChange(description)}
          />
        )}
      /> */}

      <Controller
        isMulti
        isClearable
        name="tags"
        control={control}
        placeholder={t('SELECT_MULTIPLE_TAGS')}
        as={FuseChipSelect}
        className="mt-8 mb-24"
        textFieldProps={{
          label: t('TAGS'),
          variant: 'outlined',
          InputLabelProps: { shrink: true },
        }}
      />

      <FormControlLabel
        label={t('PUBLISH')}
        className="mt-8 mb-24"
        control={
          <Controller
            name="publish"
            control={control}
            render={(props) => (
              <Switch
                checked={props.value}
                onChange={(e) => props.onChange(e.target.checked)}
              />
            )}
          />
        }
      />

      <CategoryDialog
        t={t}
        isOpen={isCategoryDialogOpen}
        onClose={handleCloseCategoryDialog}
        onSelectCategory={handleSelectCategory}
      />
    </div>
  );
};

PostBasicInfo.propTypes = {
  t: PropTypes.func.isRequired,
  theme: PropTypes.object.isRequired,
  register: PropTypes.func.isRequired,
  errors: PropTypes.object.isRequired,
  setValue: PropTypes.func.isRequired,
  control: PropTypes.object.isRequired,
  getValues: PropTypes.func.isRequired,
};

export default PostBasicInfo;
