import PropTypes from 'prop-types';
import Icon from '@material-ui/core/Icon';
import { Controller } from 'react-hook-form';
import Divider from '@material-ui/core/Divider';
import TextField from '@material-ui/core/TextField';
import Typography from '@material-ui/core/Typography';
import InputAdornment from '@material-ui/core/InputAdornment';

const ProductPricing = ({ t, register, control, getValues, setValue }) => {
  const getPriceTaxInclValue = () => {
    let {
      priceTaxIncl = 0,
      discount = 0,
      priceTaxExcl = 0,
      taxRate = 0,
    } = getValues(['priceTaxIncl', 'discount', 'priceTaxExcl', 'taxRate']);

    discount = (discount * priceTaxExcl) / 100;

    let p = parseInt(priceTaxExcl) - parseInt(discount);

    taxRate = (taxRate * p) / 100;

    priceTaxIncl = parseInt(p) + parseInt(taxRate);

    if (priceTaxIncl === '0' || priceTaxIncl === '') {
      priceTaxIncl = priceTaxExcl;
    }

    return priceTaxIncl;
  };

  return (
    <div>
      <div className="flex flex-wrap -mx-4 mb-24">
        <Controller
          control={control}
          name="priceTaxExcl"
          render={({ onChange, onBlur, value }) => (
            <TextField
              autoFocus
              fullWidth
              type="number"
              value={value}
              onBlur={onBlur}
              variant="outlined"
              onChange={(e) => {
                onChange(e);
                setValue('priceTaxIncl', getPriceTaxInclValue(), {
                  shouldDirty: true,
                });
              }}
              label={t('TAX_EXCLUDED_PRICE')}
              className="md:w-1/3 px-3 mt-8 mb-24 md:mb-0"
              InputProps={{
                endAdornment: (
                  <InputAdornment position="start">{t('RIAL')}</InputAdornment>
                ),
              }}
            />
          )}
        />

        <Controller
          control={control}
          name="discount"
          render={({ onChange, onBlur, value }) => (
            <TextField
              fullWidth
              type="number"
              value={value}
              onBlur={onBlur}
              variant="outlined"
              onChange={(e) => {
                onChange(e);
                setValue('priceTaxIncl', getPriceTaxInclValue(), {
                  shouldDirty: true,
                });
              }}
              label={t('DISCOUNT')}
              className="md:w-1/3 px-3 mt-8 mb-24 md:mb-0"
              InputProps={{
                max: 99,
                endAdornment: (
                  <InputAdornment position="start">%</InputAdornment>
                ),
              }}
            />
          )}
        />

        <Controller
          control={control}
          name="taxRate"
          render={({ onChange, onBlur, value }) => (
            <TextField
              fullWidth
              type="number"
              value={value}
              onBlur={onBlur}
              variant="outlined"
              onChange={(e) => {
                onChange(e);
                setValue('priceTaxIncl', getPriceTaxInclValue(), {
                  shouldDirty: true,
                });
              }}
              label={t('TAX_RATE')}
              className="md:w-1/3 px-4 mt-8"
              InputProps={{
                endAdornment: (
                  <InputAdornment position="start">%</InputAdornment>
                ),
              }}
            />
          )}
        />
      </div>

      <div className="max-w-sm">
        <div className="flex items-center pb-16">
          <Icon color="action">add_to_queue</Icon>
          <Typography className="h2 mx-16" color="textSecondary">
            {t('TAX_INCLUDED_PRICE_TITLE')}
          </Typography>
        </div>

        <TextField
          fullWidth
          type="number"
          variant="outlined"
          name="priceTaxIncl"
          inputRef={register}
          label={t('TAX_INCLUDED_PRICE')}
          helperText={t('WEBSITE_DISPLAYED_PRICE')}
          className="mt-8 mb-24"
          InputProps={{
            readOnly: true,
            endAdornment: (
              <InputAdornment position="start">{t('RIAL')}</InputAdornment>
            ),
          }}
        />
      </div>

      <Divider />

      <div className="flex flex-wrap -mx-4 mb-24">
        <TextField
          fullWidth
          name="like"
          type="number"
          label={t('LIKE')}
          variant="outlined"
          inputRef={register}
          className="md:w-1/3 px-3 mt-8 mb-24 md:mb-0"
        />

        <TextField
          fullWidth
          name="wish"
          type="number"
          label={t('WISH')}
          variant="outlined"
          inputRef={register}
          className="md:w-1/3 px-3 mt-8 mb-24 md:mb-0"
        />

        <TextField
          fullWidth
          type="number"
          name="quantity"
          variant="outlined"
          inputRef={register}
          label={t('QUANTITY')}
          className="md:w-1/3 px-4 mt-8"
        />
      </div>
    </div>
  );
};

ProductPricing.propTypes = {
  t: PropTypes.func.isRequired,
  register: PropTypes.func.isRequired,
  setValue: PropTypes.func.isRequired,
  control: PropTypes.object.isRequired,
  getValues: PropTypes.func.isRequired,
};

export default ProductPricing;
