import { useEffect, useRef, useState } from 'react';
import _ from '@lodash';
import FuseUtils from '@fuse/utils';
import { useParams } from 'react-router-dom';
import Spinner from 'app/components/Spinner';
import { useTranslation } from 'react-i18next';
import CategoryLabelList from './CategoryLabelList';
import FusePageCarded from '@fuse/core/FusePageCarded';
import CategoryLabelsHeader from './CategoryLabelsHeader';
import useCategoryLabels from '../hooks/useCategoryLabels';
import CategoryLabelsToolbar from './CategoryLabelsToolbar';
import CategoryLabelFormDialog from './CategoryLabelFormDialog';
import useSaveCategoryLabel from '../hooks/useSaveCategoryLabel';
import CategoryLabelsSidebarHeader from './CategoryLabelsSidebarHeader';
import CategoryLabelsSidebarContent from './CategoryLabelsSidebarContent';

function CategoryLabels() {
  const [isDialogOpen, setIsDialogOpen] = useState(false);
  const [isEditDialog, setIsEditDialog] = useState(false);
  const [selectedLabel, setSelectedLabel] = useState(null);

  const [filteredData, setFilteredData] = useState(null);
  const [searchText, setSearchText] = useState('');
  const [orderBy, setOrderBy] = useState('');
  const [orderDescending, setOrderDescending] = useState(false);

  const pageLayout = useRef(null);

  const { filterHandle } = useParams();

  const { t } = useTranslation('categories');

  const { data: labels, isLoading } = useCategoryLabels();

  const [saveCategoryLabel] = useSaveCategoryLabel();

  useEffect(() => {
    console.log('useEffect', {
      searchText,
      orderBy,
      orderDescending,
      filterHandle,
    });
    function getFilteredArray(entities, _searchText) {
      if (_searchText.length === 0) {
        return labels;
      }
      return FuseUtils.filterArrayByString(labels, _searchText);
    }

    if (labels) {
      let filterdData = _.orderBy(
        getFilteredArray(labels, searchText),
        [orderBy],
        [orderDescending ? 'desc' : 'asc']
      );

      if (filterHandle && filterHandle !== 'all') {
        filterdData = filterdData.filter((item) => item[filterHandle]);
      }

      setFilteredData(filterdData);
    } else {
      setFilteredData([]);
    }
  }, [labels, orderBy, orderDescending, searchText, filterHandle]);

  const handleUpdateLabel = (categoryLabel) => {
    return saveCategoryLabel({
      categoryLabel,
      isEdit: true,
    });
  };

  const handleToggleOrderDescending = () => {
    setOrderDescending((value) => !value);
  };

  const handleOpenAddDialog = () => {
    setIsDialogOpen(true);
    setIsEditDialog(false);
  };

  const handleOpenEditDialog = (selectedLabel) => {
    setSelectedLabel(selectedLabel);
    setIsEditDialog(true);
    setIsDialogOpen(true);
  };

  const handleCloseDialog = () => {
    setSelectedLabel(null);
    setIsDialogOpen(false);
    setIsEditDialog(false);
  };

  const handleSubmit = (categoryLabel) => {
    return saveCategoryLabel({ categoryLabel, isEdit: isEditDialog });
  };

  if (!filteredData) {
    return null;
  }

  return (
    <>
      {isLoading && <Spinner />}
      <FusePageCarded
        classes={{
          root: 'w-full',
          header: 'items-center min-h-72 h-72 sm:h-136 sm:min-h-136',
        }}
        header={
          <CategoryLabelsHeader
            t={t}
            searchText={searchText}
            pageLayout={pageLayout}
            onSearchTextChange={setSearchText}
          />
        }
        contentToolbar={
          <CategoryLabelsToolbar
            t={t}
            orderBy={orderBy}
            onOrderByChange={setOrderBy}
            orderDescending={orderDescending}
            onToggleOrderDescending={handleToggleOrderDescending}
          />
        }
        content={
          <CategoryLabelList
            t={t}
            isLoading={isLoading}
            labels={filteredData}
            onUpdate={handleUpdateLabel}
            onOpenEditDialog={handleOpenEditDialog}
          />
        }
        leftSidebarHeader={<CategoryLabelsSidebarHeader t={t} />}
        leftSidebarContent={
          <CategoryLabelsSidebarContent
            t={t}
            onOpenAddDialog={handleOpenAddDialog}
          />
        }
        ref={pageLayout}
        innerScroll
      />

      {isDialogOpen && (
        <CategoryLabelFormDialog
          t={t}
          edit={isEditDialog}
          data={selectedLabel}
          onSubmit={handleSubmit}
          onClose={handleCloseDialog}
        />
      )}
    </>
  );
}

export default CategoryLabels;
