import axios from 'axios';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { getCategoriesKey } from './useCategories';

export default function useDeleteCategory() {
  return useMutation(
    ({ id }) => {
      return axios.delete('/api/category-app/remove-category', {
        data: { categoryId: id },
      });
    },
    {
      onMutate: ({ id, labelHandle, filterHandle, folderHandle }) => {
        const categoriesKey = getCategoriesKey({
          labelHandle,
          filterHandle,
          folderHandle,
        });

        queryCache.cancelQueries('categories');

        const previousCategories = queryCache.getQueryData(categoriesKey);

        queryCache.setQueryData(
          categoriesKey,
          previousCategories.filter((category) => category.id !== id)
        );

        return () => queryCache.setQueryData(categoriesKey, previousCategories);
      },
      onError: (err, variables, rollback) => rollback(),
      onSuccess: () => {
        queryCache.invalidateQueries('categories');
      },
    }
  );
}
