import axios from 'axios';
import { usePaginatedQuery } from 'react-query';

export default function usePostList({
  page,
  search,
  sortBy,
  perPage,
  sortDir,
}) {
  return usePaginatedQuery(
    ['postlist', page, perPage, search, sortBy, sortDir],
    async (_, page, perPage, search, sortBy, sortDir) => {
      const skip = perPage * page - perPage;

      const response = await axios.get(`/api/e-laundry-app/postlist`, {
        params: {
          limit: perPage,
          skip,
          search: search ? search : null,
          sortBy: sortBy ? sortBy : null,
          sortDir: sortBy ? sortDir : null,
        },
      });

      const { count, postlist } = response.data;
      return {
        count,
        postlist,
        pageCount: Math.ceil(count / perPage),
      };
    }
  );
}
