import axios from 'axios';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { getProcessKey } from './useProcess';

export default function useDeleteCategory() {
  return useMutation(
    ({ id }) => {
      return axios.delete('/api/process-app/remove-category', {
        data: { categoryId: id },
      });
    },
    {
      onMutate: ({ id, labelHandle, filterHandle, folderHandle }) => {
        const processKey = getProcessKey({
          labelHandle,
          filterHandle,
          folderHandle,
        });

        queryCache.cancelQueries('process');

        const previousProcess = queryCache.getQueryData(processKey);

        queryCache.setQueryData(
          processKey,
          previousProcess.filter((category) => category.id !== id)
        );

        return () => queryCache.setQueryData(processKey, previousProcess);
      },
      onError: (err, variables, rollback) => rollback(),
      onSuccess: () => {
        queryCache.invalidateQueries('process');
      },
    }
  );
}
