import axios from 'axios';
import FuseUtils from '@fuse/utils';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';

const uploadImage = (filename = '', file, isEdit) => {
  var formData = new FormData();
  formData.append(filename, file);

  if (isEdit) {
    return axios
      .put('/api/process-app/upload', formData)
      .then((res) => res.data);
  }

  return axios
    .post('/api/process-app/upload', formData)
    .then((res) => res.data);
};

const saveCategoryLabel = ({ categoryLabel, isEdit }) => {
  const { imageFile, iconFile, ...data } = categoryLabel;

  const imagesToUpload = [];

  if (imageFile) {
    imagesToUpload.push({
      file: imageFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_background_',
    });
  }

  if (iconFile) {
    imagesToUpload.push({
      file: iconFile,
      filename: 'p_' + FuseUtils.generateGUID() + '_icon_',
    });
  }

  return Promise.all(
    imagesToUpload.map((image) =>
      uploadImage(image.filename, image.file, isEdit)
    )
  ).then((uploadedImages) => {
    uploadedImages.forEach((uploadedImage) => {
      const fieldName = uploadedImage.id === 'icon' ? 'iconSrc' : 'imageSrc';
      data[fieldName] = uploadedImage.url;
    });

    if (isEdit) {
      return axios
        .put('/api/process-app/update-category-label', data)
        .then(() => data);
    }

    return axios.post('/api/process-app/new-label', data).then(() => data);
  });
};

export default function useSaveCategoryLabel() {
  return useMutation(saveCategoryLabel, {
    onMutate: ({ isEdit, categoryLabel }) => {
      queryCache.cancelQueries('categoryLabels');

      const previousCategoryLabels = queryCache.getQueryData('categoryLabels');
      let newCategoryLabels;

      if (isEdit) {
        newCategoryLabels = previousCategoryLabels.map((item) =>
          item.id === categoryLabel.id ? categoryLabel : item
        );
      } else {
        newCategoryLabels = [categoryLabel, ...previousCategoryLabels];
      }

      queryCache.setQueryData('categoryLabels', newCategoryLabels);

      return () =>
        queryCache.setQueryData('categoryLabels', previousCategoryLabels);
    },
    onError: (err, variables, rollback) => rollback(),
    onSuccess: () => {
      queryCache.invalidateQueries('categoryLabels', { refetchInactive: true });
    },
  });
}
