import { useEffect, useState } from 'react';
import * as yup from 'yup';
import Icon from '@material-ui/core/Icon';
import { useForm } from 'react-hook-form';
import Button from '@material-ui/core/Button';
import Popover from '@material-ui/core/Popover';
import TextField from '@material-ui/core/TextField';
import IconButton from '@material-ui/core/IconButton';
import { yupResolver } from '@hookform/resolvers/yup';
import InputAdornment from '@material-ui/core/InputAdornment';
import useAddPropertyLabel from '../hooks/useAddPropertyLabel';

const validationSchema = yup.object().shape({
  title: yup.string().required(),
});

function AddLabelMenu({ t }) {
  const [anchorEl, setAnchorEl] = useState(null);

  const {
    reset,
    errors,
    register,
    handleSubmit,
    formState: { isSubmitting },
  } = useForm({
    resolver: yupResolver(validationSchema),
    defaultValues: { title: '' },
  });

  useEffect(() => {
    if (!anchorEl) {
      reset();
    }
  }, [anchorEl, reset]);

  const [addLabel] = useAddPropertyLabel();

  const handleMenuOpen = (event) => {
    setAnchorEl(event.currentTarget);
  };

  const handleMenuClose = () => {
    setAnchorEl(null);
  };

  const handleAddLabel = ({ title }) => {
    addLabel(title);
    handleMenuClose();
  };

  return (
    <div>
      <Button
        onClick={handleMenuOpen}
        variant="contained"
        color="primary"
        className="w-full"
      >
        {t('ADD_LABEL')}
      </Button>

      <Popover
        anchorEl={anchorEl}
        open={Boolean(anchorEl)}
        onClose={handleMenuClose}
        anchorOrigin={{ vertical: 'bottom', horizontal: 'center' }}
        transformOrigin={{ vertical: 'top', horizontal: 'center' }}
      >
        <>
          <form
            noValidate
            onSubmit={handleSubmit(handleAddLabel)}
            className="p-16 flex flex-col items-end"
          >
            <TextField
              required
              fullWidth
              autoFocus
              name="title"
              size="small"
              className="mb-12"
              variant="outlined"
              label={t('TITLE')}
              autoComplete="off"
              inputRef={register}
              error={!!errors?.title}
              helperText={errors?.title?.message}
              InputProps={{
                endAdornment: (
                  <InputAdornment position="end">
                    <IconButton onClick={handleMenuClose} size="small">
                      <Icon className="text-18">close</Icon>
                    </IconButton>
                  </InputAdornment>
                ),
              }}
            />
            <Button
              size="small"
              type="submit"
              color="secondary"
              variant="contained"
              disabled={isSubmitting}
            >
              {t('ADD')}
            </Button>
          </form>
        </>
      </Popover>
    </div>
  );
}

export default AddLabelMenu;
