import _ from '@lodash';
import clsx from 'clsx';
import PropTypes from 'prop-types';
import List from '@material-ui/core/List';
import Icon from '@material-ui/core/Icon';
import FuseAnimate from '@fuse/core/FuseAnimate';
import ListItem from '@material-ui/core/ListItem';
import { amber, red } from '@material-ui/core/colors';
import IconButton from '@material-ui/core/IconButton';
import { makeStyles } from '@material-ui/core/styles';
import Typography from '@material-ui/core/Typography';
import FuseAnimateGroup from '@fuse/core/FuseAnimateGroup';

const useStyles = makeStyles({
  item: {
    '&.completed': {
      background: 'rgba(0,0,0,0.03)',
      '& .label-title, & .label-description': {
        textDecoration: 'line-through',
      },
    },
  },
});

function PropertyLabelList({
  t,
  labels,
  onUpdate,
  isLoading,
  onOpenEditDialog,
}) {
  const classes = useStyles();

  if (!isLoading && labels.length === 0) {
    return (
      <FuseAnimate delay={100}>
        <div className="flex flex-1 items-center justify-center h-full">
          <Typography color="textSecondary" variant="h5">
            {t('THERE_ARE_NO_PROPERTY_LABELS')}
          </Typography>
        </div>
      </FuseAnimate>
    );
  }

  return (
    <List className="p-0">
      <FuseAnimateGroup
        enter={{
          animation: 'transition.slideUpBigIn',
        }}
      >
        {labels.map((label) => (
          <ListItem
            dense
            button
            key={label.id}
            className={clsx(
              classes.item,
              { completed: label.completed },
              'border-solid border-b-1 py-16 px-0 sm:px-8'
            )}
            onClick={(ev) => {
              ev.preventDefault();
              onOpenEditDialog(label);
            }}
          >
            <div className="flex flex-1 flex-col relative overflow-hidden px-8">
              <Typography
                variant="subtitle1"
                className="label-title truncate"
                color={label.completed ? 'textSecondary' : 'inherit'}
              >
                {label.title}
              </Typography>

              <Typography
                color="textSecondary"
                className="label-description truncate"
              >
                {_.truncate(label.description.replace(/<(?:.|\n)*?>/gm, ''), {
                  length: 180,
                })}
              </Typography>
            </div>

            <div className="px-8">
              <IconButton
                onClick={(ev) => {
                  ev.preventDefault();
                  ev.stopPropagation();
                  onUpdate({
                    ...label,
                    important: !label.important,
                  });
                }}
              >
                {label.important ? (
                  <Icon style={{ color: red[500] }}>error</Icon>
                ) : (
                  <Icon>error_outline</Icon>
                )}
              </IconButton>
              <IconButton
                onClick={(ev) => {
                  ev.preventDefault();
                  ev.stopPropagation();
                  onUpdate({
                    ...label,
                    starred: !label.starred,
                  });
                }}
              >
                {label.starred ? (
                  <Icon style={{ color: amber[500] }}>star</Icon>
                ) : (
                  <Icon>star_outline</Icon>
                )}
              </IconButton>
            </div>
          </ListItem>
        ))}
      </FuseAnimateGroup>
    </List>
  );
}

PropertyLabelList.propTypes = {
  t: PropTypes.func.isRequired,
  onUpdate: PropTypes.func.isRequired,
  isLoading: PropTypes.bool.isRequired,
  labels: PropTypes.array.isRequired,
  onOpenEditDialog: PropTypes.func.isRequired,
};

export default PropertyLabelList;
