import clsx from 'clsx';
import PropTypes from 'prop-types';
import List from '@material-ui/core/List';
import Icon from '@material-ui/core/Icon';
import Paper from '@material-ui/core/Paper';
import Input from '@material-ui/core/Input';
import Spinner from 'app/components/Spinner';
import Avatar from '@material-ui/core/Avatar';
import Toolbar from '@material-ui/core/Toolbar';
import ImageIcon from '@material-ui/icons/Image';
import ListItem from '@material-ui/core/ListItem';
import { makeStyles } from '@material-ui/core/styles';
import ListItemText from '@material-ui/core/ListItemText';

const useStyles = makeStyles((theme) => ({
  root: {
    width: '100%',
    maxWidth: 360,
    backgroundColor: theme.palette.background.paper,
  },
  header: {
    backgroundColor: theme.palette.background.default,
  },
  listItem: {
    borderBottom: `1px solid ${theme.palette.divider}`,
    '&.active': {
      backgroundColor: theme.palette.background.paper,
    },
  },
}));

function StatusIcon({ status }) {
  switch (status) {
    case 'free':
      return (
        <Icon className="block text-16 text-white bg-green rounded-full">
          check_circle
        </Icon>
      );

    case 'busy':
      return (
        <Icon className="block text-16 text-white bg-yellow-700 rounded-full">
          access_time
        </Icon>
      );
    case 'deactive':
      return (
        <Icon className="block text-16 text-grey-700 bg-white rounded-full">
          not_interested
        </Icon>
      );
    default:
      return (
        <Icon className="block text-16 text-green bg-white rounded-full">
          check_circle
        </Icon>
      );
  }
  // if (trip === 0 && status === true) {
  //   return (
  //     <Icon className="block text-16 text-white bg-green rounded-full">
  //       check_circle
  //     </Icon>
  //   );
  // }
  // if (trip === 0 && status === true) {
  //   return (
  //     <Icon className="block text-16 text-white bg-yellow-700 rounded-full">
  //       access_time
  //     </Icon>
  //   );
  // }

  // if (status === false) {
  //   return (
  //     <Icon className="block text-16 text-grey-700 bg-white rounded-full">
  //       not_interested
  //     </Icon>
  //   );
  // }
  // return (
  //   <Icon className="block text-16 text-green bg-white rounded-full">
  //     check_circle
  //   </Icon>
  // );
}

const GodsViewMasters = ({
  onClick,
  isLoading,
  masterList = [],
  searchText = '',
  onSearchTextChange,
}) => {
  const classes = useStyles();

  return (
    <div className="flex flex-auto flex-col w-full h-full px-10">
      {isLoading && <Spinner />}
      <Toolbar className={clsx(classes.header, 'px-4')}>
        <Paper className="flex p-4 items-center w-full px-8 py-4 rounded-8 shadow">
          <Icon color="action">search</Icon>
          <Input
            fullWidth
            disableUnderline
            value={searchText}
            placeholder="Search"
            className="flex flex-1 px-8"
            onChange={onSearchTextChange}
            inputProps={{ 'aria-label': 'Search' }}
          />
        </Paper>
      </Toolbar>

      <List className={clsx(classes.root, 'h-full')}>
        {masterList.map((item) => (
          <ListItem
            button
            key={item.id}
            onClick={() => onClick(item)}
            className={clsx(classes.listItem, 'px-16 py-12 min-h-92')}
          >
            <div className="relative">
              <div className="absolute right-0 bottom-0 -m-4 z-10">
                <StatusIcon status={item.status} />
              </div>

              <Avatar alt={item.masterName}>
                <ImageIcon />
              </Avatar>
            </div>
            <ListItemText
              primary={item?.masterName}
              secondary={item?.vehicle_model}
              classes={{ root: 'min-w-px px-16', secondary: 'truncate' }}
            />
          </ListItem>
        ))}
      </List>
    </div>
  );
};

GodsViewMasters.propTypes = {
  onClick: PropTypes.func.isRequired,
  isLoading: PropTypes.bool.isRequired,
  masterList: PropTypes.array.isRequired,
  searchText: PropTypes.string.isRequired,
  onSearchTextChange: PropTypes.func.isRequired,
};

StatusIcon.propTypes = {
  status: PropTypes.string.isRequired,
};

export default GodsViewMasters;
