import PropTypes from 'prop-types';
import busyTaxiIcon from './taxi_busy.png';
import freeTaxiIcon from './taxi_free.png';
import Badge from '@material-ui/core/Badge';
import Tooltip from '@material-ui/core/Tooltip';
import { toLocaleDigits } from 'app/utils/string';
import deactivateTaxiIcon from './taxi_deactive.png';

function getMarkerIcon(type) {
  switch (type) {
    case 'free':
      return freeTaxiIcon;
    case 'busy':
      return busyTaxiIcon;
    case 'deactive':
    default:
      return deactivateTaxiIcon;
  }
}
// function getColor(type) {
//   switch (type) {
//     case 'free':
//       return 'green';
//     case 'busy':
//       return 'blue';
//     case 'deactive':
//       return 'gray-700';
//     case 'all':
//     default:
//       return 'red';
//   }
// }

const Marker = ({
  data,
  onClick,
  onHover,
  onLeave,
  isHovered,
  currentLang,
}) => {
  return (
    <Tooltip
      arrow
      placement="top"
      open={isHovered}
      onOpen={onHover}
      onClose={onLeave}
      title={data.masterName}
      PopperProps={{ disablePortal: true }}
    >
      <Badge
        color="secondary"
        badgeContent={toLocaleDigits(data.trip, currentLang)}
      >
        <img
          width="50"
          height="32"
          onClick={onClick}
          alt={data.masterName}
          src={getMarkerIcon(data.status)}
          className="absolute top-1/2 ltr:left-1/2 rtl:right-1/2 select-none cursor-pointer text"
        />
        {/* <Icon
        className={`absolute top-1/2 left-1/2 select-none cursor-pointer text-${getColor(
          data.status
        )}`}
        fontSize="large"
        onClick={onClick}
      >
        local_taxi
      </Icon> */}
      </Badge>
    </Tooltip>
  );
};

Marker.propTypes = {
  onClick: PropTypes.func.isRequired,
  onHover: PropTypes.func.isRequired,
  onLeave: PropTypes.func.isRequired,
  isHovered: PropTypes.bool.isRequired,
  currentLang: PropTypes.string.isRequired,
  data: PropTypes.shape({
    masterName: PropTypes.string.isRequired,
    status: PropTypes.string.isRequired,
    trip: PropTypes.number.isRequired,
  }),
};

export default Marker;
