import clsx from 'clsx';
import PropTypes from 'prop-types';
import Dialog from '@material-ui/core/Dialog';
import AppBar from '@material-ui/core/AppBar';
import { useTranslation } from 'react-i18next';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import { makeStyles } from '@material-ui/core/styles';
import DialogContent from '@material-ui/core/DialogContent';
import DialogCloseButton from 'app/components/DialogCloseButton';

const useStyles = makeStyles({
  table: { '& th': { padding: '16px 0' } },
});

const MasterInfoDialog = ({ isOpen, onClose, selectedItem }) => {
  const { t } = useTranslation('reports');

  const classes = useStyles();

  return (
    <Dialog
      fullWidth
      maxWidth="sm"
      open={isOpen}
      disablePortal
      onClose={onClose}
      classes={{ paper: 'rounded-8' }}
    >
      <AppBar position="static" elevation={1}>
        <Toolbar className="flex w-full">
          <Typography variant="subtitle1" color="inherit">
            {t('dialog_title')}
          </Typography>
        </Toolbar>
        <DialogCloseButton onClick={onClose} />
      </AppBar>

      <DialogContent>
        <div className="mb-16">
          <table className={clsx(classes.table, 'w-full text-justify')}>
            <tbody className="text-center">
              <tr>
                <th>Name</th>
                <td>{selectedItem.masterName}</td>
              </tr>

              <tr>
                <th>Vehicle Model</th>
                <td>{selectedItem.vehicle_model}</td>
              </tr>
            </tbody>
          </table>
        </div>
      </DialogContent>
    </Dialog>
  );
};

MasterInfoDialog.propTypes = {
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  selectedItem: PropTypes.object.isRequired,
};

export default MasterInfoDialog;
