import { useCallback, useEffect, useRef } from 'react';
import clsx from 'clsx';
import PropTypes from 'prop-types';
import Paper from '@material-ui/core/Paper';
import InputBase from '@material-ui/core/InputBase';
import { makeStyles } from '@material-ui/core/styles';

const useStyles = makeStyles((theme) => {
  console.log({ theme });
  return {
    root: {
      padding: 4,
      display: 'flex',
      alignItems: 'center',
      position: 'absolute',
      top: 10,
      right: theme.direction === 'ltr' ? 60 : null,
      left: theme.direction === 'rtl' ? 60 : null,
      zIndex: 1,
    },
    input: {
      marginLeft: theme.spacing(1),
      flex: 1,
    },
  };
});

const SearchBox = ({ mapInstance, mapApi }) => {
  const searchBoxRef = useRef();
  const searchInputRef = useRef();

  const classes = useStyles();

  const onPlacesChanged = useCallback(() => {
    const selected = searchBoxRef.current.getPlaces();
    const { 0: place } = selected;

    if (!place.geometry) {
      return;
    }

    if (place.geometry.viewport) {
      mapInstance.fitBounds(place.geometry.viewport);
    } else {
      mapInstance.setCenter(place.geometry.location);
      mapInstance.setZoom(17);
    }

    searchInputRef.current.blur();
  }, [mapInstance]);

  useEffect(() => {
    console.log('useeffect search box');
    const { places, event } = mapApi;

    searchBoxRef.current = new places.SearchBox(searchInputRef.current);

    // map.controls[window.google.maps.ControlPosition.TOP_RIGHT].push(
    //   searchInputRef.current
    // );

    searchBoxRef.current.addListener('places_changed', onPlacesChanged);

    return () => {
      event.clearInstanceListeners(searchBoxRef.current);
    };
  }, [mapApi, onPlacesChanged]);

  const clearSearchBox = () => {
    searchInputRef.current.value = '';
  };

  return (
    <Paper className={clsx(classes.root, 'w-1/2 sm:w-400')} elevation={2}>
      <InputBase
        autoComplete="off"
        onFocus={clearSearchBox}
        className={classes.input}
        inputRef={searchInputRef}
        placeholder="Search Google Maps"
        inputProps={{ 'aria-label': 'search google maps' }}
      />
    </Paper>
  );
};

SearchBox.propTypes = {
  mapApi: PropTypes.object.isRequired,
  mapInstance: PropTypes.object.isRequired,
};

export default SearchBox;
