import { useState, useRef } from 'react';
import clsx from 'clsx';
import * as yup from 'yup';
import { Link } from 'react-router-dom';
import Card from '@material-ui/core/Card';
import Icon from '@material-ui/core/Icon';
import { useForm } from 'react-hook-form';
import Button from '@material-ui/core/Button';
import { useTranslation } from 'react-i18next';
import FuseAnimate from '@fuse/core/FuseAnimate';
import TextField from '@material-ui/core/TextField';
import { yupResolver } from '@hookform/resolvers/yup';
import { makeStyles } from '@material-ui/core/styles';
import Typography from '@material-ui/core/Typography';
import IconButton from '@material-ui/core/IconButton';
import { useDispatch, useSelector } from 'react-redux';
import CardContent from '@material-ui/core/CardContent';
import { submitRegister } from 'app/auth/store/registerSlice';
import InputAdornment from '@material-ui/core/InputAdornment';
import { darken } from '@material-ui/core/styles/colorManipulator';
import { green } from '@material-ui/core/colors';
import CircularProgress from '@material-ui/core/CircularProgress';
import FormControl from "@material-ui/core/FormControl";
import FormControlLabel from "@material-ui/core/FormControlLabel";
import Checkbox from "@material-ui/core/Checkbox";

const useStyles = makeStyles((theme) => ({
  root: {
    background: `linear-gradient(to left, ${theme.palette.primary.dark
      } 0%, ${darken(theme.palette.primary.dark, 0.5)} 100%)`,
    color: theme.palette.primary.contrastText,
  },
  leftSection: {},
  rightSection: {
    background: green[500],

  },
  buttonProgress: {
    color: green[500],
    position: 'absolute',
    top: '50%',
    left: '50%',
    marginTop: -8,
    marginLeft: -12,
  },
  rootwrapper: {
    display: 'flex',
    '& > *': {
      margin: theme.spacing(1),
    },
  },

  wrapper: {
    margin: theme.spacing(1),
    position: 'relative',
    width: '-moz-available',
  },
  buttonSuccess: {
    backgroundColor: green[500],
    '&:hover': {
      backgroundColor: green[700],
    },
  },
  loginstyle: {
    '& > *': {
      margin: theme.spacing(2),
    },
  },

}));

const validationSchema = yup.object().shape({
  name: yup.string().required(),
  family: yup.string().required(),
  nationalityCode: yup.string().required(),
  mobile: yup.string().required(),
});

function Congratulations() {
  const { t } = useTranslation('loginPage');

  const classes = useStyles();
  const [showPassword, setShowPassword] = useState(false);

  const [loading, setLoading] = useState(false);
  const [success, setSuccess] = useState(false);
  const timer = useRef();

  const dispatch = useDispatch();
  const login = useSelector(({ auth }) => auth.login);

  const { register, errors, handleSubmit } = useForm({
 
    resolver: yupResolver(validationSchema),
  });

  const handleSubmitCongratulations = (data) => {
    dispatch(submitRegister(data));
  };


  const handleButtonClick = () => {
    if (!loading) {
      setSuccess(false);
      setLoading(true);
      timer.current = window.setTimeout(() => {
        setSuccess(true);
        setLoading(false);
      }, 2000);
    }
  };

  return (
    <div
      className={clsx(
        classes.root,
        'flex flex-col flex-auto items-center justify-center flex-shrink-0 p-16 md:p-24'
      )}
    >
      <FuseAnimate animation="transition.expandIn">
        <div className="flex w-full max-w-400 md:max-w-3xl rounded-12 shadow-2xl overflow-hidden">
          <Card
            className={clsx(
              classes.leftSection,
              'flex flex-col w-full max-w-sm items-center pr-0 pl-0 pb-32 justify-center'
            )}
            square
            elevation={0}
          >
            <CardContent className="flex flex-col items-center justify-center w-full p-0 pt-16 max-w-320">
            <FuseAnimate delay={300}>
                <div className="mb-36">
                 <div className="mb-4 flex items-center justify-center ">
                    <img
                      alt="logo"
                      className="mb-4 mt-4"
                      src={`${process.env.PUBLIC_URL}/assets/images/sbsms/done.png`}
                    />
                  </div>
                 
                    <div className="mb-16 flex-wrap items-center justify-center ">
                      <Typography
                        variant="h5"
                        color="inherit"
                        className="text-center justify-center  "
                      >
                          {t('CONGRATULATION')}
                      </Typography>
                    </div>


                    <div className="mb-24 flex-wrap items-center justify-center ">
                      <Typography
                        variant="subtitle1"
                        color="inherit"
                        className="text-center justify-center  "
                      >
                         {t('CONGRATULATION_titleend')}

                      </Typography>
                      <Typography
                        variant="subtitle1"
                        color="inherit"
                        className="items-center justify-center flex-shrink-0"
                      >
                         {t('CONGRATULATION_subtitleend')}
                
                      </Typography>
                    </div>

                  
                </div>
              </FuseAnimate>

              <div className="w-full pt-64">
                <form
                  noValidate
                  name="loginForm"
                  onSubmit={handleSubmit(handleSubmitCongratulations)}
                  className="flex flex-col justify-center w-full"
                >
                      
                  
                      


                  <div className={classes.rootwrapper}>
                    <div className={clsx(classes.wrapper, "pl-4 p-0 mx-0")}>
                      <Button
                        type="submit"
                        variant="contained"
                        color="primary"
                        className={clsx(classes.buttonSuccess, "w-full")} 
                        onClick={handleButtonClick}
                        aria-label={t('LOGINPANEL')}
                        disabled={loading}
                      >
                        {t('LOGINPANEL')}
                      </Button>
                      {loading && <CircularProgress size={24} className={classes.buttonProgress} />}

                    </div>
                   
                  </div>
                </form>
              </div>
            </CardContent>




          </Card>

          <div
            className={clsx(
              classes.rightSection,
              'hidden md:flex flex-1 items-center justify-center p-64'
            )}

          >
            <div className="max-w-330 ">

              <FuseAnimate delay={300}>
                <div className="mb-8 flex items-center justify-center">
                  <FuseAnimate animation="transition.expandIn">
                    <img
                      alt="logo"
                      className="mb-4 mt-4"
                      src={`${process.env.PUBLIC_URL}/assets/images/sbsms/SIGNUP3.png`}
                    />
                  </FuseAnimate>
                </div>
              </FuseAnimate>

              <FuseAnimate animation="transition.slideUpIn" delay={400}>
                <div className="mb-8 flex-wrap ">
                  <Typography
                    variant="h6"
                    color="inherit"
                    className="text-center justify-center  "
                  >
                    {t('CONGRATULATION_title')}
                  </Typography> 
                </div>
              </FuseAnimate>


            </div>
          </div>
        </div>
      </FuseAnimate>
    </div>
  );
}

export default Congratulations;
