import { useState, useRef } from 'react';
import clsx from 'clsx';
import * as yup from 'yup';
import { Link } from 'react-router-dom';
import Card from '@material-ui/core/Card';
import Icon from '@material-ui/core/Icon';
import { useForm } from 'react-hook-form';
import Button from '@material-ui/core/Button';
import { useTranslation } from 'react-i18next';
import FuseAnimate from '@fuse/core/FuseAnimate';
import { yupResolver } from '@hookform/resolvers/yup';
import { makeStyles } from '@material-ui/core/styles';
import Typography from '@material-ui/core/Typography';
import { useDispatch, useSelector } from 'react-redux';
import CardContent from '@material-ui/core/CardContent';
import { submitRegister } from 'app/auth/store/registerSlice';
import InputAdornment from '@material-ui/core/InputAdornment';
import { darken } from '@material-ui/core/styles/colorManipulator';
import { green, blue } from '@material-ui/core/colors';
import CircularProgress from '@material-ui/core/CircularProgress';
import InputCode from "./component/InputCode";
import "./styles.css";


const useStyles = makeStyles((theme) => ({
  root: {
    background: `linear-gradient(to left, ${theme.palette.primary.dark
      } 0%, ${darken(theme.palette.primary.dark, 0.5)} 100%)`,
    color: theme.palette.primary.contrastText,
  },
  leftSection: {},
  rightSection: {
    background: blue[500],
  },
  secondaryHeading: {
    fontSize: theme.typography.pxToRem(12),
    color: theme.palette.text.secondary,
  },
  buttonProgress: {
    color: green[500],
    position: 'absolute',
    top: '50%',
    left: '50%',
    marginTop: -8,
    marginLeft: -12,
  },
  rootwrapper: {
    display: 'flex',
    '& > *': {
      margin: theme.spacing(1),
    },
  },

  wrapper: {
    margin: theme.spacing(1),
    position: 'relative',
    width: '-moz-available',
  },
  buttonSuccess: {
    backgroundColor: green[500],
    '&:hover': {
      backgroundColor: green[700],
    },
  },
  loginstyle: {
    '& > *': {
      margin: theme.spacing(2),
    },
  },
  inputcode: {
    direction: 'ltr'
  }

}));

const validationSchema = yup.object().shape({
  name: yup.string().required(),
  family: yup.string().required(),
  nationalityCode: yup.string().required(),
  mobile: yup.string().required(),
});

function Verifycode() {
  const { t } = useTranslation('loginPage');

  const classes = useStyles();

  const [loading, setLoading] = useState(false);
  const [success, setSuccess] = useState(false);
  const timer = useRef();

  const dispatch = useDispatch();
  const login = useSelector(({ auth }) => auth.login);

  const { register, errors, handleSubmit } = useForm({

    resolver: yupResolver(validationSchema),
  });

  const handleSubmitVerifycode = (data) => {
    dispatch(submitRegister(data));
  };


  const handleButtonClick = () => {
    if (!loading) {
      setSuccess(false);
      setLoading(true);
      timer.current = window.setTimeout(() => {
        setSuccess(true);
        setLoading(false);
      }, 2000);
    }
  };

  return (
    <div
      className={clsx(
        classes.root,
        'flex flex-col flex-auto items-center justify-center flex-shrink-0 p-16 md:p-24'
      )}
    >
      <FuseAnimate animation="transition.expandIn">
        <div className="flex w-full max-w-400 md:max-w-3xl rounded-12 shadow-2xl overflow-hidden">
          <Card
            className={clsx(
              classes.leftSection,
              'flex flex-col w-full max-w-sm items-center pr-0 pl-0 pb-32 justify-center'
            )}
            square
            elevation={0}
          >
            <CardContent className="flex flex-col items-center justify-center w-full p-0 pt-16 max-w-320">


              <div className="w-full">
                <form
                  noValidate
                  name="loginForm"
                  onSubmit={handleSubmit(handleSubmitVerifycode)}
                  className="flex flex-col justify-center w-full"
                >
                  <InputCode
                    length={6}
                    label="لطفاً کد دریافتی را در کادر زیر وارد نمایید"
                    loading={loading}
                    className={clsx(classes.inputcode, " flex flex-col justify-center w-full")}
                    onComplete={code => {
                      setLoading(true);
                      setTimeout(() => setLoading(false), 10000);
                    }}
                  />
                  <Typography 
                    color=""
                    className={classes.secondaryHeading}  
                  >
                    {t('PLEASE_INSER_VERIFY_CODE')}
                  </Typography>


                  <div className="flex items-center pt-24 pb-64 justify-between">
                    <Button  onClick={handleButtonClick}  >
                      ارسال مجدد کد فعال سازی ؟
                    </Button>

                  </div>

                  <div className={classes.rootwrapper}>
                    <div className={clsx(classes.wrapper, "pl-4 p-0 mx-0")}>
                      <Button
                        type="submit"
                        variant="contained"
                        color="primary"
                        className={clsx(classes.buttonSuccess, "min-w-160")}
                        onClick={handleButtonClick}
                        aria-label={t('NEXT')}
                        disabled={loading}
                      >
                        {t('NEXT')}
                      </Button>
                      {loading && <CircularProgress size={24} className={classes.buttonProgress} />}

                    </div>
                    <div className={clsx(classes.wrapper, "pr-4 p-0 mx-0")}>
                      <Link to="/login" >
                        <Button
                          variant="contained"
                          color="primary"
                          className="min-w-160 mx-auto  normal-case"
                          aria-label={t('PREVIOUS')}
                        >
                          {t('[PREVIOUS]')}
                        </Button>
                      </Link>
                    </div>
                  </div>
                </form>
              </div>
            </CardContent>




          </Card>

          <div
            className={clsx(
              classes.rightSection,
              'hidden md:flex flex-1 items-center justify-center p-64'
            )}

          >
            <div className="max-w-320 ">

              <FuseAnimate delay={300}>
                <div className="mb-8 flex items-center justify-center ">
                  <FuseAnimate animation="transition.expandIn">
                    <img
                      alt="logo"
                      className="mb-4 mt-4"
                      src={`${process.env.PUBLIC_URL}/assets/images/logos/SIGNUP1.png`}
                    />
                  </FuseAnimate>
                </div>
              </FuseAnimate>

              <FuseAnimate animation="transition.slideUpIn" delay={400}>
                <div className="mb-8 flex-wrap ">
                  <Typography
                    variant="h6"
                    color="inherit"
                    className="text-center justify-center  "
                  >
                    {t('VERYFY_CODE_title')}
                  </Typography>

                </div>
              </FuseAnimate>


            </div>
          </div>
        </div>
      </FuseAnimate>
    </div >
  );
}

export default Verifycode;
