import React, { useState } from "react";
import * as yup from "yup";
import PropTypes from "prop-types";
import ContactBox from "../ContactBox";
import Button from "@material-ui/core/Button";
import Select from "@material-ui/core/Select";
import Switch from "@material-ui/core/Switch";
import MessageInvoice from "../MessageInvoice";
import Divider from "@material-ui/core/Divider";
import MenuItem from "@material-ui/core/MenuItem";
import { yupResolver } from "@hookform/resolvers/yup";
import MessageBox from "app/components/MessageBox";
import InputLabel from "@material-ui/core/InputLabel";
import { DateTimePicker } from "@material-ui/pickers";
import { useForm, Controller } from "react-hook-form";
import FuseChipSelect from "@fuse/core/FuseChipSelect";
import FormControl from "@material-ui/core/FormControl";
import OutlinedInput from "@material-ui/core/OutlinedInput";
import FormHelperText from "@material-ui/core/FormHelperText";
import FormControlLabel from "@material-ui/core/FormControlLabel";

const groupsData = [
  "مشتریان پنل ( ۴۰۰ )",
  "نمایندگان پنل ( ۱۰ )",
  "همکاران ( ۶۰ )",
].map((item) => ({
  value: item,
  label: item,
}));

const validationSchema = yup.object().shape({
  // groups: yup.string().required(),
});

const BulkMessage = (props) => {
  const { register, handleSubmit, control, errors } = useForm({
    defaultValues: {
      text: "",
      groups: [],
      contacts: "",
      sendNumber: "",
      sendDate: null,
      removeDuplicates: false,
      doNotSendToSpecialList: false,
    },
    resolver: yupResolver(validationSchema),
  });

  const handleSendMessage = (data) => console.log({ data });

  return (
    <div className="flex flex-wrap">
      <div className="w-full md:w-3/6 p-12">
        <form onSubmit={handleSubmit(handleSendMessage)}>
          <div>
            <div className="flex w-full mb-16">
              <Controller
                isMulti
                name="groups"
                control={control}
                className="w-full"
                as={FuseChipSelect}
                options={groupsData}
                placeholder="انتخاب گروه"
                textFieldProps={{
                  label: "انتخاب گروه",
                  InputLabelProps: {
                    shrink: true,
                  },
                  variant: "outlined",
                }}
              />
            </div>
            <Divider className="my-32" />
          </div>

          <div>
            <Controller
              name="contacts"
              as={ContactBox}
              control={control}
              showAddButton={false}
            />

            <Divider className="my-32" />
          </div>

          <div>
            <Controller name="text" control={control} as={MessageBox} />
            <Divider className="my-32" />
          </div>

          <div>
            <FormControl
              variant="outlined"
              error={!!errors?.sendNumber}
              className="flex w-full mt-8 mb-16"
            >
              <InputLabel htmlFor="send-number-label-placeholder">
                ارسال از شماره
              </InputLabel>
              <Select
                error={!!errors?.sendNumber}
                input={
                  <Controller
                    name="sendNumber"
                    control={control}
                    as={OutlinedInput}
                    id="send-number-label-placeholder"
                    labelWidth={"ار سال از شماره".length * 6}
                  />
                }
              >
                <MenuItem value="123456">
                  <em>123456</em>
                </MenuItem>
                <MenuItem value="1587878">
                  <em>1587878</em>
                </MenuItem>
                <MenuItem value="9898565">
                  <em>9898565</em>
                </MenuItem>
                <MenuItem value="787878">
                  <em>787878</em>
                </MenuItem>
              </Select>
              {errors?.sendNumber && (
                <FormHelperText>{errors?.sendNumber?.message}</FormHelperText>
              )}
            </FormControl>
            <Divider className="my-32" />
          </div>

          <div>
            <FormControl
              className="flex w-full mt-8 mb-16"
              variant="outlined"
              style={{ direction: "rtl" }}
            >
              <Controller
                name="sendDate"
                control={control}
                as={DateTimePicker}
                autoOk
                clearable
                disablePast
                showTodayButton
                okLabel="تأیید"
                cancelLabel="لغو"
                label="زمان ارسال"
                todayLabel="امروز"
                clearLabel="پاک کردن"
                inputVariant="outlined"
                labelFunc={(date) =>
                  date ? date.format("jYYYY/jMM/jDD HH:mm") : ""
                }
              />
            </FormControl>
            <Divider className="my-32" />
          </div>

          <div className="my-16">
            <FormControlLabel
              control={
                <Switch name="doNotSendToSpecialList" inputRef={register} />
              }
              label="عدم ارسال به لیست ویژه"
            />
            <FormHelperText id="my-helper-text">
              این گزینه بدین معنی است که پیامک به شماره های موجود در لیست ویژه
              ارسال نمی شود
            </FormHelperText>

            <Divider className="my-32" />
          </div>

          <div className="my-16">
            <FormControlLabel
              control={<Switch name="removeDuplicates" inputRef={register} />}
              label="عدم ارسال تکراری"
            />
            <FormHelperText id="my-helper-text">
              این گزینه بدین معنی است اگر در گروه های انتخاب شده شماره تکراری
              وجود داشت حذف شود
            </FormHelperText>
          </div>

          <div className="mt-32 mb-8">
            <Button
              type="button"
              className="mx-8"
              color="secondary"
              variant="contained"
            >
              محاسبه صورت حساب
            </Button>
            <Button variant="contained" className="mx-8" type="button">
              ارسال پیامک تستی
            </Button>
            <Button variant="contained" color="primary" type="submit">
              ارسال پیامک
            </Button>
          </div>
        </form>
      </div>
      <div className="w-full md:w-3/6 p-12">
        <MessageInvoice />
      </div>
    </div>
  );
};

BulkMessage.propTypes = {};

export default BulkMessage;
