import React from "react";
import PropTypes from "prop-types";
import Input from "@material-ui/core/Input";
import Paper from "@material-ui/core/Paper";
import AppBar from "@material-ui/core/AppBar";
import { toPersianDigits } from "app/utils/string";
import Typography from "@material-ui/core/Typography";
import SelectContactModal from "../SelectContactModal";

function countContactNumbers(contactsValue) {
  const contactsArray = contactsValue.split("\n");
  return contactsArray.filter(Boolean).length;
}

const ContactBox = ({
  value,
  onChange,
  showAddButton = true,
  label = "شماره گیرندگان",
}) => {
  const handleChange = (event) => {
    onChange(event.target.value);
  };

  const handleSelectContact = (contact) => {
    onChange(value + contact?.mobile + "\n");
  };

  return (
    <Paper className="w-full rounded-8 shadow-1 overflow-hidden">
      <div className="flex items-center justify-between px-16 h-52 border-b-1">
        <Typography className="text-16">{label}</Typography>

        {showAddButton && <SelectContactModal onSelect={handleSelectContact} />}
      </div>

      <Input
        rows="6"
        multiline
        margin="none"
        value={value}
        disableUnderline
        className="p-16 w-full"
        onChange={handleChange}
        classes={{ root: "text-14" }}
        placeholder="شماره‌ها را وارد کنید"
      />
      <AppBar
        className="card-footer border-t-1"
        position="static"
        color="default"
        elevation={0}
      >
        <div className="rounded-2 mb-8 md:mb-0 h-32 whitespace-no-wrap inline-flex items-center">
          <div className="px-12">
            <span className="text-red-500 ml-4">
              {toPersianDigits(countContactNumbers(value))}
            </span>
            <span>شماره</span>
          </div>
        </div>
      </AppBar>
    </Paper>
  );
};

ContactBox.propTypes = {
  value: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
  showAddButton: PropTypes.bool,
};

export default ContactBox;
