import React from "react";
import * as yup from "yup";
import Alert from "@material-ui/lab/Alert";
import AlertTitle from "@material-ui/lab/AlertTitle";
import Radio from "@material-ui/core/Radio";
import Button from "@material-ui/core/Button";
import Select from "@material-ui/core/Select";
import Switch from "@material-ui/core/Switch";
import MenuItem from "@material-ui/core/MenuItem";
import { yupResolver } from "@hookform/resolvers/yup";
import MessageBox from "app/components/MessageBox";
import TextField from "@material-ui/core/TextField";
import { DropzoneArea } from "material-ui-dropzone";
import PreviewMessageBox from "../PreviewMessageBox";
import InputLabel from "@material-ui/core/InputLabel";
import { useForm, Controller } from "react-hook-form";
import RadioGroup from "@material-ui/core/RadioGroup";
import FormControl from "@material-ui/core/FormControl";
import OutlinedInput from "@material-ui/core/OutlinedInput";
import FormHelperText from "@material-ui/core/FormHelperText";
import FormControlLabel from "@material-ui/core/FormControlLabel";
import InputAdornment from '@material-ui/core/InputAdornment';
import {   withStyles, } from '@material-ui/core/styles';

const ValidationTextField = withStyles({
  root: {
    '& input:valid + fieldset': {
     // borderColor: 'green',
      borderWidth: 1,
    },
    '& input:invalid + fieldset': {
      borderColor: 'red',
      borderWidth: 2,
    },
    '& input:valid:focus + fieldset': {
      borderLeftWidth: 6,
      padding: '4px !important', // override inline-style
    },
  },
})(TextField);
const validationSchema = yup.object().shape({
  sendNumber: yup.string().required(),
});

const P2PMessage = (props) => {
  const { register, handleSubmit, control, errors, watch } = useForm({
    defaultValues: {
      title: "",
      file: null,
      sendNumber: "123456",
      appendText: true,
      appendType: "beginning",
      appendedText: "",
      previewText: "",
      doNotSendToSpecialList: false,
    },
    resolver: yupResolver(validationSchema),
  });

  const handleSendMessage = (data) => console.log({ data });

  const appendText = watch("appendText");

  return (
    <div className="flex flex-wrap">
      <div className="w-full md:w-3/6 p-12">
        <form onSubmit={handleSubmit(handleSendMessage)}>


          <ValidationTextField
            autoFocus
            fullWidth
            type="text"
            name="title"
            label="عنوان ارسال"
            margin="dense"
            variant="outlined"
            inputRef={register}
            className="mt-0 mb-20"
            InputProps={{
              startAdornment: <InputAdornment position="start"> </InputAdornment>,
            }}
          />

          <div className="mb-20">
            <Controller
              name="file"
              filesLimit={1}
              as={DropzoneArea}
              control={control}
              showAlerts={false}
              dropzoneParagraphClass="text-18"
              dropzoneClass="min-h-208 bg-light-blue-50 border-1 border-blue-500"
              dropzoneText="برای آپلود اینجا کلیک کنید یا فایل را به اینجا بکشید"
            />
          </div>

          <FormControl
            className="flex w-full mb-20"
            variant="outlined"
            error={!!errors?.sendNumber}
          >
            <InputLabel htmlFor="send-number-label-placeholder">
              ارسال از شماره
            </InputLabel>
            <Select
              error={!!errors?.sendNumber}
              input={
                <Controller
                  name="sendNumber"
                  control={control}
                  as={OutlinedInput}
                  id="send-number-label-placeholder"
                  labelWidth={"ار سال از شماره".length * 6}
                />
              }
            >
              <MenuItem value="123456">
                <em>123456</em>
              </MenuItem>
              <MenuItem value="1587878">
                <em>1587878</em>
              </MenuItem>
              <MenuItem value="9898565">
                <em>9898565</em>
              </MenuItem>
              <MenuItem value="787878">
                <em>787878</em>
              </MenuItem>
            </Select>
            {errors?.sendNumber && (
              <FormHelperText>{errors?.sendNumber?.message}</FormHelperText>
            )}
          </FormControl>

          <div className="mb-20">
            <FormControlLabel
              control={
                <Controller
                  name="appendText"
                  render={(props) => (
                    <Switch
                      checked={props.value}
                      onChange={(e) => props.onChange(e.target.checked)}
                    />
                  )}
                  control={control}
                />
              }
              label="چسباندن متن به ارسال"
            />
          </div>

          {appendText && (
            <FormControl className="mb-20">
              <Controller
                render={(props) => (
                  <RadioGroup
                    row
                    aria-label="append type"
                    {...props}
                    name="appendType"
                  >
                    <FormControlLabel
                      value="beginning"
                      control={<Radio />}
                      label="چسباندن متن به ابتدا"
                    />
                    <FormControlLabel
                      value="end"
                      control={<Radio />}
                      label="چسباندن متن به انتها"
                    />
                  </RadioGroup>
                )}
                name="appendType"
                control={control}
              />
            </FormControl>
          )}

          {appendText && (
            <div className="mb-20">
              <Controller
                as={MessageBox}
                control={control}
                name="appendedText"
                title="متن چسباندن"
              />
            </div>
          )}

          <div className="mb-20">
            <Controller
              name="previewText"
              control={control}
              as={PreviewMessageBox}
            />
          </div>

          <div className="mb-20">
            <FormControlLabel
              control={
                <Controller
                  name="doNotSendToSpecialList"
                  render={(props) => (
                    <Switch
                      checked={props.value}
                      onChange={(e) => props.onChange(e.target.checked)}
                    />
                  )}
                  control={control}
                />
              }
              label="عدم ارسال به لیست ویژه"
            />
          </div>

          <div className="mb-20">
            <Button
              type="button"
              className="mx-8"
              color="secondary"
              variant="contained"
            >
              ارسال پیامک تستی
            </Button>
            <Button variant="contained" color="primary" type="submit">
              ارسال پیامک
            </Button>
          </div>
        </form>
      </div>
      <div className="w-full md:w-3/6 p-12">
        <Alert severity="info" className="mt-8 mb-20">
          <AlertTitle>موجودی پیامک</AlertTitle>
          لطفا قبل از ارسال از کافی بدون اعتبار خود اطمینان حاصل نمایید.
        </Alert>
        <Alert severity="info" className="mb-20">
          <AlertTitle>فایل اکسل سه ستونی</AlertTitle>
          <p>فایل اکسل سه ستونی باید شامل:</p>
          <p>
            ستون اول شماره فرستنده، ستون دوم شماره گیرنده و ستون سوم حاوی متن
            ارسالی است.
          </p>
          <Button
            size="small"
            type="button"
            className="mt-12"
            color="secondary"
            variant="contained"
          >
            دانلود فایل نمونه
          </Button>
        </Alert>

        <Alert severity="info" className="mb-20">
          <AlertTitle>فایل اکسل دو ستونی</AlertTitle>
          <p>
            فایل اکسل دو ستونی باید شامل: ستون اول شماره گیرنده و ستون دوم حاوی
            متن ارسالی است.
          </p>
          <div className="mt-16 text-red-500">نکته:</div>
          <p>
            شماره ارسال در این روش از لیست شماره ارسال پیش فرض استفاده می کنید
            که قابل انتخاب است
          </p>
          <Button
            size="small"
            type="button"
            className="mt-12"
            color="secondary"
            variant="contained"
          >
            دانلود فایل نمونه
          </Button>
        </Alert>

        <Alert severity="info" className="mb-20">
          <AlertTitle>فرمت شماره موبایل‌ها</AlertTitle>
          شماره ها با فرمت زیر قابل شناسایی است:
          <br />
          ۹۸۹xxxxxxx+
          <br />
          ۹۸۹xxxxxxx
          <br />
          ۹xxxxxxx
          <br />
          ۰۹xxxxxxx
        </Alert>
        <Alert severity="info" className="mb-20">
          <AlertTitle>چسباندن متن به ارسال</AlertTitle>
          این گزینه برای مواردی که لازم به افزودن متنی به ابتدا یا انتهای متن
          تنظیم شده نظیر به نظیر فایل آپلود شده کاربرد دارد و متن اضافه شده به
          ابتدا یا انتها به تمامی متن های ارسال فایل ارسال اضافه می شود.
        </Alert>
        <Alert severity="info" className="mb-20">
          <AlertTitle>عدم ارسال به لیست ویژه</AlertTitle>
          با فعال کردن این گزینه شما به سیستم این اجازه را می‌دهید که شماره‌های
          موجود جهات ارسال نظیر به نظیر ابتدا با لیست ویژه (شماره‌‌هایی که نباید
          ارسال به آنها انجام شود) مقایسه شده و شماره های موجود در لیست، از لیست
          ارسال حذف شده و به آنها ارسال انجام نمی‌شود.
        </Alert>
        <Alert severity="info" className="mb-20">
          <AlertTitle>پیش نمایش متن</AlertTitle>
          با کلیک بر روی گزینه نمایش متن، سیستم اولین ردیف فایل اکسل یا فایل
          متنی که آپلود کرده اید را خوانده و متن ارسال و اولین شماره را برای شما
          نمایش می‌دهد. این مورد صرافا جهت بررسی صحت فایل بارگذاری شده جهت ارسال
          است و ردیف های بعدی فایل قابل مشاهده نیست.
        </Alert>
      </div>
    </div>
  );
};

P2PMessage.propTypes = {};

export default P2PMessage;
