import React from "react";
import PropTypes from "prop-types";
import Input from "@material-ui/core/Input";
import Paper from "@material-ui/core/Paper";
import AppBar from "@material-ui/core/AppBar";
import Button from "@material-ui/core/Button";
import { toPersianDigits } from "app/utils/string";
import Typography from "@material-ui/core/Typography";
import AutorenewIcon from "@material-ui/icons/Autorenew";

const PreviewMessageBox = ({ value, onChange }) => {
  const handleChange = (event) => {
    onChange(event.target.value);
  };

  return (
    <Paper className="w-full rounded-8 shadow-1 overflow-hidden">
      <div className="flex items-center justify-between px-16 h-52 border-b-1">
        <Typography className="text-16">پیش نمایش اولین ردیف ارسال</Typography>
        <Button
          size="small"
          color="secondary"
          variant="outlined"
          startIcon={<AutorenewIcon />}
          // onClick={handleOpenDialog}
        >
          نمایش متن
        </Button>
      </div>

      <Input
        rows="6"
        multiline
        margin="none"
        value={value}
        disableUnderline
        onChange={handleChange}
        className="p-16 w-full"
        classes={{ root: "text-14" }}
        placeholder="برای پیش نمایش متن از دکمه نمایش متن استفاده کنید"
      />
      <AppBar
        className="flex card-footer border-t-1"
        position="static"
        color="default"
        elevation={0}
      >
        <div className="rounded-2 mb-8 md:mb-0 h-32 whitespace-no-wrap inline-flex items-center">
          <div className="px-12">
            متن بالا به شماره{" "}
            <span className="text-red-500 mr-4">
              {toPersianDigits("09171112222")}
            </span>{" "}
            ارسال خواهد شد
          </div>
        </div>
      </AppBar>
    </Paper>
  );
};

PreviewMessageBox.propTypes = {
  title: PropTypes.string,
  value: PropTypes.string.isRequired,
  onChange: PropTypes.func.isRequired,
};

export default PreviewMessageBox;
