import React, { useState } from "react";
import PropTypes from "prop-types";
import { useForm } from "react-hook-form";
import Alert from "@material-ui/lab/Alert";
import Table from "@material-ui/core/Table";
import Paper from "@material-ui/core/Paper";
import AppBar from "@material-ui/core/AppBar";
import Button from "@material-ui/core/Button";
import Dialog from "@material-ui/core/Dialog";
import Toolbar from "@material-ui/core/Toolbar";
import Divider from "@material-ui/core/Divider";
import CloseIcon from "@material-ui/icons/Close";
import TableRow from "@material-ui/core/TableRow";
import TextField from "@material-ui/core/TextField";
import TableBody from "@material-ui/core/TableBody";
import TableCell from "@material-ui/core/TableCell";
import TableHead from "@material-ui/core/TableHead";
import IconButton from "@material-ui/core/IconButton";
import Typography from "@material-ui/core/Typography";
import { makeStyles } from "@material-ui/core/styles";
import DialogContent from "@material-ui/core/DialogContent";
import TableContainer from "@material-ui/core/TableContainer";
import { fade } from "@material-ui/core/styles/colorManipulator";
import ImportContactsIcon from "@material-ui/icons/ImportContacts";
import { Icon } from "@material-ui/core";
import clsx from "clsx";
import InputAdornment from '@material-ui/core/InputAdornment';

const useStyles = makeStyles((theme) => {
  return {
    table: {
      Width: "100%",
    },
    closeButton: {
      position: "absolute",
      right: theme.spacing(1),
      top: theme.spacing(1),
      color: theme.palette.grey[500],
      "&:hover": {
        background: fade(theme.palette.secondary.contrastText, 0.3),
      },
    },
  
    container: {
      maxHeight: 280,
      borderRadius: 8,
      border: '1px solid rgba(0, 0, 0, 0.12)',
    },
  };
});

function SelectContactModal({ onSelect }) {
  const [openDialog, setOpenDialog] = useState(false);
  const [isSearching, setIsSearching] = useState(false);
  const [searchResult, setSearchResult] = useState([]);

  const [contacts, setContacts] = useState([
    {
      id: 1,
      mobile: "09120811016",
      name: "محمد مداحی",
      family:"",
      contactGroup:""
    },
    {
      id: 2,
      mobile: "09170000000",
      name: "محمد پاکباز",
      family:"",
      contactGroup:""
    },
    {
      id: 2,
      mobile: "09120811164",
      name: "محمد رسولی زاده",
      family:"",
      contactGroup:"مشتریان"
    },
  ]);

  const { register, handleSubmit } = useForm();

  const classes = useStyles();

  const handleOpenDialog = () => {
    setOpenDialog(true);
  };

  const handleCloseDialog = () => {
    setOpenDialog(false);
  };

  const handleSelect = (contact) => {
    onSelect(contact);
    // handleCloseDialog();
  };

  const handleSearch = ({ name, mobile }) => {
    if (!name && !mobile) {
      setIsSearching(false);
      setSearchResult([]);
    } else {
      setIsSearching(true);

      const result = contacts.filter(
        (contact) =>
          (name && contact.name.includes(name)) ||
          (mobile && contact.mobile.includes(mobile))
      );
      setSearchResult(result);
    }
  };

  const result = isSearching ? searchResult : contacts;
  return (
    <>
      <div className="flex-wrap flex-row">
        <Button
          size="small"
          variant="outlined"
          className="min-w-8 border-0"
          onClick={handleOpenDialog}
        >
          <Icon className="block text-24 bg-white rounded-full"> event_note </Icon>
        </Button>
        <Button
          size="small"
          variant="outlined"
          className="mr-8"
          startIcon={<ImportContactsIcon />}
          onClick={handleOpenDialog}
        >
          افزودن مخاطب
        </Button>
      </div>


      <Dialog
        open={openDialog}
        onClose={handleCloseDialog}
        aria-labelledby="form-dialog-title"
        classes={{
          paper: "rounded-8",
        }}

        fullWidth
      >
        <AppBar position="static">
          <Toolbar className="flex w-full">
            <Typography variant="subtitle1" color="inherit">
              لیست مخاطبین
            </Typography>
          </Toolbar>
          <IconButton
            aria-label="close"
            className={classes.closeButton}
            onClick={handleCloseDialog}
          >
            <CloseIcon />
          </IconButton>
        </AppBar>

        <DialogContent classes={{ root: "m-20 p-0 " }}>


          <form
            autoComplete="off"
            className="flex-row  pt-0 mb-0"
            onSubmit={handleSubmit(handleSearch)}
          >
             
            <TextField
              autoFocus
              label="جستجو"
              id="outlined-start-adornment"
              name="name"
              size="small"
              inputRef={register}
              onChange={handleSubmit(handleSearch)}
              placeholder="جهت جستجو مشخصات مورد نظر خود را وارد کنید"
              className=  "mt-4 w-2/3  min-w-1/2"               
              InputProps={{
                startAdornment: <InputAdornment position="start"> </InputAdornment>,
              }}
              variant="outlined"
            />
 
            <Button
              size="small"
              type="submit"
              color="primary"
              variant="contained"
              className="mt-8 mb-16 mx-16"
            >
              جستجو
            </Button>
            
          </form>
 
          <TableContainer component={Paper} className={clsx(classes.container, "")}>
            <Table className={classes.table} aria-label="لیست مخاطبین">
              <TableHead>
                <TableRow>
                  <TableCell align="center">شماره موبایل</TableCell>
                  <TableCell align="center">نام</TableCell>
                  <TableCell align="center">نام خانوادگی</TableCell>
                  <TableCell align="center">گروه</TableCell>
                </TableRow>
              </TableHead>
              <TableBody>
                {result.map((contact) => (
                  <TableRow
                    hover
                    key={contact.id}
                    className="cursor-pointer"
                    onClick={() => handleSelect(contact)}
                  >
                     <TableCell align="center">{contact.mobile}</TableCell>
                    <TableCell align="center">{contact.name}</TableCell>
                    <TableCell align="center">{contact.family}</TableCell>
                    <TableCell align="center">{contact.contactGroup}</TableCell> 
                  </TableRow>
                ))}
              </TableBody>
            </Table>
          </TableContainer>

          <div className="mb-16  mt-24">
          <Alert  variant="outlined"  severity="info">
            جهت درج شماره روی آن کلیک کنید
          </Alert>
        </div>
        <div className="flex-wrap flex-row ">
          <Button
            size="small"
            type="submit"
            color="primary"
            variant="contained"
            className="mt-8 mb-16 "
            onClick={handleCloseDialog}
          >
            انصراف
          </Button>
        </div>

        </DialogContent>

       

      </Dialog>
    </>
  );
}

SelectContactModal.propTypes = {
  onSelect: PropTypes.func.isRequired,
};

export default SelectContactModal;
