import FuseAnimate from '@fuse/core/FuseAnimate';
import FusePageSimple from '@fuse/core/FusePageSimple';
import Avatar from '@material-ui/core/Avatar';
import Button from '@material-ui/core/Button';
import { makeStyles } from '@material-ui/core/styles';
import Tab from '@material-ui/core/Tab';
import Tabs from '@material-ui/core/Tabs';
import Typography from '@material-ui/core/Typography';
import React, { useState } from 'react';
import AboutTab from './tabs/AboutTab';
import ChangePasswordTab from './tabs/ChangePasswordTab';

import { useTranslation } from 'react-i18next';

const useStyles = makeStyles(theme => ({
	layoutHeader: {
		background: 'url("https://www.domestic-bliss.com/wp-content/uploads/2021/01/HomeTest-2048x1321.jpg") !important',
		height: 120,
		minHeight: 320,
		[theme.breakpoints.down('md')]: {
			height: 130,
			minHeight: 240
		}
	}
}));

function ProfilePage() {
	const classes = useStyles();
	const [selectedTab, setSelectedTab] = useState(0);
	const { t } = useTranslation('profile');
	function handleTabChange(event, value) {
		setSelectedTab(value);
	}

	return (
		<FusePageSimple
			classes={{
				header: classes.layoutHeader,
				toolbar: 'px-16 sm:px-24'
			}}
			header={
				<div className="p-24 flex flex-1 flex-col items-center justify-center md:flex-row md:items-end">
					<div className="flex flex-1 flex-col items-center justify-center md:flex-row md:items-center md:justify-start">
						<FuseAnimate animation="transition.expandIn" delay={300}>
							<Avatar className="w-96 h-96" src={`${process.env.PUBLIC_URL}/assets/images/avatars/Christy.jpg`} />
						</FuseAnimate>
						<FuseAnimate animation="transition.slideLeftIn" delay={300}>
							<Typography
								className="md:mx-24 text-24 md:text-32 my-8 md:my-0"
								variant="h4"
								color="inherit"
							>
							 	Kim
							</Typography>
						</FuseAnimate>
					</div>

					<div className="flex items-center justify-end">
						<Button className="mx-8 normal-case" variant="contained" color="secondary" aria-label="Follow">
							Active
						</Button>
						 
					</div>
				</div>
			}
			contentToolbar={
				<Tabs
					value={selectedTab}
					onChange={handleTabChange}
					indicatorColor="primary"
					textColor="primary"
					variant="scrollable"
					scrollButtons="off"
					classes={{
						root: 'h-64 w-full'
					}}
				>					 
					<Tab
						classes={{
							root: 'h-64'
						}}
						label="My Account"
					/>
					<Tab
						classes={{
							root: 'h-64'
						}}
						label="Change Password"
					/>
				</Tabs>
			}
			content={
				<div className="p-16 sm:p-24"> 
					{selectedTab === 0 && 
					  <AboutTab 
					     t={t} 
					  />
					} 
					{selectedTab === 1 && 
					  <ChangePasswordTab 
					     t={t} 
					  />
					}
				</div>
			}
		/>
	);
}

export default ProfilePage;
