import FuseAnimateGroup from '@fuse/core/FuseAnimateGroup';
import AppBar from '@material-ui/core/AppBar'; 
import Card from '@material-ui/core/Card';
import CardContent from '@material-ui/core/CardContent';
import TextField from '@material-ui/core/TextField';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import axios from 'axios';
import React, { useEffect, useState } from 'react';
import Button from '@material-ui/core/Button';
import SaveIcon from '@material-ui/icons/Save';
import PropTypes from 'prop-types';  
import { makeStyles } from '@material-ui/core/styles';

const useStyles = makeStyles((theme) => ({
	button: {
	  margin: theme.spacing(1),
	},
  }));



const roles= [
	{ id: 'admin',    name: 'admin' },       
	{ id: 'customer', name: 'customer' },    
  ];
// function AboutTab() {
const AboutTab = ({
		t,
		theme,
		errors,
		control,
		register,
		setValue,
		getValues,
}) => {

	const classes = useStyles();
	const [data, setData] = useState(null);

	useEffect(() => {
		axios.get('/api/profile/about').then(res => {
			setData(res.data);
		});
	}, []);

	if (!data) {
		return (
			<div className="md:flex max-w-2xl">
			<Typography variant="subtitle1" color="inherit" className="flex-1 px-12">
							error in Loading data ...
			 	</Typography>
			 	<Typography> </Typography>
		  </div>
		);
	}
 
	const {data:info , name  } = data;
	return (
		<div className="md:flex max-w-2xl">
			<div className="flex flex-col flex-1 md:ltr:pr-32 md:rtl:pl-32">
				<FuseAnimateGroup
					enter={{
						animation: 'transition.slideUpBigIn'
					}}
				>
					<Card className="w-full mb-16 rounded-8 shadow">
						<AppBar position="static" elevation={0}>
							<Toolbar className="px-8">
								<Typography variant="subtitle1" color="inherit" className="flex-1 px-12">
									General Information
								</Typography>
								<Button
								    variant="contained"
									color="secondary"
        							size="small"
       								className={classes.button}
      							    startIcon={<SaveIcon />}
    							 >
      							  Save
    						    </Button>
							</Toolbar>
						</AppBar>

						<CardContent>
							<div className="mb-24"> 
								<TextField
          					      required
          					      autoFocus
          					      fullWidth
								  value={info.displayName}								
								  name="displayName"
          						  label={t('DISPLAYNAME')}
                                  variant="outlined"
                                  inputRef={register}
                                  error={!!errors?.displayName}
                                  helperText={errors?.displayName?.message}
                                  className="md:w-1/3 px-3 mt-8 mb-8 md:mb-0"
                                />
								 
							</div>

							<div className="mb-24">
							    <TextField
          					      required
          					      autoFocus
          					      fullWidth
								  value={info.email}								
								  name="email"
          						  label={t('EMAIL')}
                                  variant="outlined"
                                  inputRef={register}
                                  error={!!errors?.email}
                                  helperText={errors?.email?.message}
                                  className="md:w-1/3 px-3 mt-8 mb-8 md:mb-0"
                                />								 
							</div>

	 	
 
  	  </CardContent>
	 </Card>
    </FuseAnimateGroup>
   </div>			 
  </div>
 );
}
AboutTab.propTypes = {
	t: PropTypes.func.isRequired,
	theme: PropTypes.object.isRequired,
	register: PropTypes.func.isRequired,
	errors: PropTypes.object.isRequired,
	setValue: PropTypes.func.isRequired,
	control: PropTypes.object.isRequired,
	getValues: PropTypes.func.isRequired,
  };
export default AboutTab;
