import { useEffect, useState } from 'react';
import clsx from 'clsx';
import * as yup from 'yup';
import Tab from '@material-ui/core/Tab';
import { useParams } from 'react-router';
import Tabs from '@material-ui/core/Tabs';
import Icon from '@material-ui/core/Icon';
import { useDispatch } from 'react-redux';
import { useForm } from 'react-hook-form';
import Spinner from 'app/components/Spinner';
import { useUpdateEffect } from '@fuse/hooks';
import { useTranslation } from 'react-i18next';
import FuseAnimate from '@fuse/core/FuseAnimate';
import Typography from '@material-ui/core/Typography';
import { Link, useHistory } from 'react-router-dom';

import useNormalMsgReportTab from '../hooks/useNormalMsgReport';
import { useTheme } from '@material-ui/core/styles';
import { yupResolver } from '@hookform/resolvers/yup';
import FusePageCarded from '@fuse/core/FusePageCarded';
import LoadingButton from 'app/components/LoadingButton';
import { showMessage } from 'app/store/fuse/messageSlice';
import AllNormalMsgReport from './all/AllNormalMsgReport.js';
 
import ToggleButton from "@material-ui/lab/ToggleButton";
import FilterListIcon from "@material-ui/icons/FilterList";
import Tooltip from "@material-ui/core/Tooltip";
import { CircularProgressbar, buildStyles } from 'react-circular-progressbar';
import "react-circular-progressbar/dist/styles.css";


const validationSchema = yup.object().shape({
  name: yup.string().required(),
});

const defaultFormState = {
  
  name: '',
  Code: '',
  info: '',
  tags: [],
  images: [],
  taxRate: 0,
  discount: 0,
  quantity: 0,
  
  publish: false,
  properties: [],
  description: '',
  priceTaxExcl: 0,
  priceTaxIncl: 0,
  courselevel: null,
  categoriesObject: [],
  featuredImageId: null,
};

const NormalMsgReport = () => {
  const [tabValue, setTabValue] = useState(0);
  const [featuredImage, setFeaturedImage] = useState(null);

  const theme = useTheme();
  const { t } = useTranslation('reports');

  let { postId } = useParams();
  const history = useHistory();

  const isEdit = postId !== 'all';

  const { data, isLoading, remove } = useNormalMsgReportTab({
    postId,
    enabled: isEdit,
  });

  const dispatch = useDispatch();

  const {
    reset,
    watch,
    errors,
    control,
    register,
    setValue,
    getValues,
    handleSubmit,
    formState: { isSubmitting },
  } = useForm({
    shouldUnregister: false,
    resolver: yupResolver(validationSchema),
    defaultValues: data ? data : defaultFormState,
  });

  const [showDetails, setShowDetails] = useState(true);

  // console.log({ values: getValues() });

  useEffect(() => {
    console.log('reset');
    if (data) {
      reset(data);
    } else {
      reset(defaultFormState);
    }
  }, [reset, data]);

  useUpdateEffect(() => {
    if (postId === 'all') {
      remove();
      setTabValue(0);
    }
  }, [postId]);

  useEffect(() => {
    const { images = [], featuredImageId } = data || {};


  }, [isEdit, data]);




  const handleChangeTab = (event, value) => {
    setTabValue(value);
  };

  if (isLoading) {
    return <Spinner />;
  }

  if (isEdit && !data) {
    return null;
  }

  return (
    
      <FusePageCarded
        classes={{
          toolbar: 'p-0',
          header: 'min-h-72 h-72 sm:h-72 sm:min-h-72',
          content: 'flex p-0 mr-0 ml-0',
        }}
        header={
          <div className="flex flex-1 w-full items-center justify-between">
            <div className="flex flex-col items-start max-w-full">
              <FuseAnimate animation="transition.slideRightIn" delay={300}>
                <Typography
                  role="button"
                  color="inherit"
                  component={Link}
                  to="/dashboard"
                  className="normal-case flex items-center sm:mb-12"
                >
                  <Icon className="text-20">
                    {theme.direction === 'ltr' ? 'arrow_back' : 'arrow_forward'}
                  </Icon>
                  <span className="mx-4">{t('REPORTS')}</span>
                </Typography>
              </FuseAnimate>

              
            </div>
          
          </div>
        }
        contentToolbar={
          <div className="flex flex-1 w-full items-center justify-between">
            <div className="px-0   sm:block">
              <Tabs
                value={tabValue}
                textColor="primary"
                variant="scrollable"
                scrollButtons="auto"
                indicatorColor="primary"
                onChange={handleChangeTab}
                classes={{ root: 'w-full h-64' }}
              >
                <Tab className="h-64 normal-case" label={t('NORMALREPORTS')}   />
              </Tabs>
            </div>
            <Tooltip title={showDetails ? "بستن فیلترها" : "نمایش فیلترها"}  >
              <ToggleButton
                value="showDetails"
                onClick={() => {
                  setShowDetails(!showDetails);
                }}
                className="border-none left-8 relative  mx-18  rounded-full fixed text-gray-500  "
                aria-label={showDetails ? "بستن فیلترها" : "نمایش فیلترها"}
              >
                <FilterListIcon />
              </ToggleButton>
            </Tooltip>
          </div>
        }
        content={
          <div className={clsx('p-0 h-full', 'min-w-full h-full p-0 m-0')}>
            {tabValue === 0 && <AllNormalMsgReport t={t} postId={"All"} showDetails />} 
          </div>
        }
        innerScroll
      />
    
  );
};

NormalMsgReport.propTypes = {};

export default NormalMsgReport;
