import { useEffect, useMemo, useState } from 'react';
import qs from 'qs';
import Fab from '@material-ui/core/Fab';
import Icon from '@material-ui/core/Icon';
import Spinner from 'app/components/Spinner';
import OrderListHeader from './AllOrderList_Header';
import useOrderList from '../../hooks/useOrderList';
import useDeleteOrderList from '../../hooks/useDeleteOrderList';

import { useTranslation } from 'react-i18next';
import DataTable from 'app/components/DataTable';
import { makeStyles } from '@material-ui/core/styles';
import IconButton from '@material-ui/core/IconButton';
import FusePageCarded from '@fuse/core/FusePageCarded';
import UploadIcon from '@material-ui/icons/CloudUpload';
import { useLocation, useHistory } from 'react-router-dom';
import useDataTable from 'app/components/DataTable/useDataTable';
import DataTableCheckbox from 'app/components/DataTable/DataTableCheckbox';
import FuseAnimate from '@fuse/core/FuseAnimate';
import Typography from '@material-ui/core/Typography';
import { Link } from 'react-router-dom';
import moment from 'moment';

export const dateFormat = 'YYYY-MM-DD';

const useStyles = makeStyles((theme) => ({
  fab: {
    position: 'absolute',
    right: theme.spacing(1),
    left: theme.spacing(1),

  },


}));

function AllOrderList(postId ,  showDetails) {
  const classes = useStyles();
  const { t } = useTranslation('orders');

  const history = useHistory();
  const { search: locationSearch } = useLocation();

  const urlParams = qs.parse(locationSearch, {
    ignoreQueryPrefix: true,
  });

  const [queryPerPage, setQueryPerPage] = useState(
    parseInt(urlParams.perPage) || 10
  );
  const [queryPage, setQueryPage] = useState(parseInt(urlParams.page) || 1);
  const [querySortBy, setQuerySortBy] = useState(urlParams.sortBy);
  const [querySortDir, setQuerySortDir] = useState(urlParams.sortDir);
  const [querySearch, setQuerySearch] = useState(urlParams.search);

  const {
    isLoading,
    isFetching,
    resolvedData = { count: 0, orders: [], pageCount: 0 },
  } = useOrderList({
    postId: postId.postId,
    page: queryPage,
    search: querySearch,
    sortBy: querySortBy,
    perPage: queryPerPage,
    sortDir: querySortDir,
  });

  const [deleteOrderList] = useDeleteOrderList();

  const columns = useMemo(
    () => [
      {
        id: 'selection',
        header: ({
          selectedRows,
          isAllRowsSelected,
          isIndeterminateSelect,
          onToggleAllSelectedRow,
        }) => {
          const selectedRowIds = Object.keys(selectedRows);

          return (
            <div className="flex  ">
              <DataTableCheckbox
                className="mx-10"
                checked={isAllRowsSelected}
                indeterminate={isIndeterminateSelect}
                onChange={(e) => onToggleAllSelectedRow(e.target.checked)}
              />

              {selectedRowIds.length > 0 && (
                <div className="flex items-center justify-center h-54 mx-10">
                  <IconButton
                    onClick={(e) => {
                      e.stopPropagation();
                      deleteOrderList(selectedRowIds).then(() => {
                        onToggleAllSelectedRow(false);
                      });
                    }}
                  >
                    <Icon color="error">delete</Icon>
                  </IconButton>
                </div>
              )}
            </div>
          );
        },
        accessor: ({ row, isSelected, handleToggleSelectedRow }) => (
          <div>
            <DataTableCheckbox
              className="mx-10"
              checked={isSelected}
              onChange={(e) =>
                handleToggleSelectedRow(row.id, e.target.checked)
              }
            />
          </div>
        ),
        headerClassName: 'w-48',
        disablePadding: true,
      },
      {
        header: t('SERVICE'), sortable: true,
        accessor: ({ row }) => row.serviceType ? row.serviceType : ''
      },
      {
        header: t('CUSTOMER'), sortable: true,
        accessor: ({ row }) =>
          <Typography
            role="button"
            color="inherit"
            component={Link}
            to={"/apps/e-services/orders/" + row.id}
            className="normal-case flex items-center sm:mb-4"
          >
            {row.customer ? row.customer.firstName + ' ' + row.customer.lastName : ''}
            <br />
            {row.customer.email} <br />
            {row.customer.phone}
          </Typography>

      },
      {
        header: t('payment_method'),
        accessor: ({ row }) => row.gateway ? row.gateway.title : 'Cash - NOT PAID', sortable: true
      },
      {
        header: t('PRICE'),
        accessor: 'total', sortable: true
      },
      {
        header: t('STATUS'), sortable: true,
        accessor: ({ row }) => (row.status && row.status.length) ? row.status[row.status.length - 1].title : '', id: 'status',
      },
      {
        header: t('DATE'),
        accessor: ({ row }) =>
          <Typography
            role="button"
            color="inherit"
            component={Link}
            to={"/apps/e-services/orders/" + row.id}
            className="normal-case flex items-center sm:mb-4"
          >
            {moment(row.date).format(dateFormat).toString()}

            <br />
            {row.select_date + " : " + row.select_time}
          </Typography>
        , sortable: true
      },
      {
        header: t('DESCRIPTION'),
        accessor: 'description', sortable: true
      },
      {
        id: 'active',
        header: t('ACTIVE'),
        sortable: true,
        accessor: ({ row }) =>
          <FuseAnimate animation="transition.slideRightIn" delay={300}>
            <Typography
              role="button"
              color="inherit"
              component={Link}
              to={"/apps/e-services/orders/" + row.id}
              className="normal-case flex items-center sm:mb-4"
            >
              <Icon className="text-20"> edit         </Icon>
            </Typography>
          </FuseAnimate>
      },
    ],
    [t, deleteOrderList]
  );

  const {
    page,
    sortBy,
    search,
    perPage,
    sortDir,
    handleSearch,
    appliedFilters,
    ...tableInstance
  } = useDataTable({
    columns,
    initialPage: queryPage,
    initialSortBy: querySortBy,
    initialSearch: querySearch,
    data: resolvedData?.orders,
    initialPerPage: queryPerPage,
    initialSortDir: querySortDir,
  });

  useEffect(() => {
    setQueryPage(page);
  }, [page]);

  useEffect(() => {
    setQueryPerPage(perPage);
  }, [perPage]);

  useEffect(() => {
    setQuerySearch(search);
  }, [search]);

  useEffect(() => {
    if (sortBy !== querySortBy) {
      setQuerySortBy(sortBy);
    }

    if (sortDir !== querySortDir) {
      setQuerySortDir(sortDir);
    }
  }, [sortBy, sortDir, querySortBy, querySortDir]);

  const handleNavigateToOrder = (row) => {
    history.push(`/apps/e-services/ordersview/${row.id}`);
  };

  return (
    <FusePageCarded

      classes={{
        content: 'flex   ',
        contentWrapper: 'p-0 m-0 br-0',
        contentCard: 'overflow-hidden  ',
        header: (showDetails ? 'min-h-72 h-72 sm:h-136 sm:min-h-136 bg-white' : "min-h-0 h-0 sm:h-0 sm:min-h-0 bg-white"),
      }}
      header={<OrderListHeader onSearch={handleSearch} />}
      content={

        <>
          {isLoading && <Spinner />}
          <DataTable

            hover
            page={page}
            stickyHeader
            sortBy={sortBy}
            sortDir={sortDir}
            perPage={perPage}
            isLoading={isFetching}
            count={resolvedData?.count}
            onRowClick={handleNavigateToOrder}
            paginationClasses={{ toolbar: 'ltr:pr-52 rtl:pl-52' }}
            {...tableInstance}
          />
          {console.log(resolvedData)}
          <Fab
            color="primary"
            className={classes.fab}
            aria-label="upload excel file"
          >
            <UploadIcon />
          </Fab>
        </>
      }
      innerScroll
    />
  );
}

export default AllOrderList;
