import PropTypes from 'prop-types';
import Dialog from '@material-ui/core/Dialog';
import AppBar from '@material-ui/core/AppBar';
import Button from '@material-ui/core/Button';
import { useTranslation } from 'react-i18next';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogCloseButton from 'app/components/DialogCloseButton';
import { useCallback, useState } from 'react';
import Cropper from 'react-easy-crop';
import getCroppedImg from './utils';

const CropDialog = ({ isOpen, onClose, imageUrl, onSave }) => {
  const [crop, setCrop] = useState({ x: 0, y: 0 });
  const [rotation, setRotation] = useState(0);
  const [zoom, setZoom] = useState(1);
  const [croppedAreaPixels, setCroppedAreaPixels] = useState(null);

  const { t } = useTranslation('reports');

  const onCropComplete = useCallback((croppedArea, croppedAreaPixels) => {
    setCroppedAreaPixels(croppedAreaPixels);
  }, []);

  const handleSave = async () => {
    try {
      const croppedImage = await getCroppedImg(
        imageUrl,
        croppedAreaPixels,
        rotation
      );
      onSave(croppedImage);
    } catch (e) {
      console.error(e);
    }
  };

  return (
    <Dialog
      fullWidth
      maxWidth="md"
      open={isOpen}
      onClose={onClose}
      disableBackdropClick
      classes={{
        paper: 'm-24 rounded-8',
      }}
    >
      <AppBar position="static" elevation={1}>
        <Toolbar className="flex w-full">
          <Typography variant="subtitle1" color="inherit">
            {t('CROP_IMAGE')}
          </Typography>
        </Toolbar>
        <DialogCloseButton onClick={onClose} />
      </AppBar>

      <DialogContent
        classes={{
          root: 'relative min-h-200 sm:min-h-400 p-24',
        }}
      >
        <Cropper
          crop={crop}
          zoom={zoom}
          image={imageUrl}
          aspect={4 / 3}
          rotation={rotation}
          onCropChange={setCrop}
          onZoomChange={setZoom}
          onRotationChange={setRotation}
          onCropComplete={onCropComplete}
        />
      </DialogContent>
      <DialogActions className="p-8">
        <div className="px-16">
          <Button color="primary" variant="contained" onClick={handleSave}>
            {t('SAVE')}
          </Button>
        </div>
      </DialogActions>
    </Dialog>
  );
};

CropDialog.propTypes = {
  imageUrl: PropTypes.string.isRequired,
  isOpen: PropTypes.bool.isRequired,
  onClose: PropTypes.func.isRequired,
  onSave: PropTypes.func.isRequired,
};

export default CropDialog;
