import PropTypes from 'prop-types';
import React from 'react';
import { makeStyles, useTheme } from '@material-ui/core/styles';

import Card from '@material-ui/core/Card';
import Icon from '@material-ui/core/Icon';
import AppBar from '@material-ui/core/AppBar';
import ReactStars from "react-rating-stars-component";
import Typography from '@material-ui/core/Typography';
import FuseAnimate from '@fuse/core/FuseAnimate';
import { useBarcode } from 'react-barcodes';
import Avatar from '@material-ui/core/Avatar';


const useStyles = makeStyles((theme) => ({
  cardview: {
    width: '100%',
    maxWidth: '36ch',
    backgroundColor: theme.palette.background.paper,
  },
  inline: {
    display: 'inline',
  }, alert: {
    borderRadius: theme.shape.borderRadius,
    padding: "8px 16px",
    marginBottom: "12px",
  },


}));


const OrderViewBasicInfo = ({ t, theme, data }) => {
  const classes = useStyles();
  const Apptheme = useTheme();
  const formatter = new Intl.NumberFormat('ar-SY', {
    style: 'currency',
    currency: 'SYP',
    minimumFractionDigits: 0
  });
  const { inputRef } = useBarcode({
    value: data.code,
    options: {
      background: '#ffffff',
    }
  });
  const firstExample = {
    size: 30,
    value: data.rating ? data.rating.rate:0,
    edit: false
  };

  return (
    <div className="w-full">

      <FuseAnimate animation="transition.slideUpIn" delay={200}>
        <div className="flex flex-col md:flex-row sm:p-8 container">

          <div className="flex flex-1 flex-col min-w-0">
            <div className="pb-8 flex items-center">

              <img
                src={data?.service && data?.service.images.length > 0 && data?.service.images[0].url}
                alt=""
                style={{ maxWidth: '90px', width: '100%', marginTop: '0px', marginLeft: '10px' }}
                className="rounded-4"
              />
              <Typography className="h1 mx-16"  style={{ fontWeight: 800 }} color="textSecondary">
                {data?.serviceType}
              </Typography>
              <svg class="w-136 h-64 ml-24" ref={inputRef} />
            </div>
            <Typography className="pb-8 h5 mx-8" color="textSecondary">
              <strong style={{ fontWeight: 800 }}>
                Description :
              </strong>
              {data?.description}
            </Typography>

            <Typography className="pb-24 h5 mx-8" color="textSecondary">
              <strong style={{ fontWeight: 800 }}>
                Date :
              </strong>
              {data?.dateTime}
            </Typography>

       
            

            <div className="pb-8 flex items-center">
              <Icon color="action">account_circle</Icon>
              <Typography className="h2 mx-16" style={{ fontWeight: 800 }} color="textSecondary">
                Customer
              </Typography>
            </div>

            <div className="mb-8">
              <div className="table-responsive mb-8">
                <table className="simple">
                  <thead>
                    <tr>
                      <th>Name</th>
                      <th>Email</th>
                      <th>Phone</th>
                      <th>jobTitle</th>
                    </tr>
                  </thead>
                  <tbody>
                    <tr>
                      <td>
                        <div className="flex items-center">
                          <Avatar src={data?.customer?.avatar} />
                          <Typography className="truncate mx-8">
                            {data?.customer?.firstName}  {data?.customer?.lastName}
                          </Typography>
                        </div>
                      </td>
                      <td>
                        <Typography className="truncate">
                          {data?.customer?.email}
                        </Typography>
                      </td>
                      <td>
                        <Typography className="truncate">
                          {data?.customer?.phone}
                        </Typography>
                      </td>
                      <td>
                        <span className="truncate"> {data?.customer?.jobTitle}</span>
                      </td>
                    </tr>
                  </tbody>
                </table>
              </div>

              <Typography className="flex pb-4 h5 mx-8" color="textSecondary">
              <strong className="flex" style={{ fontWeight: 800 ,marginTop: 9 }}>
                Customer Rating :
               
              </strong>    
              <ReactStars {...firstExample} />   
              </Typography>    
              <Typography className=" pb-24 h5 mx-8" color="textSecondary">  
              <strong style={{ fontWeight: 800 }}>
                Rating description :
              </strong>
              {data.rating ? data.rating.description:''}
            </Typography>

            </div>


            <div className="pb-16 flex items-center">
              <Icon color="action">account_circle</Icon>
              <Typography className="h2 mx-16" style={{ fontWeight: 800 }} color="textSecondary">
                Worker or Driver
              </Typography>
            </div>

            <Card className="w-full rounded-4 shadow-1">
              {data?.masterList && data?.masterList.map(masterList => (
                <div className="flex flex-row justify-between items-start">
                  <div className="flex flex-col">
                    <div className="flex items-center mb-16 print:mb-0">
                      <img
                        className="w-80 print:w-60"
                        src={masterList?.masterImage}
                        alt="logo"
                      />

                      <div className="max-w-180">
                        <table>
                          <tbody>
                            <tr>
                              <td className="text-right">
                                <Typography color="textSecondary"> masterName   </Typography>
                              </td>
                              <td className="px-16">
                                <Typography>{masterList?.masterName}</Typography>
                              </td>
                            </tr>
                            <tr>
                              <td className="text-right">
                                <Typography color="textSecondary"> masterCode   </Typography>
                              </td>
                              <td className="px-16">
                                <Typography>{masterList.masterCode}</Typography>
                              </td>
                            </tr>
                            <tr>
                              <td className="text-right">
                                <Typography color="textSecondary">  masterMobile </Typography>
                              </td>
                              <td className="px-16">
                                <Typography>{masterList.masterMobile}</Typography>
                              </td>
                            </tr>
                            <tr>
                              <td className="text-right">
                                <Typography color="textSecondary">  masterAddress </Typography>
                              </td>
                              <td className="px-16">
                                <Typography> {masterList.masterAddress}   </Typography>
                              </td>
                            </tr>
                          </tbody>
                        </table>
                      </div>

                    </div>
                  </div>
                  <table>
                    <tbody>
                      <tr>
                        <td className="text-right">
                          <Typography color="textSecondary"> vehicle_bime   </Typography>
                        </td>
                        <td className="px-16">
                          <Typography>{masterList.vehicle_bime}</Typography>
                        </td>
                      </tr>
                      <tr>
                        <td className="text-right">
                          <Typography color="textSecondary"> vehicle_model   </Typography>
                        </td>
                        <td className="px-16">
                          <Typography>{masterList.vehicle_model}</Typography>
                        </td>
                      </tr>
                      <tr>
                        <td className="text-right">
                          <Typography color="textSecondary">  vehicle_brand </Typography>
                        </td>
                        <td className="px-16">
                          <Typography>{masterList.vehicle_brand}</Typography>
                        </td>
                      </tr>
                      <tr>
                        <td className="text-right">
                          <Typography color="textSecondary">  pelak </Typography>
                        </td>
                        <td className="px-16">
                          <Typography> {masterList.peak_2number}     {masterList.pelak_3number}  {masterList.pelak_alpha}   {masterList.vehicle_pelak}  </Typography>
                        </td>
                      </tr>
                    </tbody>
                  </table>
                </div>
              ))}
            </Card>



            <div className="pb-16 flex items-center">
              <Icon color="action">account_circle</Icon>
              <Typography className="h2 mx-16" style={{ fontWeight: 800 }} color="textSecondary">
                Delivery or Address
              </Typography>
            </div>

            <Card className="w-full rounded-4 shadow-1">

              {/*----- --------------------- {Apptheme.direction === 'ltr' ?  data?.createTripDate :  data?.fdate   } --------from -to -address -----------------------*/}

              <div className="px-16 pt-16 text-18 font-300">
                <Icon color="action"> place </Icon> 
               {t('MASTER_CENTER')}
                {data?.fromAddress && data?.fromAddress.map(fromAddress => (
                  <div className="pb-16 flex items-center">
                    <Typography className="h5 mx-16" color="textSecondary">
                    <strong style={{ fontWeight: 800 }}>
                      {fromAddress.title} :
                    </strong> 
                      {fromAddress.address}
                    </Typography>
                    <Typography className="h5 mx-16" color="textSecondary">
                    <strong style={{ fontWeight: 800 }}>
                     Phone :
                    </strong> 
                      {fromAddress.tel}
                    </Typography>
                  </div>
                ))}
              </div>
              <div className="px-16 pb-8 text-18 font-300" > 
              <Icon color="action"> place </Icon> 
               {t('CUSTOMER_LOCATION')}
                {data.toAddress && !data.toAddress  && data?.toAddress.map(toAddress => (
                  <div className="pb-16 flex items-center">
                    <Typography className="h5 mx-16" color="textSecondary">
                    <strong style={{ fontWeight: 800 }}>
                      {toAddress.title} :
                    </strong> 
                      {toAddress.address}
                    </Typography>
                    <Typography className="h5 mx-16" color="textSecondary">
                    <strong style={{ fontWeight: 800 }}>
                     Phone :
                    </strong> 
                      {toAddress.tel}
                    </Typography>
                  </div>
                ))}
              </div>
            </Card>

          </div>


          <div className="flex flex-wrap w-full md:w-360 ">
            <div className="mb-32 w-full sm:w-full md:w-full">

              <div className="widget w-full ">
                <Card className="w-full rounded-8 shadow">
                  <AppBar position="static">
                    <div className="p-16 px-4 flex flex-row items-center justify-between">
                      <div className="px-12">
                        <Typography className="h5" color="inherit">
                          {t('SERVICE_TYPE')}
                        </Typography>
                        <Typography className="h1 font-400" color="inherit">
                          {data?.serviceType}
                        </Typography>

                      </div>
                      <div>
                        <img
                          src={data?.service && data?.service.images.length > 0 && data?.service.images[0].url}
                          alt=""
                          style={{ maxWidth: '40px', width: '100%', marginTop: '0px', marginRight: '10px' }}
                          className="rounded-6"
                        />
                        <Typography className="h5" color="inherit">
                          {data.payment.method}
                        </Typography>

                      </div>
                    </div>
                    <div className="p-16 pt-8 flex flex-row justify-between items-end">
                      <Typography className="text-24 font-300 leading-none" color="inherit">
                        {formatter.format(data?.total)}
                      </Typography>
                    </div>
                  </AppBar>
                </Card>
              </div>
              <div className="widget w-full p-8">
                <table className="simple clickable">
                  <thead>
                    <tr>
                      <th aria-label="title" />
                      <th className="text-right"> </th>
                      <th className="text-right"> </th>
                    </tr>
                  </thead>
                  {data?.serviceType == "cleaning" && (
                    <tbody>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyTitle : ""))}  </td>
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr > <td> {t('select_time')} </td>  <td >{data?.select_time}</td>  <td >  {t('Time')} </td>               </tr>
                      <tr > <td> {t('select_date')} </td>  <td >{data?.select_date}</td>  <td >  {t('Date')} </td>               </tr>
                      <tr > <td> {t('area')} </td>  <td >{data?.area}</td>  <td >  {t('m*m')} </td>               </tr>
                      <tr > <td> {t('room')} </td>  <td >{data?.room}</td>  <td >  {t('Number')} </td>               </tr>
                    </tbody>
                  )}
                  {data?.serviceType == "SolarPanel" && (
                    <tbody>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyTitle : ""))}  </td>
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_place ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_place ? properties.PropertyTitle : ""))}  </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.purpose ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.purpose ? properties.PropertyTitle : ""))}  </td>
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr > <td> {t('select_time')} </td>  <td >{data?.select_time}</td>  <td >  {t('Time')} </td>               </tr>
                      <tr > <td> {t('select_date')} </td>  <td >{data?.select_date}</td>  <td >  {t('Date')} </td>               </tr>
                      <tr > <td> {t('area')} </td>  <td >{data?.area}</td>  <td >  {t('m*m')} </td>                   </tr>
                    </tbody>
                  )}
                  {data?.serviceType == "Repairs" && (
                    <tbody>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_place ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_place ? properties.PropertyTitle : ""))}  </td>
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyTitle : ""))}  </td>
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr > <td> {t('select_time')} </td>  <td >{data?.select_time}</td>  <td >  {t('Time')} </td>               </tr>
                      <tr > <td> {t('select_date')} </td>  <td >{data?.select_date}</td>  <td >  {t('Date')} </td>               </tr>
                      <tr > <td> {t('area')} </td>  <td >{data?.area}</td>  <td >  {t('m*m')} </td>                   </tr>
                    </tbody>
                  )}
                  {data?.serviceType == "Camera" && (
                    <tbody>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_place ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_place ? properties.PropertyTitle : ""))}  </td>
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyTitle : ""))}  </td>
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr > <td> {t('select_time')} </td>  <td >{data?.select_time}</td>  <td >  {t('Time')} </td>               </tr>
                      <tr > <td> {t('select_date')} </td>  <td >{data?.select_date}</td>  <td >  {t('Date')} </td>               </tr>
                    </tbody>
                  )}
                  {data?.serviceType == "Interiordecoration" && (
                    <tbody>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_place ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_place ? properties.PropertyTitle : ""))}  </td>
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr className="text-left">
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyLabelName : ""))} </td>
                        <td >  {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyTitle : ""))}  </td>
                        <td > {data?.service && data?.service.properties.map(properties => (
                          properties.PropertyId === data?.type_service ? properties.PropertyPrice : ""))}  {t('LS')} </td>
                      </tr>
                      <tr > <td> {t('select_time')} </td>  <td >{data?.select_time}</td>  <td >  {t('Time')} </td>               </tr>
                      <tr > <td> {t('select_date')} </td>  <td >{data?.select_date}</td>  <td >  {t('Date')} </td>               </tr>
                    </tbody>
                  )}
                </table>
              </div>


            </div>
          </div>


        </div>
      </FuseAnimate>
    </div>



  );
};

OrderViewBasicInfo.propTypes = {
  t: PropTypes.func.isRequired,
  theme: PropTypes.object.isRequired,
  data: PropTypes.object.isRequired,
};

export default OrderViewBasicInfo;
