import PropTypes from 'prop-types';
import Card from '@material-ui/core/Card';
import Icon from '@material-ui/core/Icon';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import CardContent from '@material-ui/core/CardContent';
import FuseAnimateGroup from '@fuse/core/FuseAnimateGroup';
import IconButton from '@material-ui/core/IconButton';
import Paper from '@material-ui/core/Paper';
import Avatar from '@material-ui/core/Avatar';
import GoogleMap from 'google-map-react';
import Tooltip from '@material-ui/core/Tooltip';

//import PhotoDocument from './OrdersStatus';
//import Vehicle from './OrdersStatus';

function Marker(props) {
  return (
    <Tooltip title={props.text} placement="top">
      <Icon className="text-red">place</Icon>
    </Tooltip>
  );
}

const OrderViewLocation = ({ t, theme, data }) => {
  return (
    <div>

      <FuseAnimateGroup
        className="flex flex-wrap"
        enter={{
          animation: 'transition.slideUpBigIn'
        }}
      >

        {data?.fromAddress && data?.fromAddress.length > 0 && data?.fromAddress.map(fromAddress => (
          <div>
            <div className="px-16 pt-16 text-18 font-300"><Icon color="action"> place </Icon>
              {t('MASTER_CENTER')}

              <div className="pb-16 flex items-center">
                <Typography className="h3 mx-16" color="textSecondary">
                  {fromAddress.address}
                </Typography>
              </div>

            </div>
            <div className="w-full h-320">
              <GoogleMap
                bootstrapURLKeys={{
                  key: process.env.REACT_APP_MAP_KEY
                }}
                defaultZoom={15}
                defaultCenter={[
                  data?.fromAddress.lat,
                  data?.fromAddress.long
                ]}
              >
                <Marker
                  text={t('CURRENT_LOCATION')}
                  lat={data?.fromAddress.lat}
                  lng={data?.fromAddress.long}
                />
              </GoogleMap>
            </div>
          </div>
        ))}


        {data?.toAddress && data?.toAddress.map(toAddress => (
          <div>
            <div className="px-16 pb-8 text-18 font-300"> <Icon color="action"> where_to_vote </Icon>
              {t('CUSTOMER_LOCATION')}

              <div className="pb-16 flex items-center">
                <Typography className="h3 mx-16" color="textSecondary">
                  {toAddress.address}
                </Typography>
              </div>
            </div>
            <div className="w-full h-320">
              <GoogleMap
                bootstrapURLKeys={{
                  key: process.env.REACT_APP_MAP_KEY
                }}
                defaultZoom={15}
                defaultCenter={[
                  data?.toAddress[0].lat,
                  data?.toAddress[0].long
                ]}
              >
                <Marker
                  text={t('CURRENT_LOCATION')}
                  lat={data?.toAddress[0].lat}
                  lng={data?.toAddress[0].long}
                />
              </GoogleMap>
            </div>
          </div>
        ))}

      </FuseAnimateGroup>

    </div>



  );
};

OrderViewLocation.propTypes = {
  t: PropTypes.func.isRequired,
  theme: PropTypes.object.isRequired,
  data: PropTypes.object.isRequired,
};

export default OrderViewLocation;
