import { useEffect, useMemo, useState } from 'react';
import qs from 'qs';
import PropTypes from 'prop-types';
import Paper from '@material-ui/core/Paper';
import Spinner from 'app/components/Spinner';
import DataTable from 'app/components/DataTable';
import useOrders from '../../hooks/useOrderOrders';
import { useLocation, useHistory } from 'react-router-dom';
import useDataTable from 'app/components/DataTable/useDataTable';
import FuseAnimate from '@fuse/core/FuseAnimate';
import Typography from '@material-ui/core/Typography';
import Icon from '@material-ui/core/Icon';
import { Link } from 'react-router-dom';

const OrderViewOrders = ({ t, postId }) => {
  const history = useHistory();
  const { search: locationSearch } = useLocation();

  const urlParams = qs.parse(locationSearch, {
    ignoreQueryPrefix: true,
  });

  const [queryPerPage, setQueryPerPage] = useState(
    parseInt(urlParams.perPage) || 5
  );
  const [queryPage, setQueryPage] = useState(parseInt(urlParams.page) || 1);
  const [querySortBy, setQuerySortBy] = useState(urlParams.sortBy);
  const [querySortDir, setQuerySortDir] = useState(urlParams.sortDir);
  const [querySearch, setQuerySearch] = useState(urlParams.search);

  const {
    isLoading,
    isFetching,
    resolvedData = { count: 0, orders: [], pageCount: 0 },
  } = useOrders({
    postId,
    page: queryPage,
    search: querySearch,
    sortBy: querySortBy,
    perPage: queryPerPage,
    sortDir: querySortDir,
  });

  const columns = useMemo( 
    () => [

      { header: t('CUSTOMER_NAME'),  sortable: true,   accessor: ({ row }) =>  row.customer.firstName + ' ' + row.customer.lastName    },
      { header: t('payment_method'),   accessor: ({ row }) =>   row.gateway.title  ,   sortable: true },
      { header: t('PRICE'), accessor: 'total', sortable: true },      
      { header: t('STATUS'),   sortable: true,   accessor: ({ row }) =>  row.status.length ? row.status[row.status.length-1].name: '' ,   id: 'status',   },
      { header: t('DATE'), accessor: 'fdate', sortable: true },
      { header: t('DESCRIPTION'), accessor: 'description', sortable: true },
      { header: t('STATUS'),   sortable: true,   accessor: ({ row }) => 
        <FuseAnimate animation="transition.slideRightIn" delay={300}>
                <Typography
                  role="button"
                  color="inherit"
                  component={Link}
                  to={"/apps/e-services/orderview/"+row.id}
                  className="normal-case flex items-center sm:mb-12"
                >
                  <Icon className="text-20">more_horiz         </Icon> 
                </Typography>
              </FuseAnimate>
      },
    ],
    [t]
  );

  const {
    page,
    sortBy,
    search,
    perPage,
    sortDir,
    handleSearch,
    appliedFilters,
    ...tableInstance
  } = useDataTable({
    columns,
    initialPage: queryPage,
    initialSortBy: querySortBy,
    initialSearch: querySearch,
    data: resolvedData?.orders,
    initialPerPage: queryPerPage,
    initialSortDir: querySortDir,
  });

  useEffect(() => {
    setQueryPage(page);
  }, [page]);

  useEffect(() => {
    setQueryPerPage(perPage);
  }, [perPage]);

  useEffect(() => {
    setQuerySearch(search);
  }, [search]);

  useEffect(() => {
    if (sortBy !== querySortBy) {
      setQuerySortBy(sortBy);
    }

    if (sortDir !== querySortDir) {
      setQuerySortDir(sortDir);
    }
  }, [sortBy, sortDir, querySortBy, querySortDir]);

  return (
    <div className="flex w-full h-full">
      {isLoading && <Spinner />}
      <Paper className="w-full rounded-8 shadow-1">
        <DataTable
          page={page}
          stickyHeader
          sortBy={sortBy}
          sortDir={sortDir}
          perPage={perPage}
          isLoading={isFetching}
          count={resolvedData?.count}
          {...tableInstance}
        />
      </Paper>
    </div>
  );
};

OrderViewOrders.propTypes = {
  t: PropTypes.func.isRequired,
  postId: PropTypes.string.isRequired,
};

export default OrderViewOrders;
