import { useRef, useState } from 'react';
import clsx from 'clsx';
import PropTypes from 'prop-types';
import List from '@material-ui/core/List';
import Icon from '@material-ui/core/Icon';
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import Divider from '@material-ui/core/Divider';
import FuseAnimate from '@fuse/core/FuseAnimate';
import ListItem from '@material-ui/core/ListItem';
import { useDeepCompareEffect } from '@fuse/hooks';
import { makeStyles } from '@material-ui/core/styles';
import ListItemText from '@material-ui/core/ListItemText';
import ListSubheader from '@material-ui/core/ListSubheader';
import FusePageCardedSidebar from '@fuse/core/FusePageCarded/FusePageCardedSidebar';

const drawerWidth = 240;

const useStyles = makeStyles((theme) => ({
  sidebarWrapper: {
    position: 'absolute',
    backgroundColor: 'transparent',
    zIndex: 5,
    overflow: 'hidden',
    '&.permanent': {
      [theme.breakpoints.up('lg')]: {
        zIndex: 1,
        position: 'relative',
      },
    },
  },
  sidebar: {
    position: 'absolute',
    '&.permanent': {
      [theme.breakpoints.up('lg')]: {
        backgroundColor: 'transparent',
        position: 'relative',
        bOrder: 'none',
        overflow: 'hidden',
      },   
    },
    width: drawerWidth,
    height: '100%',
  },
  leftSidebar: {},
  rightSidebar: {},
  sidebarContent: {
    display: 'flex',
    flex: '1 1 auto',
    flexDirection: 'column',
    // backgroundColor: theme.palette.background.default,
    color: theme.palette.text.primary,
    [theme.breakpoints.up('lg')]: {
      overflow: 'auto',
      '-webkit-overflow-scrolling': 'touch',
    },
  },
  backdrop: {
    position: 'absolute',
  },
  paper: {
    [theme.breakpoints.down('md')]: {
      boxShadow: 'none',
    },
  },
  listItem: {
    color: 'inherit!important',
    textDecoration: 'none!important',
    height: 40,
    width: 'calc(100% - 16px)',
    bOrderRadius: '0 20px 20px 0',
    paddingLeft: 24,
    paddingRight: 12,
    '&$selected': {
      backgroundColor: theme.palette.secondary.main,
      color: `${theme.palette.secondary.contrastText}!important`,
      pointerEvents: 'none',
      '& .list-item-icon': {
        color: 'inherit',
      },
    },
    '& .list-item-icon': {
      marginRight: 16,
    },
  },
  selected: {},
}));

const PropertySidebar = ({
  t,
  selectedLabel,
  properties = [],
  onOpenAddDialog,
  allProperyLabels = [],
  onSelectedLabelChange,
}) => {
  const [labels, setLabels] = useState([]);
  // const pageLayout = useRef(null);

  const leftSidebarRef = useRef(null);
  const rootRef = useRef(null);

  const classes = useStyles();

  useDeepCompareEffect(() => {
    setLabels(
      allProperyLabels.filter(({ id }) =>
        properties.find(({ propertyLabel }) => propertyLabel.id === id)
      )
    );
  }, [allProperyLabels, properties]);
  // useImperativeHandle(pageLayout, () => ({
  //   rootRef,
  //   toggleLeftSidebar: () => {
  //     leftSidebarRef.current.toggleSidebar();
  //   },
  // }));
  return (
    <FusePageCardedSidebar
      position="left"
      classes={classes}
      rootRef={rootRef}
      innerScroll={true}
      ref={leftSidebarRef}
      variant={'permanent'}
      content={
        <div className="p-0 lg:p-4 lg:ltr:pr-4 lg:rtl:pl-4">
          <FuseAnimate animation="transition.slideLeftIn" delay={200}>
            <Paper elevation={1} className={clsx(classes.paper, 'rounded-8')}>
              <div className="p-24">
                <Button
                  color="primary"
                  className="w-full"
                  variant="contained"
                  onClick={onOpenAddDialog}
                >
                  {t('ADD_PROPERTY')}
                </Button>
              </div>

              <List>
                <ListItem
                  button
                  selected={selectedLabel === ''}
                  onClick={() => onSelectedLabelChange('')}
                  classes={{
                    root: classes.listItem,
                    selected: classes.selected,
                  }}
                >
                  <Icon className="list-item-icon text-16" color="action">
                    label
                  </Icon>
                  <ListItemText
                    disableTypography
                    className="truncate"
                    primary={t('PROPERTIES')}
                  />
                </ListItem>
              </List>
              <Divider />
              <List>
                <ListSubheader>{t('LABELS')}</ListSubheader>
                {labels.map((label) => (
                  <ListItem
                    button
                    key={label.id}
                    selected={selectedLabel === label.id}
                    onClick={() => onSelectedLabelChange(label.id)}
                    classes={{
                      root: classes.listItem,
                      selected: classes.selected,
                    }}
                  >
                    <Icon className="list-item-icon text-16" color="action">
                      label
                    </Icon>
                    <ListItemText
                      disableTypography
                      className="truncate"
                      primary={label.title}
                    />
                  </ListItem>
                ))}
              </List>
            </Paper>
          </FuseAnimate>
        </div>
      }
    />
  );
};

PropertySidebar.propTypes = {
  t: PropTypes.func.isRequired,
  properties: PropTypes.array.isRequired,
  selectedLabel: PropTypes.string.isRequired,
  onOpenAddDialog: PropTypes.func.isRequired,
  allProperyLabels: PropTypes.array.isRequired,
  onSelectedLabelChange: PropTypes.func.isRequired,
};

export default PropertySidebar;
