import { useEffect, useState } from 'react';
import * as yup from 'yup';
import Tab from '@material-ui/core/Tab';
import { Link } from 'react-router-dom';
import { useParams } from 'react-router';
import Tabs from '@material-ui/core/Tabs';
import Icon from '@material-ui/core/Icon';
import { useDispatch } from 'react-redux';
import { useForm } from 'react-hook-form';
import useRoles from '../hooks/useRoles';
import Spinner from 'app/components/Spinner';
import { useUpdateEffect } from '@fuse/hooks';
import { useHistory } from 'react-router-dom';
import { useTranslation } from 'react-i18next';
import FuseAnimate from '@fuse/core/FuseAnimate';
import { useTheme } from '@material-ui/core/styles';
import useSaveRole from '../hooks/useSaveRole';
import Typography from '@material-ui/core/Typography';
import { yupResolver } from '@hookform/resolvers/yup';
import FusePageCarded from '@fuse/core/FusePageCarded';
import LoadingButton from 'app/components/LoadingButton';
import { showMessage } from 'app/store/fuse/messageSlice';
import CurrencySettings from './CurrencySettings';
import PanelSettings from './PanelSettings';
import { Button } from '@material-ui/core';
import useSaveUserSettings from '../hooks/useSaveUserSettings';

const validationSchema = yup.object().shape({
  name: yup.string().required(),
});

const defaultFormState = {
  wish: 0,
  like: 0,
  name: '',
  Code: '',
  info: '',
  tags: [],
  images: [],
  taxRate: 0,
  discount: 0,
  quantity: 0,
  master: null,
  cluster: null,
  publish: false,
  properties: [],
  description: '',
  priceTaxExcl: 0,
  priceTaxIncl: 0,
  courselevel: null,
  categoriesObject: [],
  featuredImageId: null,
};

const AppSettings = () => {
  const [tabValue, setTabValue] = useState(0);
  const theme = useTheme();
  const { t } = useTranslation('settings');
  let { postId } = useParams();
  const isEdit = postId !== 'new';

  const { data, isLoading, remove } = useRoles({
    postId,
    enabled: isEdit,
  });
  const handleChangeTab = (event, value) => {
    setTabValue(value);
  };
  
  const { register, handleSubmit, watch, errors } = useForm();
  const [updateSettings] = useSaveUserSettings()
  
  const onSubmit = data => {
    updateSettings(data)
  }

  return (
    <form className="h-full">
      <FusePageCarded
        classes={{
          toolbar: 'p-0',
          header: 'min-h-72 h-72 sm:h-136 sm:min-h-136',
        }}
        header={
          <div className="flex flex-1 w-full items-center justify-between">
            <div className="flex flex-col items-start max-w-full">
              <FuseAnimate animation="transition.slideRightIn" delay={300}>
                <Typography
                  role="button"
                  color="inherit"
                  component={Link}
                  to="/dashboard"
                  className="normal-case flex items-center sm:mb-12"
                >
                  <Icon className="text-20">
                    {theme.direction === 'ltr' ? 'arrow_back' : 'arrow_forward'}
                  </Icon>
                  <span className="mx-4">{t('SETTINGS')}</span>
                </Typography>
              </FuseAnimate>

              <div className="flex items-center max-w-full">
                <div className="flex flex-col min-w-0 mx-8 sm:mc-16">
                  <FuseAnimate animation="transition.slideLeftIn" delay={300}>
                    <Typography className="text-16 sm:text-20 truncate">
                      {isEdit && data ? data.name : t('NEW_PRODUCT')}
                    </Typography>
                  </FuseAnimate>
                </div>
              </div>
            </div>
            <Button
              type="submit"
              color="secondary"
              variant="contained"
              onClick={handleSubmit(onSubmit)}
              className="whitespace-no-wrap normal-case"
            >
              {t('SAVE')}
            </Button>
          </div>
        }
        contentToolbar={
          <Tabs
            value={tabValue}
            textColor="primary"
            variant="scrollable"
            scrollButtons="auto"
            indicatorColor="primary"
            onChange={handleChangeTab}
            classes={{ root: 'w-full h-64' }}
          >
            <Tab className="h-64 normal-case" label={t('CURRENCY')} />
            <Tab className="h-64 normal-case" label={t('PANEL')} />
          </Tabs>
        }
        content={
          <div className="p-16 sm:p-24">
            {tabValue === 0 && <CurrencySettings register={register} />}
            {tabValue === 1 && <PanelSettings register={register}/>}
          </div>
        }
        innerScroll
      />
    </form>
  );
};

export default AppSettings;
