import { useEffect, useMemo, useState } from 'react';
import qs from 'qs';
import Icon from '@material-ui/core/Icon';
import Spinner from 'app/components/Spinner';
import useRoles from '../hooks/useRoles';
import { useTranslation } from 'react-i18next';
import DataTable from 'app/components/DataTable';
import { makeStyles } from '@material-ui/core/styles';
import IconButton from '@material-ui/core/IconButton';
import AddIcon from '@material-ui/icons/Add';
import { useLocation, useHistory } from 'react-router-dom';
import useDeleteRole from '../hooks/useDeleteRole';
import useDataTable from 'app/components/DataTable/useDataTable';
import DataTableCheckbox from 'app/components/DataTable/DataTableCheckbox';
import {
  Accordion,
  AccordionDetails,
  AccordionSummary,
  Button,
  FormControl,
  InputLabel,
  MenuItem,
  Select,
  TextField,
  Typography,
} from '@material-ui/core';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import LocalGroceryStoreIcon from '@material-ui/icons/LocalGroceryStore';
import LibraryBooksIcon from '@material-ui/icons/LibraryBooks';
import Mymodal from 'app/pages/e-laundry/Orders/Mymodal/Mymodal';
const useStyles = makeStyles((theme) => ({
  addnew: {
    backgroundColor: '#142534',
    color: 'white',
    marginBottom: 20,
    '&:hover': {
      backgroundColor: '#142534',
    },
  },
  modalroot: {
    backgroundColor: 'white',
    borderRadius: 8,
    width: 600,
    overflow: 'hidden',
  },
  modalwrapper: {
    width: '100%',
    minHeight: 200,
  },
  modalhead: {
    backgroundColor: '#3c4252',
    width: '100%',
    height: 50,
    padding: 20,
    textAlign: 'right',
    display: 'flex',
    alignItems: 'center',
    color: 'white',
  },
  body: {
    padding: 20,
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center',
    justifyContent: 'center',
  },
  addbtn: {
    marginTop: 20,
    padding: '5px 20px',
    color: 'white',
    backgroundColor: '#3c4252',
    width: '100%',
    '&:hover': {
      backgroundColor: '#3c4252',
    },
  },
}));

function CurrencySettings() {
  const classes = useStyles();
  const { t } = useTranslation('orders');

  const history = useHistory();
  const { search: locationSearch } = useLocation();

  const urlParams = qs.parse(locationSearch, {
    ignoreQueryPrefix: true,
  });

  const [queryPerPage, setQueryPerPage] = useState(
    parseInt(urlParams.perPage) || 10
  );
  const [queryPage, setQueryPage] = useState(parseInt(urlParams.page) || 1);
  const [querySortBy, setQuerySortBy] = useState(urlParams.sortBy);
  const [querySortDir, setQuerySortDir] = useState(urlParams.sortDir);
  const [querySearch, setQuerySearch] = useState(urlParams.search);
  const [open, setOpen] = useState(false);
  const handleOpen = () => {
    setOpen(true);
  };

  const handleClose = () => {
    setOpen(false);
  };
  const {
    isLoading,
    isFetching,
    resolvedData = { count: 0, orders: [], pageCount: 0 },
  } = useRoles({
    page: queryPage,
    search: querySearch,
    sortBy: querySortBy,
    perPage: queryPerPage,
    sortDir: querySortDir,
  });
  const [deleteOrderList] = useDeleteRole();

  const columns = useMemo(
    () => [
      {
        id: 'selection',
        header: ({
          selectedRows,
          isAllRowsSelected,
          isIndeterminateSelect,
          onToggleAllSelectedRow,
        }) => {
          const selectedRowIds = Object.keys(selectedRows);

          return (
            <div className="flex">
              <DataTableCheckbox
                className="mx-10"
                checked={isAllRowsSelected}
                indeterminate={isIndeterminateSelect}
                onChange={(e) => onToggleAllSelectedRow(e.target.checked)}
              />

              {selectedRowIds.length > 0 && (
                <div className="flex items-center justify-center h-64 mx-10">
                  <IconButton
                    onClick={(e) => {
                      e.stopPropagation();
                      deleteOrderList(selectedRowIds).then(() => {
                        onToggleAllSelectedRow(false);
                      });
                    }}
                  >
                    <Icon color="error">delete</Icon>
                  </IconButton>
                </div>
              )}
            </div>
          );
        },
        accessor: ({ row, isSelected, handleToggleSelectedRow }) => (
          <div>
            <DataTableCheckbox
              className="mx-10"
              checked={isSelected}
              onChange={(e) =>
                handleToggleSelectedRow(row.id, e.target.checked)
              }
            />
          </div>
        ),
        headerClassName: 'w-136',
        disablePadding: true,
      },
      {
        header:t('CURRENCY'),
        sortable: true,
        accessor: ({ row }) =>
          row.customer.firstName + ' ' + row.customer.lastName,
      },
      {
        header:t('SYMBOL'),
        accessor: ({ row }) => row.gateway.title,
        sortable: true,
      },
      { header:t('CUST') , accessor: 'total', sortable: true },
      {
        header:t('DEFAULT') ,
        sortable: true,
        accessor: ({ row }) =>
          row.status.length ? row.status[row.status.length - 1].name : '',
        id: 'status',
      },
      {
        id: 'active',
        header: t('ACTIVE'),
        sortable: true,
        accessor: ({ row }) =>
          row.publish ? (
            <Icon className="text-green text-20">check_circle</Icon>
          ) : (
            <Icon className="text-red text-20">remove_circle</Icon>
          ),
      },
    ],
    [t, deleteOrderList]
  );

  const {
    page,
    sortBy,
    search,
    perPage,
    sortDir,
    handleSearch,
    appliedFilters,
    ...tableInstance
  } = useDataTable({
    columns,
    initialPage: queryPage,
    initialSortBy: querySortBy,
    initialSearch: querySearch,
    data: resolvedData?.orders,
    initialPerPage: queryPerPage,
    initialSortDir: querySortDir,
  });

  useEffect(() => {
    setQueryPage(page);
  }, [page]);

  useEffect(() => {
    setQueryPerPage(perPage);
  }, [perPage]);

  useEffect(() => {
    setQuerySearch(search);
  }, [search]);

  useEffect(() => {
    if (sortBy !== querySortBy) {
      setQuerySortBy(sortBy);
    }

    if (sortDir !== querySortDir) {
      setQuerySortDir(sortDir);
    }
  }, [sortBy, sortDir, querySortBy, querySortDir]);

  const handleNavigateToOrder = (row) => {
    history.push(`/apps/e-laundry/ordersview/${row.id}`);
  };
  const [product, setproduct] = useState(undefined);
  const [dropdown, setdropdown] = useState('product');
  const [price, setprice] = useState(0);
  const handleChange = (event) => {
    setproduct(event.target.value);
  };
  return (
    <>
      {isLoading && <Spinner />}
      <Mymodal
        open={open}
        close={handleClose}
        modal={
          <>
            <div className={classes.modalroot}>
              <div className={classes.modalwrapper}>
                <div className={classes.modalhead}>     {t('ADD_NEW_CURRENCY')}   </div>
                <div className={classes.body}>
                  <FormControl variant="outlined" className="w-full">
                    <InputLabel id="demo-simple-select-outlined-label">
                      product
                    </InputLabel>
                    <Select
                      labelId="demo-simple-select-outlined-label"
                      id="demo-simple-select-outlined"
                      value={product}
                      onChange={handleChange}
                      label="Select a product"
                    >
                      <MenuItem value="none">
                        <em>None</em>
                      </MenuItem>
                      <MenuItem value={'test'}>USD</MenuItem>
                      <MenuItem value={'one'}>RUB</MenuItem>
                      <MenuItem value={'two'}>EUR</MenuItem>
                    </Select>
                  </FormControl>
                  {product === undefined || product === 'none' ? (
                    ''
                  ) : (
                    <>
                      <Accordion
                        className="w-full mt-16"
                        expanded={dropdown === 'product'}
                        onChange={() =>
                          setdropdown(
                            dropdown !== 'product' ? 'product' : false
                          )
                        }
                      >
                        <AccordionSummary expandIcon={<ExpandMoreIcon />}>
                          <div style={{ color: 'gray' }} className="flex">
                            <LocalGroceryStoreIcon />
                            <Typography className="font-600 mx-8">
                              {product}
                            </Typography>
                          </div>
                        </AccordionSummary>
                        <AccordionDetails className="flex flex-col md:flex-row">
                          <TextField
                            id="Quantity"
                            label="Quantity"
                            className="w-full m-4"
                            type="number"
                            InputProps={{
                              inputProps: {
                                max: 10000,
                                min: 0,
                              },
                            }}
                            variant="outlined"
                            InputLabelProps={{
                              shrink: true,
                            }}
                          />
                          <TextField
                            id="price"
                            label="price"
                            className="w-full m-4"
                            type="number"
                            value={price}
                            onChange={(e) => setprice(e.target.value)}
                            InputProps={{
                              inputProps: {
                                max: 10000,
                                min: 0,
                              },
                            }}
                            variant="outlined"
                            InputLabelProps={{
                              shrink: true,
                            }}
                            helperText={`price   : (${price} USD )`}
                          />
                        </AccordionDetails>
                      </Accordion>
                      <Accordion
                        className="w-full mt-16"
                        expanded={dropdown === 'propertises'}
                        onChange={() =>
                          setdropdown(
                            dropdown !== 'propertises' ? 'propertises' : false
                          )
                        }
                      >
                        <AccordionSummary expandIcon={<ExpandMoreIcon />}>
                          <div style={{ color: 'gray' }} className="flex">
                            <LibraryBooksIcon />
                            <Typography className="font-600 mx-8">
                              Propertises
                            </Typography>
                          </div>
                        </AccordionSummary>
                        <AccordionDetails className="flex flex-col md:flex-row">
                          Detail
                        </AccordionDetails>
                      </Accordion>
                      <Button className={classes.addbtn}>Add</Button>
                    </>
                  )}
                </div>
              </div>
            </div>
          </>
        }
      />
      <DataTable
        hover
        page={page}
        stickyHeader
        sortBy={sortBy}
        sortDir={sortDir}
        perPage={perPage}
        isLoading={isFetching}
        count={resolvedData?.count}
        onRowClick={handleNavigateToOrder}
        {...tableInstance}
      />
      <IconButton onClick={handleOpen} className={classes.addnew}>
        <AddIcon />
      </IconButton>
      {console.log(resolvedData)}
    </>
  );
}

export default CurrencySettings;
