import React, { useState } from 'react';
import { makeStyles } from '@material-ui/core/styles';
import InputLabel from '@material-ui/core/InputLabel';
import FormControl from '@material-ui/core/FormControl';
import { useTranslation } from 'react-i18next';
import Select from '@material-ui/core/Select';
import SettingsApplicationsIcon from '@material-ui/icons/SettingsApplications';
import { TextField, Typography } from '@material-ui/core';
import FlipCameraAndroidIcon from '@material-ui/icons/FlipCameraAndroid';
const useStyles = makeStyles((theme) => ({
  formControl: {
    direction: 'ltr !important',
    minWidth: 300,
    textAlign: 'end !important',
    margin: '0 0.8rem',
  },
  selectEmpty: {
    marginTop: theme.spacing(2),
  },
  header: {
    margin: '30px 0',
    display: 'flex',
    color: 'rgba(0,0,0,0.7)',
    alignItems: 'center',
  },
  servicesSettings: {
    marginBottom: 15,
    display: 'flex',
    maxWidth: 1200,
  },
}));

const PanelSettings = ({ register }) => {
  const classes = useStyles();
  const [state, setState] = useState({
    Language: '',
    name: 'hai',
  });
  const { t } = useTranslation('settings');

  const handleChange = (event) => {
    const name = event.target.name;
    setState({
      ...state,
      [name]: event.target.value,
    });
  };

  return (
    <div>
      <FormControl variant="outlined" className={classes.formControl}>
        <InputLabel htmlFor="outlined-age-native-simple">Language</InputLabel>
        <Select
          native
          placeholder="asd"
          value={state.age}
          onChange={handleChange}
          label={t('LANGUAGE')}
          inputProps={{
            name: 'Language',
            id: 'outlined-age-native-simple',
          }}
        >
          <option aria-label="None" value="" />
          <option value={'Arabic'}>Arabic</option>
          <option value={'English'}>English</option>
          <option value={'Russian'}>Russian</option>
          <option value={'French'}>French</option>
        </Select>
      </FormControl>

      <div className={classes.header}>
        <SettingsApplicationsIcon className="text-4xl" />
        <Typography className="mx-8 text-2xl">{t('RADIUS_SERVICE')}</Typography>
      </div>

      <div className={classes.servicesSettings}>
        <TextField
          name="distanceMatrixVal"
          inputRef={register}
          fullWidth
          label={t('DISTANCEMATRIXVAL')}
          className="mx-8"
          type="number"
          InputProps={{
            inputProps: {
              max: 200,
              min: 2,
            },
          }}
          variant="outlined"
          className="md:w-1/3 px-3 mb-16 md:mb-0 mx-8"
        />
        <TextField
          name="CountMaster"
          inputRef={register}
          fullWidth
          type="number"
          label={t('COUNTMASTER')}  
          InputProps={{
            inputProps: {
              max: 10000,
              min: 0,
            },
          }}
          variant="outlined"
          className="md:w-1/3 px-3 mb-16 md:mb-0 mx-8"
        />
        <TextField
          name="TripMaster"
          inputRef={register}
          fullWidth
          type="number"
          label={t('TRIPMASTER')} 
          InputProps={{
            inputProps: {
              max: 10000,
              min: 0,
            },
          }}
          variant="outlined"
          className="md:w-1/3 px-3 mb-16 md:mb-0 mx-8"
        />
      </div>

      <div className={classes.servicesSettings}>
        <TextField
          name="surgePrice"
          inputRef={register}
          fullWidth
          type="number"
          label={t('SURGEPRICE')}   
          InputProps={{
            inputProps: {
              max: 10000,
              min: 0,
            },
          }}
          variant="outlined"
          className="md:w-1/3 px-3 mb-16 md:mb-0 mx-8"
        />
        <TextField
          name="hardLimit"
          inputRef={register}
          fullWidth
          type="number"
          label={t('HARDLIMIT')}   
          InputProps={{
            inputProps: {
              max: 10000,
              min: 0,
            },
          }}
          variant="outlined"
          className="md:w-1/3 px-3 mb-16 md:mb-0 mx-8"
        />
        <TextField
          name="newBookingMaxSearchTime  "
          inputRef={register}
          fullWidth
          type="number"
          label={t('NEWBOOKINGMAXSEARCHTIME')}   
          InputProps={{
            inputProps: {
              max: 1000000,
              min: 1,
            },
          }}
          variant="outlined"
          className="md:w-1/3 px-3 mb-16 md:mb-0 mx-8"
        />
      </div>


      <div className={classes.header}>
        <FlipCameraAndroidIcon className="text-4xl" />
        <Typography className="mx-8 text-2xl">
        {t('APPLICATION_VER')}   
        </Typography>
      </div>


      

    <div className="flex" >
        <TextField
          name="andCust"
          inputRef={register}
          fullWidth
          className="mx-8"
          label={t('ANDCUST')}     
          defaultValue={4}
          type="number"
          InputProps={{
            inputProps: {
              max: 10,
              min: 1,
            },
          }}
          variant="outlined"
          className="md:w-1/4 px-3 mb-16 md:mb-8 mx-8"
        />
        <TextField
          name="iosCust"
          inputRef={register}
          fullWidth
          type="number"
          label={t('IOSCUST')}   
          defaultValue={6.0}
          InputProps={{
            inputProps: {
              max: 10000,
              min: 3,
            },
          }}
          variant="outlined"
          className="md:w-1/4 px-3 mb-16 md:mb-8 mx-8"
        />
        <TextField
          name="andDriver"
          inputRef={register}
          fullWidth
          type="number"
          label={t('ANDDRIVER')} 
          InputProps={{
            inputProps: {
              max: 10000,
              min: 2,
            },
          }}
          variant="outlined"
          className="md:w-1/4 px-3 mb-16 md:mb-8 mx-8"
        />    
        <TextField
          name="iosDriver"
          inputRef={register}
          fullWidth
          type="number"
          label={t('IOSDRIVER')}       
          InputProps={{
            inputProps: {
              max: 10000,
              min: 3,
            },
          }}
          variant="outlined"
          className="md:w-1/4 px-3 mb-16 md:mb-8 mx-8"
        />
  </div>
 


   <div className="flex" >
        <TextField
          name="mandatory"
          inputRef={register}
          fullWidth
          type="number"
          label={t('MANDATORY')}       
          InputProps={{
            inputProps: {
              max: 10000,
              min: 0,
            },
          }}
          variant="outlined"
          className="md:w-1/4 px-3 mb-16 md:mb-8 mx-8"
        />
        <TextField
          name="updatelink"
          inputRef={register}
          fullWidth
          type="text"
          label={t('UPDATELINK')}       
          InputProps={{
            inputProps: {
              max: 10000,
              min: 0,
            },
          }}
          variant="outlined"
          className="md:w-1/2 px-3 mb-16 md:mb-8 mx-8"
        />
        <input type="text" name="asd" ref={register} />
         
      </div>


     </div> 
   
  );
};

export default PanelSettings;
