import axios from 'axios';
import { queryCache } from 'app/App';
import { useMutation } from 'react-query';
import { getSliderKey } from './useSlider';

export default function useDeleteCategory() {
  return useMutation(
    ({ id }) => {
      return axios.delete('/api/slider-app/remove-category', {
        data: { categoryId: id },
      });
    },
    {
      onMutate: ({ id, labelHandle, filterHandle, folderHandle }) => {
        const sliderKey = getSliderKey({
          labelHandle,
          filterHandle,
          folderHandle,
        });

        queryCache.cancelQueries('slider');

        const previousSlider = queryCache.getQueryData(sliderKey);

        queryCache.setQueryData(
          sliderKey,
          previousSlider.filter((category) => category.id !== id)
        );

        return () => queryCache.setQueryData(sliderKey, previousSlider);
      },
      onError: (err, variables, rollback) => rollback(),
      onSuccess: () => {
        queryCache.invalidateQueries('slider');
      },
    }
  );
}
