import React, { useEffect } from 'react';
import axios from 'axios';
import { makeStyles } from '@material-ui/core/styles';
import { Box, Button, IconButton, Typography } from '@material-ui/core';
import { useTranslation } from 'react-i18next';
import Icon from '@material-ui/core/Icon';
import AccessibilityIcon from '@material-ui/icons/Accessibility';
import EmailIcon from '@material-ui/icons/Email';
import ContactPhoneIcon from '@material-ui/icons/ContactPhone';
import PublicIcon from '@material-ui/icons/Public';
import HomeIcon from '@material-ui/icons/Home';
import MarkunreadMailboxIcon from '@material-ui/icons/MarkunreadMailbox';
import PaymentIcon from '@material-ui/icons/Payment';
import DeleteOutlineIcon from '@material-ui/icons/DeleteOutline';
import { useForm } from 'react-hook-form';
import useSaveUserSettings from '../hooks/useSaveUserSettings';
const useStyles = makeStyles((theme) => ({
  root: {
    minWidth: '50vw',
    minHeight: 400,
  },
  title: {
    width: '100%',
    padding: 20,
    textAlign: 'right',
    backgroundColor: '#3c4252',
    color: 'white',
  },
  submit: {
    width: 150,
    height: 40,
    marginTop: 20,
    backgroundColor: '#3c4252',
    color: 'white',
    '&:hover': {
      backgroundColor: '#3c4252',
    },
  },
}));
const UserDatas = ({
  address,
  id,
  displayName,
  email,
  mobile,
  natCode,
  postCode,
  role,
  status,
}) => {
  const { register, handleSubmit } = useForm();
  const onSubmit = (user) => {
    var pushid = [];
    user.id = id;
    user.quantity = 'quantity';
    pushid.push(user);
    axios
      .put('/api/usermanager-app/save-user', { user })
      .then((res) => {
        alert(res.statusText);
      })
      .catch((err) => {
        alert(err);
      });
  };
  // const [onSubmit] = useSaveUserSettings()

  const classes = useStyles();
  const { t } = useTranslation('settings');
  return (
    <Box className={classes.root}>
      <Box>
        <Box className={classes.title}>
          <Typography variant="h6">Edit User</Typography>
        </Box>
        <form className="w-full max-w-lg px-16 m-auto pt-8">
          <Box className="flex flex-wrap -mx-3 mb-12">
            <Box className="w-full md:w-1/2 px-3 mb-6 md:mb-0">
              <label className="block uppercase tracking-wide text-gray-700 text-14 font-bold mb-4">
                {t('USERNAME')}
              </label>
              <Box className="relative">
                <Icon
                  style={{ border: '1px solid rgba(97, 97, 97,0.2)' }}
                  className="bg-grey-300 p-5 text-gray-600 absolute flex right-0 top-0 h-full w-36 items-center "
                >
                  person
                </Icon>
                <input
                  ref={register}
                  name="displayName"
                  className="px-40 placeholder-black appearance-none border block w-full bg-gray-100 text-gray-700 rounded py-10 px-6 mb-3 leading-tight focus:outline-none focus:bg-white"
                  type="text"
                  defaultValue={displayName}
                  placeholder={t('USERNAME')}
                />
              </Box>
            </Box>
            <Box className="w-full md:w-1/2 px-3">
              <label className="block uppercase tracking-wide text-gray-700 text-14 font-bold mb-4">
                {t('ROLE')}
              </label>
              <Box className="relative">
                <AccessibilityIcon
                  style={{ border: '1px solid rgba(97, 97, 97,0.2)' }}
                  className="bg-grey-300 p-5 text-gray-600 absolute flex right-0 top-0 h-full w-36 items-center "
                />
                <input
                  ref={register}
                  name="role"
                  className="px-40 placeholder-black  appearance-none block w-full bg-gray-100 text-gray-700 border rounded py-10 px-6 mb-3 leading-tight focus:outline-none focus:bg-white"
                  type="text"
                  defaultValue={role}
                  placeholder={t('ROLE')}
                />
              </Box>
            </Box>
          </Box>
          <Box className="flex flex-wrap -mx-3 mb-12">
            <Box className="w-full px-3">
              <label className="block uppercase tracking-wide text-gray-700 text-14 font-bold mb-4">
                {t('EMAIL')}
              </label>
              <Box className="relative">
                <EmailIcon
                  style={{ border: '1px solid rgba(97, 97, 97,0.2)' }}
                  className="bg-grey-300 p-5 text-gray-600 absolute flex right-0 top-0 h-full w-36 items-center "
                />
                <input
                  ref={register}
                  name="email"
                  defaultValue={email}
                  className="px-40 placeholder-black  appearance-none block w-full bg-gray-100 text-gray-700 border rounded py-10 px-6 mb-3 leading-tight focus:outline-none focus:bg-white"
                  type="email"
                  placeholder={t('EMAIL')}
                />
              </Box>
            </Box>
          </Box>
          <Box className="flex flex-wrap -mx-3 mb-12">
            <Box className="w-full md:w-1/3 px-3 mb-6 md:mb-0">
              <label className="block uppercase tracking-wide text-gray-700 text-14 font-bold mb-4">
                {t('NUMBER')}
              </label>
              <Box className="relative">
                <ContactPhoneIcon
                  style={{ border: '1px solid rgba(97, 97, 97,0.2)' }}
                  className="bg-grey-300 p-5 text-gray-600 absolute flex right-0 top-0 h-full w-36 items-center "
                />
                <input
                  ref={register}
                  name="mobile"
                  defaultValue={mobile}
                  className="px-40 placeholder-black  appearance-none block w-full bg-gray-100 text-gray-700 border rounded py-10 px-6 mb-3 leading-tight focus:outline-none focus:bg-white"
                  type="text"
                  placeholder={t('NUMBER')}
                />
              </Box>
            </Box>
            <Box className="w-full md:w-1/3 px-3 mb-6 md:mb-0">
              <label className="block uppercase tracking-wide text-gray-700 text-14 font-bold mb-4">
                {t('NATIONAL_ID')}
              </label>
              <Box className="relative">
                <PublicIcon
                  style={{ border: '1px solid rgba(97, 97, 97,0.2)' }}
                  className="bg-grey-300 p-5 text-gray-600 absolute flex right-0 top-0 h-full w-36 items-center "
                />
                <input
                  ref={register}
                  name="natCode"
                  defaultValue={natCode}
                  className="px-40 placeholder-black  appearance-none block w-full bg-gray-100 text-gray-700 border rounded py-10 px-6 mb-3 leading-tight focus:outline-none focus:bg-white"
                  type="text"
                  placeholder={t('NATIONAL_ID')}
                />
              </Box>
            </Box>
            <Box className="w-full md:w-1/3 px-3 mb-6 md:mb-0">
              <label className="block uppercase tracking-wide text-gray-700 text-14 font-bold mb-4">
                {t('STATUS')}
              </label>
              <Box className="relative">
                <select
                  defaultValue={status}
                  className="block appearance-none w-full bg-gray-200 border border-gray-100 text-gray-700 py-10 px-6 pr-8 rounded leading-tight focus:outline-none focus:bg-white focus:border-gray-500"
                  id="grid-state"
                >
                  <option>{t('ONLINE')}</option>
                  <option>{t('OFFLINE')}</option>
                  <option>Test</option>
                </select>
              </Box>
              <Box className="pointer-events-none absolute inset-y-0 right-0 flex items-center px-2 text-gray-700">
                <svg
                  className="fill-current h-4 w-4"
                  xmlns="http://www.w3.org/2000/svg"
                  viewBox="0 0 20 20"
                >
                  <path d="M9.293 12.95l.707.707L15.657 8l-1.414-1.414L10 10.828 5.757 6.586 4.343 8z" />
                </svg>
              </Box>
            </Box>
          </Box>
          <Box className="w-full px-3 mb-12 ">
            <label className="block uppercase tracking-wide text-gray-700 text-14 font-bold mb-4">
              {t('ADDRESS')}
            </label>
            <Box className="relative">
              <HomeIcon
                style={{ border: '1px solid rgba(97, 97, 97,0.2)' }}
                className="bg-grey-300 p-5 text-gray-600 absolute flex right-0 top-0 h-full w-36 items-center "
              />
              <input
                ref={register}
                name="address"
                defaultValue={address}
                className="px-40 appearance-none block w-full bg-gray-100 text-gray-700 border rounded py-10 px-6 mb-3 leading-tight focus:outline-none focus:bg-white"
                type="text"
                placeholder={t('ADDRESS')}
              />
            </Box>
          </Box>
          <Box className="flex flex-wrap mb-12">
            <Box className="w-full md:w-1/2 px-3 mb-6 md:mb-0">
              <label className="block uppercase tracking-wide text-gray-700 text-14 font-bold mb-4">
                {t('POSTAL_CODE')}
              </label>
              <Box className="relative">
                <MarkunreadMailboxIcon
                  style={{ border: '1px solid rgba(97, 97, 97,0.2)' }}
                  className="bg-grey-300 p-5 text-gray-600 absolute flex right-0 top-0 h-full w-36 items-center "
                />
                <input
                  ref={register}
                  name="postCode"
                  defaultValue={postCode}
                  className="px-40 placeholder-black  appearance-none block w-full bg-gray-100 text-gray-700 border rounded py-10 px-6 mb-3 leading-tight focus:outline-none focus:bg-white"
                  type="text"
                  placeholder={t('POSTAL_CODE')}
                />
              </Box>
            </Box>
            <Box className="w-full md:w-1/2 px-3 mb-6 md:mb-0">
              <label className="block uppercase tracking-wide text-gray-700 text-14 font-bold mb-4">
                {t('ECONOMIC_CODE')}
              </label>
              <Box className="relative">
                <PaymentIcon
                  style={{ border: '1px solid rgba(97, 97, 97,0.2)' }}
                  className="bg-grey-300 p-5 text-gray-600 absolute flex right-0 top-0 h-full w-36 items-center "
                />

                <input
                  ref={register}
                  name="echoCode"
                  className="px-40 placeholder-black  appearance-none block w-full bg-gray-100 text-gray-700 border rounded py-10 px-6 mb-3 leading-tight focus:outline-none focus:bg-white"
                  type="text"
                  placeholder={t('ECONOMIC_CODE')}
                />
              </Box>
            </Box>
            <Box className="flex w-full justify-between items-center">
              <IconButton>
                <DeleteOutlineIcon />
              </IconButton>
              <Button
                className={classes.submit}
                type="submit"
                onClick={handleSubmit(onSubmit)}
              >
                Save
              </Button>
            </Box>
          </Box>
        </form>
      </Box>
    </Box>
  );
};

export default UserDatas;
