import i18n from 'i18n';
import axios from 'axios';
import { createSlice } from '@reduxjs/toolkit';
import { setDefaultSettings } from './fuse/settingsSlice';

export const changeLanguage = (languageId) => (dispatch, getState) => {
  const { direction } = getState().fuse.settings.defaults;

  const newLangDirection = i18n.dir(languageId);

  /*
    Change Language
     */
  i18n.changeLanguage(languageId);

  /*
    If necessary, change theme direction
     */
  if (newLangDirection !== direction) {
    dispatch(setDefaultSettings({ direction: newLangDirection }));
  }

  localStorage?.setItem('locale', languageId);
  localStorage?.setItem('lang_direction', newLangDirection);
  axios.defaults.params = { Lang: languageId };

  return dispatch(i18nSlice.actions.languageChanged(languageId));
};

const i18nSlice = createSlice({
  name: 'i18n',
  initialState: {
    language: i18n.options.lng,
  },
  reducers: {
    languageChanged: (state, action) => {
      state.language = action.payload;
    },
  },
});

export default i18nSlice.reducer;
