import qs from "qs";
import axios from "axios";

export function get(url, params = {}) {
  return request("get", url, params);
}

export function post(url, data = {}) {
  return request("post", url, data);
}

function request(method, url, data = {}) {
  let config = {
    url,
    method,
    timeout: 60000,
    crossDomain: true,
    headers: {
      Accept: "application/json",
      "X-Requested-With": "XMLHttpRequest",
    },
  };

  if (method.toLowerCase() === "get") {
    config.params = data;
    config.paramsSerializer = (params) =>
      qs.stringify(params, { arrayFormat: "brackets" });
  }

  if (method.toLowerCase() === "post") {
    config.data = data;
  }

  return axios(config);
}

export function getApiError(error, errorKeysToChange = {}) {
  //TODO: add default error message
  let { message: responseMessage, response } = error || {};

  if (!response) {
    //TODO: return custom error message
    return { message: responseMessage };
  }

  let {
    status: statusCode,
    data: { errors: validationErrors = {}, message } = {},
  } = response;

  message = message ? message : responseMessage;

  if (statusCode === VALIDATION_ERROR_STATUS_CODE) {
    Object.keys(validationErrors).forEach((key) => {
      const changedName = errorKeysToChange[key];
      const fieldName = changedName ? changedName : key;

      validationErrors[fieldName] = validationErrors[key][0];

      if (changedName) {
        delete validationErrors[key];
      }
    });
    const firstError = Object.values(validationErrors)[0];

    message = firstError ? firstError : message;
  }

  return { validationErrors, message, statusCode };
}

export const VALIDATION_ERROR_STATUS_CODE = 422;
const UNAUTHORIZED_ERROR_STATUS_CODE = 401;
